# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'wizzard_main_ui.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setWindowModality(QtCore.Qt.NonModal)
        MainWindow.setEnabled(True)
        MainWindow.resize(790, 639)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(0, 45))
        MainWindow.setMaximumSize(QtCore.QSize(16777179, 16777215))
        MainWindow.setSizeIncrement(QtCore.QSize(9, 0))
        font = QtGui.QFont()
        font.setFamily("Arial")
        font.setPointSize(8)
        font.setBold(False)
        font.setWeight(50)
        MainWindow.setFont(font)
        MainWindow.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        MainWindow.setFocusPolicy(QtCore.Qt.NoFocus)
        MainWindow.setContextMenuPolicy(QtCore.Qt.PreventContextMenu)
        MainWindow.setToolTipDuration(6)
        MainWindow.setAutoFillBackground(True)
        self.le_mountStatus = QtWidgets.QLineEdit(MainWindow)
        self.le_mountStatus.setGeometry(QtCore.QRect(10, 50, 351, 21))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(10)
        font.setBold(False)
        font.setWeight(50)
        self.le_mountStatus.setFont(font)
        self.le_mountStatus.setMouseTracking(False)
        self.le_mountStatus.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_mountStatus.setAcceptDrops(False)
        self.le_mountStatus.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_mountStatus.setReadOnly(True)
        self.le_mountStatus.setObjectName("le_mountStatus")
        self.mainTabWidget = QtWidgets.QTabWidget(MainWindow)
        self.mainTabWidget.setGeometry(QtCore.QRect(10, 120, 771, 511))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mainTabWidget.sizePolicy().hasHeightForWidth())
        self.mainTabWidget.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.mainTabWidget.setFont(font)
        self.mainTabWidget.setObjectName("mainTabWidget")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.le_telescopeRA = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeRA.setGeometry(QtCore.QRect(10, 140, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeRA.setFont(font)
        self.le_telescopeRA.setMouseTracking(False)
        self.le_telescopeRA.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeRA.setAcceptDrops(False)
        self.le_telescopeRA.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeRA.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeRA.setReadOnly(True)
        self.le_telescopeRA.setObjectName("le_telescopeRA")
        self.le_telescopeAzimut = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeAzimut.setGeometry(QtCore.QRect(10, 70, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeAzimut.setFont(font)
        self.le_telescopeAzimut.setMouseTracking(False)
        self.le_telescopeAzimut.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeAzimut.setAcceptDrops(False)
        self.le_telescopeAzimut.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeAzimut.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeAzimut.setReadOnly(True)
        self.le_telescopeAzimut.setObjectName("le_telescopeAzimut")
        self.le_telescopeDEC = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeDEC.setGeometry(QtCore.QRect(230, 140, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeDEC.setFont(font)
        self.le_telescopeDEC.setMouseTracking(False)
        self.le_telescopeDEC.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeDEC.setAcceptDrops(False)
        self.le_telescopeDEC.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeDEC.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeDEC.setReadOnly(True)
        self.le_telescopeDEC.setObjectName("le_telescopeDEC")
        self.le_telescopeAltitude = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeAltitude.setGeometry(QtCore.QRect(230, 70, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeAltitude.setFont(font)
        self.le_telescopeAltitude.setMouseTracking(False)
        self.le_telescopeAltitude.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeAltitude.setAcceptDrops(False)
        self.le_telescopeAltitude.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeAltitude.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeAltitude.setReadOnly(True)
        self.le_telescopeAltitude.setObjectName("le_telescopeAltitude")
        self.label_9 = QtWidgets.QLabel(self.tab_2)
        self.label_9.setGeometry(QtCore.QRect(10, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.label_10 = QtWidgets.QLabel(self.tab_2)
        self.label_10.setGeometry(QtCore.QRect(230, 120, 131, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_10.setFont(font)
        self.label_10.setObjectName("label_10")
        self.label_8 = QtWidgets.QLabel(self.tab_2)
        self.label_8.setGeometry(QtCore.QRect(230, 50, 121, 21))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(10)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.label_11 = QtWidgets.QLabel(self.tab_2)
        self.label_11.setGeometry(QtCore.QRect(10, 120, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.label_17 = QtWidgets.QLabel(self.tab_2)
        self.label_17.setGeometry(QtCore.QRect(10, 240, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_17.setFont(font)
        self.label_17.setObjectName("label_17")
        self.le_meridianLimitTrack = QtWidgets.QLineEdit(self.tab_2)
        self.le_meridianLimitTrack.setGeometry(QtCore.QRect(140, 330, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_meridianLimitTrack.setFont(font)
        self.le_meridianLimitTrack.setMouseTracking(False)
        self.le_meridianLimitTrack.setAcceptDrops(False)
        self.le_meridianLimitTrack.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_meridianLimitTrack.setCursorPosition(2)
        self.le_meridianLimitTrack.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_meridianLimitTrack.setReadOnly(True)
        self.le_meridianLimitTrack.setObjectName("le_meridianLimitTrack")
        self.le_telescopePierSide = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopePierSide.setGeometry(QtCore.QRect(320, 240, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopePierSide.setFont(font)
        self.le_telescopePierSide.setMouseTracking(False)
        self.le_telescopePierSide.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopePierSide.setAcceptDrops(False)
        self.le_telescopePierSide.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopePierSide.setAlignment(QtCore.Qt.AlignCenter)
        self.le_telescopePierSide.setReadOnly(True)
        self.le_telescopePierSide.setObjectName("le_telescopePierSide")
        self.label_18 = QtWidgets.QLabel(self.tab_2)
        self.label_18.setGeometry(QtCore.QRect(230, 240, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_18.setFont(font)
        self.label_18.setObjectName("label_18")
        self.label_21 = QtWidgets.QLabel(self.tab_2)
        self.label_21.setGeometry(QtCore.QRect(10, 270, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_21.setFont(font)
        self.label_21.setObjectName("label_21")
        self.le_telescopeDualTrack = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeDualTrack.setGeometry(QtCore.QRect(120, 270, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeDualTrack.setFont(font)
        self.le_telescopeDualTrack.setMouseTracking(False)
        self.le_telescopeDualTrack.setAcceptDrops(False)
        self.le_telescopeDualTrack.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeDualTrack.setInputMask("")
        self.le_telescopeDualTrack.setAlignment(QtCore.Qt.AlignCenter)
        self.le_telescopeDualTrack.setReadOnly(True)
        self.le_telescopeDualTrack.setObjectName("le_telescopeDualTrack")
        self.btn_setDualTracking = QtWidgets.QPushButton(self.tab_2)
        self.btn_setDualTracking.setGeometry(QtCore.QRect(170, 270, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setDualTracking.setFont(font)
        self.btn_setDualTracking.setObjectName("btn_setDualTracking")
        self.label_52 = QtWidgets.QLabel(self.tab_2)
        self.label_52.setGeometry(QtCore.QRect(230, 330, 91, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_52.setFont(font)
        self.label_52.setWordWrap(False)
        self.label_52.setObjectName("label_52")
        self.le_timeToFlip = QtWidgets.QLineEdit(self.tab_2)
        self.le_timeToFlip.setGeometry(QtCore.QRect(340, 330, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_timeToFlip.setFont(font)
        self.le_timeToFlip.setMouseTracking(False)
        self.le_timeToFlip.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_timeToFlip.setAcceptDrops(False)
        self.le_timeToFlip.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_timeToFlip.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_timeToFlip.setReadOnly(True)
        self.le_timeToFlip.setObjectName("le_timeToFlip")
        self.btn_setUnattendedFlip = QtWidgets.QPushButton(self.tab_2)
        self.btn_setUnattendedFlip.setGeometry(QtCore.QRect(170, 300, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setUnattendedFlip.setFont(font)
        self.btn_setUnattendedFlip.setObjectName("btn_setUnattendedFlip")
        self.le_telescopeUnattendedFlip = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeUnattendedFlip.setGeometry(QtCore.QRect(120, 300, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeUnattendedFlip.setFont(font)
        self.le_telescopeUnattendedFlip.setMouseTracking(False)
        self.le_telescopeUnattendedFlip.setAcceptDrops(False)
        self.le_telescopeUnattendedFlip.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeUnattendedFlip.setInputMask("")
        self.le_telescopeUnattendedFlip.setAlignment(QtCore.Qt.AlignCenter)
        self.le_telescopeUnattendedFlip.setReadOnly(True)
        self.le_telescopeUnattendedFlip.setObjectName("le_telescopeUnattendedFlip")
        self.label_23 = QtWidgets.QLabel(self.tab_2)
        self.label_23.setGeometry(QtCore.QRect(10, 300, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_23.setFont(font)
        self.label_23.setObjectName("label_23")
        self.label_61 = QtWidgets.QLabel(self.tab_2)
        self.label_61.setGeometry(QtCore.QRect(390, 330, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_61.setFont(font)
        self.label_61.setAlignment(QtCore.Qt.AlignCenter)
        self.label_61.setWordWrap(False)
        self.label_61.setObjectName("label_61")
        self.label_62 = QtWidgets.QLabel(self.tab_2)
        self.label_62.setGeometry(QtCore.QRect(80, 240, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_62.setFont(font)
        self.label_62.setAlignment(QtCore.Qt.AlignCenter)
        self.label_62.setWordWrap(False)
        self.label_62.setObjectName("label_62")
        self.label_80 = QtWidgets.QLabel(self.tab_2)
        self.label_80.setGeometry(QtCore.QRect(10, 210, 211, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_80.setFont(font)
        self.label_80.setObjectName("label_80")
        self.line_12 = QtWidgets.QFrame(self.tab_2)
        self.line_12.setGeometry(QtCore.QRect(10, 220, 411, 21))
        self.line_12.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_12.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_12.setObjectName("line_12")
        self.line_13 = QtWidgets.QFrame(self.tab_2)
        self.line_13.setGeometry(QtCore.QRect(10, 30, 411, 21))
        self.line_13.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_13.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_13.setObjectName("line_13")
        self.label_81 = QtWidgets.QLabel(self.tab_2)
        self.label_81.setGeometry(QtCore.QRect(10, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_81.setFont(font)
        self.label_81.setObjectName("label_81")
        self.btn_startTracking = QtWidgets.QPushButton(self.tab_2)
        self.btn_startTracking.setGeometry(QtCore.QRect(460, 210, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_startTracking.setFont(font)
        self.btn_startTracking.setObjectName("btn_startTracking")
        self.btn_mountPark = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPark.setGeometry(QtCore.QRect(460, 330, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPark.setFont(font)
        self.btn_mountPark.setObjectName("btn_mountPark")
        self.btn_mountUnpark = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountUnpark.setGeometry(QtCore.QRect(610, 330, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountUnpark.setFont(font)
        self.btn_mountUnpark.setObjectName("btn_mountUnpark")
        self.line_16 = QtWidgets.QFrame(self.tab_2)
        self.line_16.setGeometry(QtCore.QRect(460, 310, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_16.setFont(font)
        self.line_16.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_16.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_16.setObjectName("line_16")
        self.label_83 = QtWidgets.QLabel(self.tab_2)
        self.label_83.setGeometry(QtCore.QRect(460, 20, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_83.setFont(font)
        self.label_83.setObjectName("label_83")
        self.label_84 = QtWidgets.QLabel(self.tab_2)
        self.label_84.setGeometry(QtCore.QRect(460, 180, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_84.setFont(font)
        self.label_84.setObjectName("label_84")
        self.btn_mountPos4 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos4.setGeometry(QtCore.QRect(610, 90, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos4.setFont(font)
        self.btn_mountPos4.setObjectName("btn_mountPos4")
        self.line_15 = QtWidgets.QFrame(self.tab_2)
        self.line_15.setGeometry(QtCore.QRect(460, 190, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_15.setFont(font)
        self.line_15.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_15.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_15.setObjectName("line_15")
        self.label_85 = QtWidgets.QLabel(self.tab_2)
        self.label_85.setGeometry(QtCore.QRect(460, 300, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_85.setFont(font)
        self.label_85.setObjectName("label_85")
        self.btn_mountPos2 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos2.setGeometry(QtCore.QRect(610, 50, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos2.setFont(font)
        self.btn_mountPos2.setObjectName("btn_mountPos2")
        self.btn_mountPos3 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos3.setGeometry(QtCore.QRect(460, 90, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos3.setFont(font)
        self.btn_mountPos3.setObjectName("btn_mountPos3")
        self.btn_mountPos1 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos1.setGeometry(QtCore.QRect(460, 50, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos1.setFont(font)
        self.btn_mountPos1.setObjectName("btn_mountPos1")
        self.btn_stopTracking = QtWidgets.QPushButton(self.tab_2)
        self.btn_stopTracking.setGeometry(QtCore.QRect(610, 210, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_stopTracking.setFont(font)
        self.btn_stopTracking.setObjectName("btn_stopTracking")
        self.line_14 = QtWidgets.QFrame(self.tab_2)
        self.line_14.setGeometry(QtCore.QRect(460, 30, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_14.setFont(font)
        self.line_14.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_14.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_14.setObjectName("line_14")
        self.btn_stop = QtWidgets.QPushButton(self.tab_2)
        self.btn_stop.setGeometry(QtCore.QRect(460, 370, 291, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_stop.setFont(font)
        self.btn_stop.setObjectName("btn_stop")
        self.btn_flipMount = QtWidgets.QPushButton(self.tab_2)
        self.btn_flipMount.setGeometry(QtCore.QRect(230, 270, 191, 51))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_flipMount.setFont(font)
        self.btn_flipMount.setObjectName("btn_flipMount")
        self.btn_setTrackingLunar = QtWidgets.QPushButton(self.tab_2)
        self.btn_setTrackingLunar.setGeometry(QtCore.QRect(460, 250, 91, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setTrackingLunar.setFont(font)
        self.btn_setTrackingLunar.setObjectName("btn_setTrackingLunar")
        self.btn_setTrackingSolar = QtWidgets.QPushButton(self.tab_2)
        self.btn_setTrackingSolar.setGeometry(QtCore.QRect(560, 250, 91, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setTrackingSolar.setFont(font)
        self.btn_setTrackingSolar.setObjectName("btn_setTrackingSolar")
        self.btn_setTrackingSideral = QtWidgets.QPushButton(self.tab_2)
        self.btn_setTrackingSideral.setGeometry(QtCore.QRect(660, 250, 91, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setTrackingSideral.setFont(font)
        self.btn_setTrackingSideral.setObjectName("btn_setTrackingSideral")
        self.label_100 = QtWidgets.QLabel(self.tab_2)
        self.label_100.setGeometry(QtCore.QRect(380, 240, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_100.setFont(font)
        self.label_100.setAlignment(QtCore.Qt.AlignCenter)
        self.label_100.setWordWrap(False)
        self.label_100.setObjectName("label_100")
        self.label_34 = QtWidgets.QLabel(self.tab_2)
        self.label_34.setGeometry(QtCore.QRect(10, 330, 141, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_34.setFont(font)
        self.label_34.setObjectName("label_34")
        self.label_65 = QtWidgets.QLabel(self.tab_2)
        self.label_65.setGeometry(QtCore.QRect(10, 360, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_65.setFont(font)
        self.label_65.setObjectName("label_65")
        self.le_meridianLimitSlew = QtWidgets.QLineEdit(self.tab_2)
        self.le_meridianLimitSlew.setGeometry(QtCore.QRect(140, 360, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_meridianLimitSlew.setFont(font)
        self.le_meridianLimitSlew.setMouseTracking(False)
        self.le_meridianLimitSlew.setAcceptDrops(False)
        self.le_meridianLimitSlew.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_meridianLimitSlew.setCursorPosition(2)
        self.le_meridianLimitSlew.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_meridianLimitSlew.setReadOnly(True)
        self.le_meridianLimitSlew.setObjectName("le_meridianLimitSlew")
        self.label_88 = QtWidgets.QLabel(self.tab_2)
        self.label_88.setGeometry(QtCore.QRect(180, 330, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_88.setFont(font)
        self.label_88.setAlignment(QtCore.Qt.AlignCenter)
        self.label_88.setWordWrap(False)
        self.label_88.setObjectName("label_88")
        self.label_89 = QtWidgets.QLabel(self.tab_2)
        self.label_89.setGeometry(QtCore.QRect(180, 360, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_89.setFont(font)
        self.label_89.setAlignment(QtCore.Qt.AlignCenter)
        self.label_89.setWordWrap(False)
        self.label_89.setObjectName("label_89")
        self.le_slewRate = QtWidgets.QLineEdit(self.tab_2)
        self.le_slewRate.setGeometry(QtCore.QRect(120, 240, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_slewRate.setFont(font)
        self.le_slewRate.setMouseTracking(False)
        self.le_slewRate.setAcceptDrops(False)
        self.le_slewRate.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_slewRate.setCursorPosition(2)
        self.le_slewRate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_slewRate.setReadOnly(False)
        self.le_slewRate.setObjectName("le_slewRate")
        self.label_90 = QtWidgets.QLabel(self.tab_2)
        self.label_90.setGeometry(QtCore.QRect(230, 360, 101, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_90.setFont(font)
        self.label_90.setWordWrap(False)
        self.label_90.setObjectName("label_90")
        self.le_timeToMeridian = QtWidgets.QLineEdit(self.tab_2)
        self.le_timeToMeridian.setGeometry(QtCore.QRect(340, 360, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_timeToMeridian.setFont(font)
        self.le_timeToMeridian.setMouseTracking(False)
        self.le_timeToMeridian.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_timeToMeridian.setAcceptDrops(False)
        self.le_timeToMeridian.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_timeToMeridian.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_timeToMeridian.setReadOnly(True)
        self.le_timeToMeridian.setObjectName("le_timeToMeridian")
        self.label_91 = QtWidgets.QLabel(self.tab_2)
        self.label_91.setGeometry(QtCore.QRect(390, 360, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_91.setFont(font)
        self.label_91.setAlignment(QtCore.Qt.AlignCenter)
        self.label_91.setWordWrap(False)
        self.label_91.setObjectName("label_91")
        self.btn_mountPos6 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos6.setGeometry(QtCore.QRect(610, 130, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos6.setFont(font)
        self.btn_mountPos6.setObjectName("btn_mountPos6")
        self.btn_mountPos5 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos5.setGeometry(QtCore.QRect(460, 130, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos5.setFont(font)
        self.btn_mountPos5.setObjectName("btn_mountPos5")
        self.btn_setSlewRate = QtWidgets.QPushButton(self.tab_2)
        self.btn_setSlewRate.setGeometry(QtCore.QRect(170, 240, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setSlewRate.setFont(font)
        self.btn_setSlewRate.setObjectName("btn_setSlewRate")
        self.label_20 = QtWidgets.QLabel(self.tab_2)
        self.label_20.setGeometry(QtCore.QRect(230, 430, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_20.setFont(font)
        self.label_20.setObjectName("label_20")
        self.le_horizonLimitHigh = QtWidgets.QLineEdit(self.tab_2)
        self.le_horizonLimitHigh.setGeometry(QtCore.QRect(340, 430, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_horizonLimitHigh.setFont(font)
        self.le_horizonLimitHigh.setMouseTracking(False)
        self.le_horizonLimitHigh.setAcceptDrops(False)
        self.le_horizonLimitHigh.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_horizonLimitHigh.setCursorPosition(3)
        self.le_horizonLimitHigh.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_horizonLimitHigh.setReadOnly(False)
        self.le_horizonLimitHigh.setObjectName("le_horizonLimitHigh")
        self.label_4 = QtWidgets.QLabel(self.tab_2)
        self.label_4.setGeometry(QtCore.QRect(10, 430, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.btn_setHorizonLimitLow = QtWidgets.QPushButton(self.tab_2)
        self.btn_setHorizonLimitLow.setGeometry(QtCore.QRect(170, 430, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setHorizonLimitLow.setFont(font)
        self.btn_setHorizonLimitLow.setObjectName("btn_setHorizonLimitLow")
        self.label_60 = QtWidgets.QLabel(self.tab_2)
        self.label_60.setGeometry(QtCore.QRect(330, 430, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_60.setFont(font)
        self.label_60.setObjectName("label_60")
        self.le_horizonLimitLow = QtWidgets.QLineEdit(self.tab_2)
        self.le_horizonLimitLow.setGeometry(QtCore.QRect(120, 430, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_horizonLimitLow.setFont(font)
        self.le_horizonLimitLow.setMouseTracking(False)
        self.le_horizonLimitLow.setAcceptDrops(False)
        self.le_horizonLimitLow.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_horizonLimitLow.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_horizonLimitLow.setReadOnly(False)
        self.le_horizonLimitLow.setClearButtonEnabled(False)
        self.le_horizonLimitLow.setObjectName("le_horizonLimitLow")
        self.label_59 = QtWidgets.QLabel(self.tab_2)
        self.label_59.setGeometry(QtCore.QRect(10, 400, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_59.setFont(font)
        self.label_59.setObjectName("label_59")
        self.line_9 = QtWidgets.QFrame(self.tab_2)
        self.line_9.setGeometry(QtCore.QRect(10, 410, 411, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_9.setFont(font)
        self.line_9.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_9.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_9.setObjectName("line_9")
        self.label_42 = QtWidgets.QLabel(self.tab_2)
        self.label_42.setGeometry(QtCore.QRect(110, 430, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_42.setFont(font)
        self.label_42.setObjectName("label_42")
        self.btn_setHorizonLimitHigh = QtWidgets.QPushButton(self.tab_2)
        self.btn_setHorizonLimitHigh.setGeometry(QtCore.QRect(390, 430, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setHorizonLimitHigh.setFont(font)
        self.btn_setHorizonLimitHigh.setObjectName("btn_setHorizonLimitHigh")
        self.line_51 = QtWidgets.QFrame(self.tab_2)
        self.line_51.setGeometry(QtCore.QRect(430, 10, 21, 461))
        self.line_51.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_51.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_51.setObjectName("line_51")
        self.mainTabWidget.addTab(self.tab_2, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.le_siteElevation = QtWidgets.QLineEdit(self.tab_4)
        self.le_siteElevation.setGeometry(QtCore.QRect(160, 110, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_siteElevation.setFont(font)
        self.le_siteElevation.setMouseTracking(False)
        self.le_siteElevation.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_siteElevation.setAcceptDrops(False)
        self.le_siteElevation.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_siteElevation.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_siteElevation.setReadOnly(True)
        self.le_siteElevation.setObjectName("le_siteElevation")
        self.label_5 = QtWidgets.QLabel(self.tab_4)
        self.label_5.setGeometry(QtCore.QRect(10, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.le_siteLongitude = QtWidgets.QLineEdit(self.tab_4)
        self.le_siteLongitude.setGeometry(QtCore.QRect(160, 50, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_siteLongitude.setFont(font)
        self.le_siteLongitude.setMouseTracking(False)
        self.le_siteLongitude.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_siteLongitude.setAcceptDrops(False)
        self.le_siteLongitude.setToolTip("")
        self.le_siteLongitude.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_siteLongitude.setMaxLength(32634)
        self.le_siteLongitude.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_siteLongitude.setReadOnly(True)
        self.le_siteLongitude.setCursorMoveStyle(QtCore.Qt.VisualMoveStyle)
        self.le_siteLongitude.setObjectName("le_siteLongitude")
        self.label_6 = QtWidgets.QLabel(self.tab_4)
        self.label_6.setGeometry(QtCore.QRect(10, 80, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.le_localSiderealTime = QtWidgets.QLineEdit(self.tab_4)
        self.le_localSiderealTime.setGeometry(QtCore.QRect(160, 140, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_localSiderealTime.setFont(font)
        self.le_localSiderealTime.setMouseTracking(False)
        self.le_localSiderealTime.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_localSiderealTime.setAcceptDrops(False)
        self.le_localSiderealTime.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_localSiderealTime.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_localSiderealTime.setReadOnly(True)
        self.le_localSiderealTime.setObjectName("le_localSiderealTime")
        self.label_7 = QtWidgets.QLabel(self.tab_4)
        self.label_7.setGeometry(QtCore.QRect(10, 140, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.le_siteLatitude = QtWidgets.QLineEdit(self.tab_4)
        self.le_siteLatitude.setGeometry(QtCore.QRect(160, 80, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_siteLatitude.setFont(font)
        self.le_siteLatitude.setMouseTracking(False)
        self.le_siteLatitude.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_siteLatitude.setAcceptDrops(False)
        self.le_siteLatitude.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_siteLatitude.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_siteLatitude.setReadOnly(True)
        self.le_siteLatitude.setObjectName("le_siteLatitude")
        self.label_12 = QtWidgets.QLabel(self.tab_4)
        self.label_12.setGeometry(QtCore.QRect(10, 110, 111, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_12.setFont(font)
        self.label_12.setObjectName("label_12")
        self.label_58 = QtWidgets.QLabel(self.tab_4)
        self.label_58.setGeometry(QtCore.QRect(10, 20, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_58.setFont(font)
        self.label_58.setObjectName("label_58")
        self.line_8 = QtWidgets.QFrame(self.tab_4)
        self.line_8.setGeometry(QtCore.QRect(10, 30, 301, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_8.setFont(font)
        self.line_8.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_8.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_8.setObjectName("line_8")
        self.label_16 = QtWidgets.QLabel(self.tab_4)
        self.label_16.setGeometry(QtCore.QRect(10, 240, 211, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_16.setFont(font)
        self.label_16.setObjectName("label_16")
        self.le_telescopeTempDECMotor = QtWidgets.QLineEdit(self.tab_4)
        self.le_telescopeTempDECMotor.setGeometry(QtCore.QRect(220, 240, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeTempDECMotor.setFont(font)
        self.le_telescopeTempDECMotor.setMouseTracking(False)
        self.le_telescopeTempDECMotor.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeTempDECMotor.setAcceptDrops(False)
        self.le_telescopeTempDECMotor.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeTempDECMotor.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeTempDECMotor.setReadOnly(True)
        self.le_telescopeTempDECMotor.setObjectName("le_telescopeTempDECMotor")
        self.label_55 = QtWidgets.QLabel(self.tab_4)
        self.label_55.setGeometry(QtCore.QRect(10, 210, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_55.setFont(font)
        self.label_55.setObjectName("label_55")
        self.line_5 = QtWidgets.QFrame(self.tab_4)
        self.line_5.setGeometry(QtCore.QRect(10, 220, 301, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_5.setFont(font)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setObjectName("line_5")
        self.label_64 = QtWidgets.QLabel(self.tab_4)
        self.label_64.setGeometry(QtCore.QRect(290, 240, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_64.setFont(font)
        self.label_64.setObjectName("label_64")
        self.line_7 = QtWidgets.QFrame(self.tab_4)
        self.line_7.setGeometry(QtCore.QRect(350, 30, 401, 21))
        self.line_7.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_7.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_7.setObjectName("line_7")
        self.le_windSpeed = QtWidgets.QLineEdit(self.tab_4)
        self.le_windSpeed.setGeometry(QtCore.QRect(650, 140, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_windSpeed.setFont(font)
        self.le_windSpeed.setMouseTracking(False)
        self.le_windSpeed.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_windSpeed.setAcceptDrops(False)
        self.le_windSpeed.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_windSpeed.setMaxLength(8)
        self.le_windSpeed.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_windSpeed.setReadOnly(True)
        self.le_windSpeed.setObjectName("le_windSpeed")
        self.label_32 = QtWidgets.QLabel(self.tab_4)
        self.label_32.setGeometry(QtCore.QRect(580, 140, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_32.setFont(font)
        self.label_32.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_32.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_32.setObjectName("label_32")
        self.label_73 = QtWidgets.QLabel(self.tab_4)
        self.label_73.setGeometry(QtCore.QRect(490, 80, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_73.setFont(font)
        self.label_73.setAlignment(QtCore.Qt.AlignCenter)
        self.label_73.setWordWrap(False)
        self.label_73.setObjectName("label_73")
        self.le_temperature = QtWidgets.QLineEdit(self.tab_4)
        self.le_temperature.setGeometry(QtCore.QRect(420, 50, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_temperature.setFont(font)
        self.le_temperature.setMouseTracking(False)
        self.le_temperature.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_temperature.setAcceptDrops(False)
        self.le_temperature.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_temperature.setMaxLength(8)
        self.le_temperature.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_temperature.setReadOnly(True)
        self.le_temperature.setObjectName("le_temperature")
        self.label_25 = QtWidgets.QLabel(self.tab_4)
        self.label_25.setGeometry(QtCore.QRect(350, 110, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_25.setFont(font)
        self.label_25.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_25.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_25.setObjectName("label_25")
        self.label_31 = QtWidgets.QLabel(self.tab_4)
        self.label_31.setGeometry(QtCore.QRect(350, 200, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_31.setFont(font)
        self.label_31.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_31.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_31.setObjectName("label_31")
        self.label_70 = QtWidgets.QLabel(self.tab_4)
        self.label_70.setGeometry(QtCore.QRect(490, 50, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_70.setFont(font)
        self.label_70.setAlignment(QtCore.Qt.AlignCenter)
        self.label_70.setWordWrap(False)
        self.label_70.setObjectName("label_70")
        self.label_68 = QtWidgets.QLabel(self.tab_4)
        self.label_68.setGeometry(QtCore.QRect(490, 200, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_68.setFont(font)
        self.label_68.setAlignment(QtCore.Qt.AlignCenter)
        self.label_68.setWordWrap(False)
        self.label_68.setObjectName("label_68")
        self.label_26 = QtWidgets.QLabel(self.tab_4)
        self.label_26.setGeometry(QtCore.QRect(350, 140, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_26.setFont(font)
        self.label_26.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_26.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_26.setObjectName("label_26")
        self.le_refractionTemperature = QtWidgets.QLineEdit(self.tab_4)
        self.le_refractionTemperature.setGeometry(QtCore.QRect(650, 50, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_refractionTemperature.setFont(font)
        self.le_refractionTemperature.setMouseTracking(False)
        self.le_refractionTemperature.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_refractionTemperature.setAcceptDrops(False)
        self.le_refractionTemperature.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_refractionTemperature.setMaxLength(8)
        self.le_refractionTemperature.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_refractionTemperature.setReadOnly(True)
        self.le_refractionTemperature.setObjectName("le_refractionTemperature")
        self.le_humidity = QtWidgets.QLineEdit(self.tab_4)
        self.le_humidity.setGeometry(QtCore.QRect(420, 140, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_humidity.setFont(font)
        self.le_humidity.setMouseTracking(False)
        self.le_humidity.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_humidity.setAcceptDrops(False)
        self.le_humidity.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_humidity.setMaxLength(8)
        self.le_humidity.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_humidity.setReadOnly(True)
        self.le_humidity.setObjectName("le_humidity")
        self.le_cloudCover = QtWidgets.QLineEdit(self.tab_4)
        self.le_cloudCover.setGeometry(QtCore.QRect(420, 170, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_cloudCover.setFont(font)
        self.le_cloudCover.setMouseTracking(False)
        self.le_cloudCover.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_cloudCover.setAcceptDrops(False)
        self.le_cloudCover.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_cloudCover.setMaxLength(8)
        self.le_cloudCover.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_cloudCover.setReadOnly(True)
        self.le_cloudCover.setObjectName("le_cloudCover")
        self.label_67 = QtWidgets.QLabel(self.tab_4)
        self.label_67.setGeometry(QtCore.QRect(720, 140, 41, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_67.setFont(font)
        self.label_67.setAlignment(QtCore.Qt.AlignCenter)
        self.label_67.setWordWrap(False)
        self.label_67.setObjectName("label_67")
        self.btn_setRefractionParameters = QtWidgets.QPushButton(self.tab_4)
        self.btn_setRefractionParameters.setGeometry(QtCore.QRect(350, 430, 401, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setRefractionParameters.setFont(font)
        self.btn_setRefractionParameters.setFlat(False)
        self.btn_setRefractionParameters.setObjectName("btn_setRefractionParameters")
        self.le_dewPoint = QtWidgets.QLineEdit(self.tab_4)
        self.le_dewPoint.setGeometry(QtCore.QRect(420, 110, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_dewPoint.setFont(font)
        self.le_dewPoint.setMouseTracking(False)
        self.le_dewPoint.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_dewPoint.setAcceptDrops(False)
        self.le_dewPoint.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_dewPoint.setMaxLength(8)
        self.le_dewPoint.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_dewPoint.setReadOnly(True)
        self.le_dewPoint.setObjectName("le_dewPoint")
        self.label_71 = QtWidgets.QLabel(self.tab_4)
        self.label_71.setGeometry(QtCore.QRect(490, 110, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_71.setFont(font)
        self.label_71.setAlignment(QtCore.Qt.AlignCenter)
        self.label_71.setWordWrap(False)
        self.label_71.setObjectName("label_71")
        self.le_windDirection = QtWidgets.QLineEdit(self.tab_4)
        self.le_windDirection.setGeometry(QtCore.QRect(650, 170, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_windDirection.setFont(font)
        self.le_windDirection.setMouseTracking(False)
        self.le_windDirection.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_windDirection.setAcceptDrops(False)
        self.le_windDirection.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_windDirection.setMaxLength(8)
        self.le_windDirection.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_windDirection.setReadOnly(True)
        self.le_windDirection.setObjectName("le_windDirection")
        self.label_33 = QtWidgets.QLabel(self.tab_4)
        self.label_33.setGeometry(QtCore.QRect(580, 170, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_33.setFont(font)
        self.label_33.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_33.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_33.setObjectName("label_33")
        self.label_30 = QtWidgets.QLabel(self.tab_4)
        self.label_30.setGeometry(QtCore.QRect(350, 170, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_30.setFont(font)
        self.label_30.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_30.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_30.setObjectName("label_30")
        self.label_24 = QtWidgets.QLabel(self.tab_4)
        self.label_24.setGeometry(QtCore.QRect(350, 50, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_24.setFont(font)
        self.label_24.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_24.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_24.setObjectName("label_24")
        self.label_22 = QtWidgets.QLabel(self.tab_4)
        self.label_22.setGeometry(QtCore.QRect(350, 280, 291, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_22.setFont(font)
        self.label_22.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_22.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_22.setObjectName("label_22")
        self.label_27 = QtWidgets.QLabel(self.tab_4)
        self.label_27.setGeometry(QtCore.QRect(350, 80, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_27.setFont(font)
        self.label_27.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_27.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_27.setObjectName("label_27")
        self.label_57 = QtWidgets.QLabel(self.tab_4)
        self.label_57.setGeometry(QtCore.QRect(350, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_57.setFont(font)
        self.label_57.setObjectName("label_57")
        self.line_10 = QtWidgets.QFrame(self.tab_4)
        self.line_10.setGeometry(QtCore.QRect(350, 260, 401, 21))
        self.line_10.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_10.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_10.setObjectName("line_10")
        self.le_refractionPressure = QtWidgets.QLineEdit(self.tab_4)
        self.le_refractionPressure.setGeometry(QtCore.QRect(650, 80, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_refractionPressure.setFont(font)
        self.le_refractionPressure.setMouseTracking(False)
        self.le_refractionPressure.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_refractionPressure.setAcceptDrops(False)
        self.le_refractionPressure.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_refractionPressure.setMaxLength(8)
        self.le_refractionPressure.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_refractionPressure.setReadOnly(True)
        self.le_refractionPressure.setObjectName("le_refractionPressure")
        self.le_rainRate = QtWidgets.QLineEdit(self.tab_4)
        self.le_rainRate.setGeometry(QtCore.QRect(420, 200, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_rainRate.setFont(font)
        self.le_rainRate.setMouseTracking(False)
        self.le_rainRate.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_rainRate.setAcceptDrops(False)
        self.le_rainRate.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_rainRate.setMaxLength(8)
        self.le_rainRate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_rainRate.setReadOnly(True)
        self.le_rainRate.setObjectName("le_rainRate")
        self.label_66 = QtWidgets.QLabel(self.tab_4)
        self.label_66.setGeometry(QtCore.QRect(720, 170, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_66.setFont(font)
        self.label_66.setAlignment(QtCore.Qt.AlignCenter)
        self.label_66.setWordWrap(False)
        self.label_66.setObjectName("label_66")
        self.le_pressure = QtWidgets.QLineEdit(self.tab_4)
        self.le_pressure.setGeometry(QtCore.QRect(420, 80, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_pressure.setFont(font)
        self.le_pressure.setMouseTracking(False)
        self.le_pressure.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_pressure.setAcceptDrops(False)
        self.le_pressure.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_pressure.setMaxLength(8)
        self.le_pressure.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_pressure.setReadOnly(True)
        self.le_pressure.setObjectName("le_pressure")
        self.le_refractionStatus = QtWidgets.QLineEdit(self.tab_4)
        self.le_refractionStatus.setGeometry(QtCore.QRect(650, 280, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_refractionStatus.setFont(font)
        self.le_refractionStatus.setMouseTracking(False)
        self.le_refractionStatus.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_refractionStatus.setAcceptDrops(False)
        self.le_refractionStatus.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_refractionStatus.setAlignment(QtCore.Qt.AlignCenter)
        self.le_refractionStatus.setReadOnly(True)
        self.le_refractionStatus.setObjectName("le_refractionStatus")
        self.label_13 = QtWidgets.QLabel(self.tab_4)
        self.label_13.setGeometry(QtCore.QRect(650, 20, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_13.setFont(font)
        self.label_13.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_13.setObjectName("label_13")
        self.label_72 = QtWidgets.QLabel(self.tab_4)
        self.label_72.setGeometry(QtCore.QRect(490, 140, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_72.setFont(font)
        self.label_72.setAlignment(QtCore.Qt.AlignCenter)
        self.label_72.setWordWrap(False)
        self.label_72.setObjectName("label_72")
        self.label_69 = QtWidgets.QLabel(self.tab_4)
        self.label_69.setGeometry(QtCore.QRect(490, 170, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_69.setFont(font)
        self.label_69.setAlignment(QtCore.Qt.AlignCenter)
        self.label_69.setWordWrap(False)
        self.label_69.setObjectName("label_69")
        self.label_78 = QtWidgets.QLabel(self.tab_4)
        self.label_78.setGeometry(QtCore.QRect(720, 80, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_78.setFont(font)
        self.label_78.setAlignment(QtCore.Qt.AlignCenter)
        self.label_78.setWordWrap(False)
        self.label_78.setObjectName("label_78")
        self.label_82 = QtWidgets.QLabel(self.tab_4)
        self.label_82.setGeometry(QtCore.QRect(280, 110, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_82.setFont(font)
        self.label_82.setAlignment(QtCore.Qt.AlignCenter)
        self.label_82.setWordWrap(False)
        self.label_82.setObjectName("label_82")
        self.checkAutoRefractionCamera = QtWidgets.QCheckBox(self.tab_4)
        self.checkAutoRefractionCamera.setGeometry(QtCore.QRect(390, 340, 161, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkAutoRefractionCamera.setFont(font)
        self.checkAutoRefractionCamera.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.checkAutoRefractionCamera.setChecked(False)
        self.checkAutoRefractionCamera.setObjectName("checkAutoRefractionCamera")
        self.label_86 = QtWidgets.QLabel(self.tab_4)
        self.label_86.setGeometry(QtCore.QRect(350, 250, 221, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_86.setFont(font)
        self.label_86.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_86.setObjectName("label_86")
        self.btn_setRefractionCorrection = QtWidgets.QPushButton(self.tab_4)
        self.btn_setRefractionCorrection.setGeometry(QtCore.QRect(720, 280, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setRefractionCorrection.setFont(font)
        self.btn_setRefractionCorrection.setObjectName("btn_setRefractionCorrection")
        self.label_105 = QtWidgets.QLabel(self.tab_4)
        self.label_105.setGeometry(QtCore.QRect(280, 80, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_105.setFont(font)
        self.label_105.setAlignment(QtCore.Qt.AlignCenter)
        self.label_105.setWordWrap(False)
        self.label_105.setObjectName("label_105")
        self.label_106 = QtWidgets.QLabel(self.tab_4)
        self.label_106.setGeometry(QtCore.QRect(280, 50, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_106.setFont(font)
        self.label_106.setAlignment(QtCore.Qt.AlignCenter)
        self.label_106.setWordWrap(False)
        self.label_106.setObjectName("label_106")
        self.label_79 = QtWidgets.QLabel(self.tab_4)
        self.label_79.setGeometry(QtCore.QRect(720, 50, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_79.setFont(font)
        self.label_79.setAlignment(QtCore.Qt.AlignCenter)
        self.label_79.setWordWrap(False)
        self.label_79.setObjectName("label_79")
        self.label_142 = QtWidgets.QLabel(self.tab_4)
        self.label_142.setGeometry(QtCore.QRect(580, 200, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_142.setFont(font)
        self.label_142.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_142.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_142.setObjectName("label_142")
        self.le_SQR = QtWidgets.QLineEdit(self.tab_4)
        self.le_SQR.setGeometry(QtCore.QRect(650, 200, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_SQR.setFont(font)
        self.le_SQR.setMouseTracking(False)
        self.le_SQR.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_SQR.setAcceptDrops(False)
        self.le_SQR.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_SQR.setMaxLength(8)
        self.le_SQR.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_SQR.setReadOnly(True)
        self.le_SQR.setObjectName("le_SQR")
        self.line_53 = QtWidgets.QFrame(self.tab_4)
        self.line_53.setGeometry(QtCore.QRect(320, 10, 21, 461))
        self.line_53.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_53.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_53.setObjectName("line_53")
        self.label_87 = QtWidgets.QLabel(self.tab_4)
        self.label_87.setGeometry(QtCore.QRect(720, 200, 41, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_87.setFont(font)
        self.label_87.setAlignment(QtCore.Qt.AlignCenter)
        self.label_87.setWordWrap(False)
        self.label_87.setObjectName("label_87")
        self.label_63 = QtWidgets.QLabel(self.tab_4)
        self.label_63.setGeometry(QtCore.QRect(10, 170, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_63.setFont(font)
        self.label_63.setObjectName("label_63")
        self.le_JulianDate = QtWidgets.QLineEdit(self.tab_4)
        self.le_JulianDate.setGeometry(QtCore.QRect(160, 170, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_JulianDate.setFont(font)
        self.le_JulianDate.setMouseTracking(False)
        self.le_JulianDate.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_JulianDate.setAcceptDrops(False)
        self.le_JulianDate.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_JulianDate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_JulianDate.setReadOnly(True)
        self.le_JulianDate.setObjectName("le_JulianDate")
        self.label_151 = QtWidgets.QLabel(self.tab_4)
        self.label_151.setGeometry(QtCore.QRect(10, 310, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_151.setFont(font)
        self.label_151.setObjectName("label_151")
        self.le_UTCDataExpirationDate = QtWidgets.QLineEdit(self.tab_4)
        self.le_UTCDataExpirationDate.setGeometry(QtCore.QRect(180, 340, 101, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_UTCDataExpirationDate.setFont(font)
        self.le_UTCDataExpirationDate.setMouseTracking(False)
        self.le_UTCDataExpirationDate.setAcceptDrops(False)
        self.le_UTCDataExpirationDate.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_UTCDataExpirationDate.setInputMask("")
        self.le_UTCDataExpirationDate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_UTCDataExpirationDate.setReadOnly(True)
        self.le_UTCDataExpirationDate.setObjectName("le_UTCDataExpirationDate")
        self.label_152 = QtWidgets.QLabel(self.tab_4)
        self.label_152.setGeometry(QtCore.QRect(80, 340, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_152.setFont(font)
        self.label_152.setObjectName("label_152")
        self.le_UTCDataValid = QtWidgets.QLineEdit(self.tab_4)
        self.le_UTCDataValid.setGeometry(QtCore.QRect(180, 310, 101, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_UTCDataValid.setFont(font)
        self.le_UTCDataValid.setMouseTracking(False)
        self.le_UTCDataValid.setAcceptDrops(False)
        self.le_UTCDataValid.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_UTCDataValid.setInputMask("")
        self.le_UTCDataValid.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_UTCDataValid.setReadOnly(True)
        self.le_UTCDataValid.setObjectName("le_UTCDataValid")
        self.line_76 = QtWidgets.QFrame(self.tab_4)
        self.line_76.setGeometry(QtCore.QRect(10, 290, 301, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_76.setFont(font)
        self.line_76.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_76.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_76.setObjectName("line_76")
        self.label_74 = QtWidgets.QLabel(self.tab_4)
        self.label_74.setGeometry(QtCore.QRect(10, 280, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_74.setFont(font)
        self.label_74.setObjectName("label_74")
        self.checkAutoRefractionNotTracking = QtWidgets.QCheckBox(self.tab_4)
        self.checkAutoRefractionNotTracking.setGeometry(QtCore.QRect(390, 370, 171, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkAutoRefractionNotTracking.setFont(font)
        self.checkAutoRefractionNotTracking.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.checkAutoRefractionNotTracking.setChecked(True)
        self.checkAutoRefractionNotTracking.setObjectName("checkAutoRefractionNotTracking")
        self.label_135 = QtWidgets.QLabel(self.tab_4)
        self.label_135.setGeometry(QtCore.QRect(350, 310, 221, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_135.setFont(font)
        self.label_135.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_135.setObjectName("label_135")
        self.line_77 = QtWidgets.QFrame(self.tab_4)
        self.line_77.setGeometry(QtCore.QRect(350, 320, 401, 21))
        self.line_77.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_77.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_77.setObjectName("line_77")
        self.mainTabWidget.addTab(self.tab_4, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.btn_runBaseModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runBaseModel.setGeometry(QtCore.QRect(10, 400, 131, 31))
        self.btn_runBaseModel.setObjectName("btn_runBaseModel")
        self.checkUseBlindSolve = QtWidgets.QCheckBox(self.tab_6)
        self.checkUseBlindSolve.setGeometry(QtCore.QRect(10, 220, 131, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkUseBlindSolve.setFont(font)
        self.checkUseBlindSolve.setObjectName("checkUseBlindSolve")
        self.btn_clearAlignmentModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_clearAlignmentModel.setGeometry(QtCore.QRect(490, 320, 251, 31))
        self.btn_clearAlignmentModel.setObjectName("btn_clearAlignmentModel")
        self.btn_loadBasePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_loadBasePoints.setGeometry(QtCore.QRect(10, 50, 131, 31))
        self.btn_loadBasePoints.setObjectName("btn_loadBasePoints")
        self.line_24 = QtWidgets.QFrame(self.tab_6)
        self.line_24.setGeometry(QtCore.QRect(10, 190, 131, 21))
        self.line_24.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_24.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_24.setObjectName("line_24")
        self.btn_generateBasePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateBasePoints.setGeometry(QtCore.QRect(10, 100, 131, 31))
        self.btn_generateBasePoints.setObjectName("btn_generateBasePoints")
        self.azimuthBase = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.azimuthBase.setGeometry(QtCore.QRect(70, 170, 51, 22))
        self.azimuthBase.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthBase.setDecimals(0)
        self.azimuthBase.setMaximum(120.0)
        self.azimuthBase.setSingleStep(1.0)
        self.azimuthBase.setProperty("value", 120.0)
        self.azimuthBase.setObjectName("azimuthBase")
        self.altitudeBase = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.altitudeBase.setGeometry(QtCore.QRect(70, 140, 51, 22))
        self.altitudeBase.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeBase.setDecimals(0)
        self.altitudeBase.setMinimum(20.0)
        self.altitudeBase.setMaximum(70.0)
        self.altitudeBase.setSingleStep(1.0)
        self.altitudeBase.setProperty("value", 70.0)
        self.altitudeBase.setObjectName("altitudeBase")
        self.label_170 = QtWidgets.QLabel(self.tab_6)
        self.label_170.setGeometry(QtCore.QRect(10, 140, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_170.setFont(font)
        self.label_170.setObjectName("label_170")
        self.label_171 = QtWidgets.QLabel(self.tab_6)
        self.label_171.setGeometry(QtCore.QRect(10, 170, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_171.setFont(font)
        self.label_171.setObjectName("label_171")
        self.label_109 = QtWidgets.QLabel(self.tab_6)
        self.label_109.setGeometry(QtCore.QRect(120, 140, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_109.setFont(font)
        self.label_109.setAlignment(QtCore.Qt.AlignCenter)
        self.label_109.setWordWrap(False)
        self.label_109.setObjectName("label_109")
        self.label_110 = QtWidgets.QLabel(self.tab_6)
        self.label_110.setGeometry(QtCore.QRect(120, 170, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_110.setFont(font)
        self.label_110.setAlignment(QtCore.Qt.AlignCenter)
        self.label_110.setWordWrap(False)
        self.label_110.setObjectName("label_110")
        self.label_116 = QtWidgets.QLabel(self.tab_6)
        self.label_116.setGeometry(QtCore.QRect(10, 20, 131, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_116.setFont(font)
        self.label_116.setObjectName("label_116")
        self.line_35 = QtWidgets.QFrame(self.tab_6)
        self.line_35.setGeometry(QtCore.QRect(10, 30, 131, 21))
        self.line_35.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_35.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_35.setObjectName("line_35")
        self.line_36 = QtWidgets.QFrame(self.tab_6)
        self.line_36.setGeometry(QtCore.QRect(10, 240, 131, 21))
        self.line_36.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_36.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_36.setObjectName("line_36")
        self.btn_openModelingPlotWindow = QtWidgets.QPushButton(self.tab_6)
        self.btn_openModelingPlotWindow.setGeometry(QtCore.QRect(490, 50, 251, 31))
        self.btn_openModelingPlotWindow.setStyleSheet("background-color: rgb(16, 72, 96);\n"
"color: rgb(255,255,255);")
        self.btn_openModelingPlotWindow.setObjectName("btn_openModelingPlotWindow")
        self.btn_generateGridPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateGridPoints.setGeometry(QtCore.QRect(180, 100, 131, 31))
        self.btn_generateGridPoints.setObjectName("btn_generateGridPoints")
        self.label_108 = QtWidgets.QLabel(self.tab_6)
        self.label_108.setGeometry(QtCore.QRect(180, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_108.setFont(font)
        self.label_108.setObjectName("label_108")
        self.label_179 = QtWidgets.QLabel(self.tab_6)
        self.label_179.setGeometry(QtCore.QRect(340, 140, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_179.setFont(font)
        self.label_179.setObjectName("label_179")
        self.label_178 = QtWidgets.QLabel(self.tab_6)
        self.label_178.setGeometry(QtCore.QRect(180, 140, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_178.setFont(font)
        self.label_178.setObjectName("label_178")
        self.btn_generateNormalPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateNormalPoints.setGeometry(QtCore.QRect(320, 210, 131, 31))
        self.btn_generateNormalPoints.setObjectName("btn_generateNormalPoints")
        self.btn_generateDensePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateDensePoints.setGeometry(QtCore.QRect(180, 210, 131, 31))
        self.btn_generateDensePoints.setObjectName("btn_generateDensePoints")
        self.numberGridPointsRow = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberGridPointsRow.setGeometry(QtCore.QRect(260, 140, 51, 21))
        self.numberGridPointsRow.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberGridPointsRow.setDecimals(0)
        self.numberGridPointsRow.setMinimum(3.0)
        self.numberGridPointsRow.setMaximum(10.0)
        self.numberGridPointsRow.setSingleStep(1.0)
        self.numberGridPointsRow.setProperty("value", 5.0)
        self.numberGridPointsRow.setObjectName("numberGridPointsRow")
        self.line_34 = QtWidgets.QFrame(self.tab_6)
        self.line_34.setGeometry(QtCore.QRect(180, 30, 271, 21))
        self.line_34.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_34.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_34.setObjectName("line_34")
        self.numberGridPointsCol = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberGridPointsCol.setGeometry(QtCore.QRect(400, 140, 51, 21))
        self.numberGridPointsCol.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberGridPointsCol.setDecimals(0)
        self.numberGridPointsCol.setMinimum(5.0)
        self.numberGridPointsCol.setMaximum(15.0)
        self.numberGridPointsCol.setSingleStep(1.0)
        self.numberGridPointsCol.setProperty("value", 10.0)
        self.numberGridPointsCol.setObjectName("numberGridPointsCol")
        self.btn_runRefinementModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runRefinementModel.setGeometry(QtCore.QRect(180, 400, 271, 31))
        self.btn_runRefinementModel.setObjectName("btn_runRefinementModel")
        self.line_26 = QtWidgets.QFrame(self.tab_6)
        self.line_26.setGeometry(QtCore.QRect(180, 240, 271, 21))
        self.line_26.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_26.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_26.setObjectName("line_26")
        self.btn_loadRefinementPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_loadRefinementPoints.setGeometry(QtCore.QRect(180, 50, 271, 31))
        self.btn_loadRefinementPoints.setObjectName("btn_loadRefinementPoints")
        self.btn_cancelModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_cancelModel.setGeometry(QtCore.QRect(490, 440, 251, 31))
        self.btn_cancelModel.setStyleSheet("")
        self.btn_cancelModel.setObjectName("btn_cancelModel")
        self.btn_runCheckModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runCheckModel.setGeometry(QtCore.QRect(490, 390, 251, 31))
        self.btn_runCheckModel.setObjectName("btn_runCheckModel")
        self.label_98 = QtWidgets.QLabel(self.tab_6)
        self.label_98.setGeometry(QtCore.QRect(490, 360, 251, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_98.setFont(font)
        self.label_98.setObjectName("label_98")
        self.line_32 = QtWidgets.QFrame(self.tab_6)
        self.line_32.setGeometry(QtCore.QRect(490, 370, 251, 21))
        self.line_32.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_32.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_32.setObjectName("line_32")
        self.line_27 = QtWidgets.QFrame(self.tab_6)
        self.line_27.setGeometry(QtCore.QRect(10, 80, 131, 21))
        self.line_27.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_27.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_27.setObjectName("line_27")
        self.line_28 = QtWidgets.QFrame(self.tab_6)
        self.line_28.setGeometry(QtCore.QRect(180, 80, 271, 21))
        self.line_28.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_28.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_28.setObjectName("line_28")
        self.btn_generateDSOPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateDSOPoints.setGeometry(QtCore.QRect(180, 260, 131, 31))
        self.btn_generateDSOPoints.setObjectName("btn_generateDSOPoints")
        self.line_39 = QtWidgets.QFrame(self.tab_6)
        self.line_39.setGeometry(QtCore.QRect(150, 10, 21, 421))
        self.line_39.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_39.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_39.setObjectName("line_39")
        self.line_40 = QtWidgets.QFrame(self.tab_6)
        self.line_40.setGeometry(QtCore.QRect(460, 10, 21, 461))
        self.line_40.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_40.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_40.setObjectName("line_40")
        self.label_113 = QtWidgets.QLabel(self.tab_6)
        self.label_113.setGeometry(QtCore.QRect(490, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_113.setFont(font)
        self.label_113.setObjectName("label_113")
        self.line_41 = QtWidgets.QFrame(self.tab_6)
        self.line_41.setGeometry(QtCore.QRect(490, 30, 251, 21))
        self.line_41.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_41.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_41.setObjectName("line_41")
        self.line_42 = QtWidgets.QFrame(self.tab_6)
        self.line_42.setGeometry(QtCore.QRect(180, 190, 271, 21))
        self.line_42.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_42.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_42.setObjectName("line_42")
        self.btn_deletePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_deletePoints.setGeometry(QtCore.QRect(490, 130, 251, 31))
        self.btn_deletePoints.setObjectName("btn_deletePoints")
        self.btn_runAllModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runAllModel.setGeometry(QtCore.QRect(10, 440, 441, 31))
        self.btn_runAllModel.setObjectName("btn_runAllModel")
        self.numberHoursDSO = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberHoursDSO.setGeometry(QtCore.QRect(260, 300, 51, 21))
        self.numberHoursDSO.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberHoursDSO.setDecimals(0)
        self.numberHoursDSO.setMinimum(1.0)
        self.numberHoursDSO.setMaximum(15.0)
        self.numberHoursDSO.setSingleStep(1.0)
        self.numberHoursDSO.setProperty("value", 10.0)
        self.numberHoursDSO.setObjectName("numberHoursDSO")
        self.label_181 = QtWidgets.QLabel(self.tab_6)
        self.label_181.setGeometry(QtCore.QRect(190, 300, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_181.setFont(font)
        self.label_181.setObjectName("label_181")
        self.label_188 = QtWidgets.QLabel(self.tab_6)
        self.label_188.setGeometry(QtCore.QRect(190, 330, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_188.setFont(font)
        self.label_188.setObjectName("label_188")
        self.numberPointsDSO = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberPointsDSO.setGeometry(QtCore.QRect(260, 330, 51, 21))
        self.numberPointsDSO.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberPointsDSO.setDecimals(0)
        self.numberPointsDSO.setMinimum(5.0)
        self.numberPointsDSO.setMaximum(50.0)
        self.numberPointsDSO.setSingleStep(1.0)
        self.numberPointsDSO.setProperty("value", 10.0)
        self.numberPointsDSO.setObjectName("numberPointsDSO")
        self.label_189 = QtWidgets.QLabel(self.tab_6)
        self.label_189.setGeometry(QtCore.QRect(330, 300, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_189.setFont(font)
        self.label_189.setObjectName("label_189")
        self.numberHoursPreview = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberHoursPreview.setGeometry(QtCore.QRect(410, 300, 41, 21))
        self.numberHoursPreview.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberHoursPreview.setDecimals(0)
        self.numberHoursPreview.setMinimum(-12.0)
        self.numberHoursPreview.setMaximum(12.0)
        self.numberHoursPreview.setSingleStep(1.0)
        self.numberHoursPreview.setProperty("value", 0.0)
        self.numberHoursPreview.setObjectName("numberHoursPreview")
        self.btn_plateSolveSync = QtWidgets.QPushButton(self.tab_6)
        self.btn_plateSolveSync.setGeometry(QtCore.QRect(490, 180, 251, 31))
        self.btn_plateSolveSync.setObjectName("btn_plateSolveSync")
        self.checkClearModelFirst = QtWidgets.QCheckBox(self.tab_6)
        self.checkClearModelFirst.setGeometry(QtCore.QRect(20, 370, 121, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkClearModelFirst.setFont(font)
        self.checkClearModelFirst.setChecked(True)
        self.checkClearModelFirst.setObjectName("checkClearModelFirst")
        self.checkKeepRefinement = QtWidgets.QCheckBox(self.tab_6)
        self.checkKeepRefinement.setGeometry(QtCore.QRect(190, 370, 261, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkKeepRefinement.setFont(font)
        self.checkKeepRefinement.setObjectName("checkKeepRefinement")
        self.line_30 = QtWidgets.QFrame(self.tab_6)
        self.line_30.setGeometry(QtCore.QRect(490, 160, 251, 21))
        self.line_30.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_30.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_30.setObjectName("line_30")
        self.line_38 = QtWidgets.QFrame(self.tab_6)
        self.line_38.setGeometry(QtCore.QRect(490, 300, 251, 21))
        self.line_38.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_38.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_38.setObjectName("line_38")
        self.label_180 = QtWidgets.QLabel(self.tab_6)
        self.label_180.setGeometry(QtCore.QRect(340, 170, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_180.setFont(font)
        self.label_180.setObjectName("label_180")
        self.altitudeMax = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.altitudeMax.setGeometry(QtCore.QRect(400, 170, 51, 21))
        self.altitudeMax.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeMax.setDecimals(0)
        self.altitudeMax.setMinimum(50.0)
        self.altitudeMax.setMaximum(90.0)
        self.altitudeMax.setSingleStep(5.0)
        self.altitudeMax.setProperty("value", 80.0)
        self.altitudeMax.setObjectName("altitudeMax")
        self.altitudeMin = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.altitudeMin.setGeometry(QtCore.QRect(260, 170, 51, 21))
        self.altitudeMin.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeMin.setDecimals(0)
        self.altitudeMin.setMinimum(20.0)
        self.altitudeMin.setMaximum(45.0)
        self.altitudeMin.setSingleStep(5.0)
        self.altitudeMin.setProperty("value", 30.0)
        self.altitudeMin.setObjectName("altitudeMin")
        self.label_190 = QtWidgets.QLabel(self.tab_6)
        self.label_190.setGeometry(QtCore.QRect(180, 170, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_190.setFont(font)
        self.label_190.setObjectName("label_190")
        self.line_45 = QtWidgets.QFrame(self.tab_6)
        self.line_45.setGeometry(QtCore.QRect(490, 210, 251, 21))
        self.line_45.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_45.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_45.setObjectName("line_45")
        self.btn_openImageWindow = QtWidgets.QPushButton(self.tab_6)
        self.btn_openImageWindow.setGeometry(QtCore.QRect(490, 90, 251, 31))
        self.btn_openImageWindow.setStyleSheet("background-color: rgb(16, 72, 96);\n"
"color: rgb(255,255,255);")
        self.btn_openImageWindow.setObjectName("btn_openImageWindow")
        self.checkDeletePointsHorizonMask = QtWidgets.QCheckBox(self.tab_6)
        self.checkDeletePointsHorizonMask.setGeometry(QtCore.QRect(500, 230, 241, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkDeletePointsHorizonMask.setFont(font)
        self.checkDeletePointsHorizonMask.setObjectName("checkDeletePointsHorizonMask")
        self.checkSortPoints = QtWidgets.QCheckBox(self.tab_6)
        self.checkSortPoints.setGeometry(QtCore.QRect(500, 250, 241, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkSortPoints.setFont(font)
        self.checkSortPoints.setObjectName("checkSortPoints")
        self.checkSimulation = QtWidgets.QCheckBox(self.tab_6)
        self.checkSimulation.setGeometry(QtCore.QRect(500, 280, 241, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkSimulation.setFont(font)
        self.checkSimulation.setObjectName("checkSimulation")
        self.mainTabWidget.addTab(self.tab_6, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.le_alignNumberStars = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignNumberStars.setGeometry(QtCore.QRect(570, 50, 31, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignNumberStars.setFont(font)
        self.le_alignNumberStars.setMouseTracking(False)
        self.le_alignNumberStars.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignNumberStars.setAcceptDrops(False)
        self.le_alignNumberStars.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignNumberStars.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignNumberStars.setReadOnly(True)
        self.le_alignNumberStars.setObjectName("le_alignNumberStars")
        self.label = QtWidgets.QLabel(self.tab_8)
        self.label.setGeometry(QtCore.QRect(460, 50, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.le_alignErrorRMS = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignErrorRMS.setGeometry(QtCore.QRect(550, 80, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignErrorRMS.setFont(font)
        self.le_alignErrorRMS.setMouseTracking(False)
        self.le_alignErrorRMS.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignErrorRMS.setAcceptDrops(False)
        self.le_alignErrorRMS.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignErrorRMS.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignErrorRMS.setReadOnly(True)
        self.le_alignErrorRMS.setObjectName("le_alignErrorRMS")
        self.alignErrorStars = QtWidgets.QTextBrowser(self.tab_8)
        self.alignErrorStars.setGeometry(QtCore.QRect(10, 120, 411, 351))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(8)
        self.alignErrorStars.setFont(font)
        self.alignErrorStars.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.alignErrorStars.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.alignErrorStars.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.alignErrorStars.setObjectName("alignErrorStars")
        self.label_14 = QtWidgets.QLabel(self.tab_8)
        self.label_14.setGeometry(QtCore.QRect(460, 80, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_14.setFont(font)
        self.label_14.setObjectName("label_14")
        self.btn_showActualModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_showActualModel.setGeometry(QtCore.QRect(10, 50, 131, 31))
        self.btn_showActualModel.setObjectName("btn_showActualModel")
        self.label_37 = QtWidgets.QLabel(self.tab_8)
        self.label_37.setGeometry(QtCore.QRect(150, 90, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_37.setFont(font)
        self.label_37.setObjectName("label_37")
        self.btn_runTargetRMSAlignment = QtWidgets.QPushButton(self.tab_8)
        self.btn_runTargetRMSAlignment.setGeometry(QtCore.QRect(150, 50, 131, 31))
        self.btn_runTargetRMSAlignment.setObjectName("btn_runTargetRMSAlignment")
        self.targetRMS = QtWidgets.QDoubleSpinBox(self.tab_8)
        self.targetRMS.setGeometry(QtCore.QRect(230, 90, 51, 22))
        self.targetRMS.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.targetRMS.setDecimals(1)
        self.targetRMS.setMaximum(30.0)
        self.targetRMS.setSingleStep(0.1)
        self.targetRMS.setObjectName("targetRMS")
        self.btn_saveBackupModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveBackupModel.setGeometry(QtCore.QRect(460, 240, 81, 31))
        self.btn_saveBackupModel.setObjectName("btn_saveBackupModel")
        self.btn_loadBackupModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadBackupModel.setGeometry(QtCore.QRect(670, 240, 81, 31))
        self.btn_loadBackupModel.setObjectName("btn_loadBackupModel")
        self.line_18 = QtWidgets.QFrame(self.tab_8)
        self.line_18.setGeometry(QtCore.QRect(460, 220, 291, 21))
        self.line_18.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_18.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_18.setObjectName("line_18")
        self.btn_loadSimpleModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadSimpleModel.setGeometry(QtCore.QRect(670, 360, 81, 31))
        self.btn_loadSimpleModel.setObjectName("btn_loadSimpleModel")
        self.btn_saveSimpleModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveSimpleModel.setGeometry(QtCore.QRect(460, 360, 81, 31))
        self.btn_saveSimpleModel.setObjectName("btn_saveSimpleModel")
        self.btn_deleteWorstPoint = QtWidgets.QPushButton(self.tab_8)
        self.btn_deleteWorstPoint.setGeometry(QtCore.QRect(290, 50, 131, 31))
        self.btn_deleteWorstPoint.setObjectName("btn_deleteWorstPoint")
        self.line_44 = QtWidgets.QFrame(self.tab_8)
        self.line_44.setGeometry(QtCore.QRect(10, 30, 411, 21))
        self.line_44.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_44.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_44.setObjectName("line_44")
        self.label_124 = QtWidgets.QLabel(self.tab_8)
        self.label_124.setGeometry(QtCore.QRect(10, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_124.setFont(font)
        self.label_124.setObjectName("label_124")
        self.label_125 = QtWidgets.QLabel(self.tab_8)
        self.label_125.setGeometry(QtCore.QRect(460, 210, 241, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_125.setFont(font)
        self.label_125.setObjectName("label_125")
        self.btn_loadBaseModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadBaseModel.setGeometry(QtCore.QRect(670, 280, 81, 31))
        self.btn_loadBaseModel.setObjectName("btn_loadBaseModel")
        self.btn_saveBaseModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveBaseModel.setGeometry(QtCore.QRect(460, 280, 81, 31))
        self.btn_saveBaseModel.setObjectName("btn_saveBaseModel")
        self.label_126 = QtWidgets.QLabel(self.tab_8)
        self.label_126.setGeometry(QtCore.QRect(550, 240, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_126.setFont(font)
        self.label_126.setAlignment(QtCore.Qt.AlignCenter)
        self.label_126.setObjectName("label_126")
        self.label_127 = QtWidgets.QLabel(self.tab_8)
        self.label_127.setGeometry(QtCore.QRect(550, 280, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_127.setFont(font)
        self.label_127.setAlignment(QtCore.Qt.AlignCenter)
        self.label_127.setObjectName("label_127")
        self.label_128 = QtWidgets.QLabel(self.tab_8)
        self.label_128.setGeometry(QtCore.QRect(550, 360, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_128.setFont(font)
        self.label_128.setAlignment(QtCore.Qt.AlignCenter)
        self.label_128.setObjectName("label_128")
        self.btn_saveDSO1Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveDSO1Model.setGeometry(QtCore.QRect(460, 400, 81, 31))
        self.btn_saveDSO1Model.setObjectName("btn_saveDSO1Model")
        self.btn_loadDSO1Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadDSO1Model.setGeometry(QtCore.QRect(670, 400, 81, 31))
        self.btn_loadDSO1Model.setObjectName("btn_loadDSO1Model")
        self.btn_saveDSO2Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveDSO2Model.setGeometry(QtCore.QRect(460, 440, 81, 31))
        self.btn_saveDSO2Model.setObjectName("btn_saveDSO2Model")
        self.btn_loadDSO2Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadDSO2Model.setGeometry(QtCore.QRect(670, 440, 81, 31))
        self.btn_loadDSO2Model.setObjectName("btn_loadDSO2Model")
        self.label_129 = QtWidgets.QLabel(self.tab_8)
        self.label_129.setGeometry(QtCore.QRect(550, 400, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_129.setFont(font)
        self.label_129.setAlignment(QtCore.Qt.AlignCenter)
        self.label_129.setObjectName("label_129")
        self.label_130 = QtWidgets.QLabel(self.tab_8)
        self.label_130.setGeometry(QtCore.QRect(550, 440, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_130.setFont(font)
        self.label_130.setAlignment(QtCore.Qt.AlignCenter)
        self.label_130.setObjectName("label_130")
        self.btn_saveRefinementModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveRefinementModel.setGeometry(QtCore.QRect(460, 320, 81, 31))
        self.btn_saveRefinementModel.setObjectName("btn_saveRefinementModel")
        self.label_133 = QtWidgets.QLabel(self.tab_8)
        self.label_133.setGeometry(QtCore.QRect(550, 320, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_133.setFont(font)
        self.label_133.setAlignment(QtCore.Qt.AlignCenter)
        self.label_133.setObjectName("label_133")
        self.btn_loadRefinementModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadRefinementModel.setGeometry(QtCore.QRect(670, 320, 81, 31))
        self.btn_loadRefinementModel.setObjectName("btn_loadRefinementModel")
        self.line_46 = QtWidgets.QFrame(self.tab_8)
        self.line_46.setGeometry(QtCore.QRect(430, 10, 21, 461))
        self.line_46.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_46.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_46.setObjectName("line_46")
        self.model = QtWidgets.QWidget(self.tab_8)
        self.model.setEnabled(True)
        self.model.setGeometry(QtCore.QRect(10, 120, 411, 351))
        self.model.setAutoFillBackground(True)
        self.model.setObjectName("model")
        self.checkPolarPlot = QtWidgets.QCheckBox(self.tab_8)
        self.checkPolarPlot.setGeometry(QtCore.QRect(20, 90, 101, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkPolarPlot.setFont(font)
        self.checkPolarPlot.setObjectName("checkPolarPlot")
        self.le_alignErrorPolar = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignErrorPolar.setGeometry(QtCore.QRect(520, 110, 81, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignErrorPolar.setFont(font)
        self.le_alignErrorPolar.setMouseTracking(False)
        self.le_alignErrorPolar.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignErrorPolar.setAcceptDrops(False)
        self.le_alignErrorPolar.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignErrorPolar.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignErrorPolar.setReadOnly(True)
        self.le_alignErrorPolar.setObjectName("le_alignErrorPolar")
        self.label_15 = QtWidgets.QLabel(self.tab_8)
        self.label_15.setGeometry(QtCore.QRect(460, 110, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_15.setFont(font)
        self.label_15.setObjectName("label_15")
        self.label_153 = QtWidgets.QLabel(self.tab_8)
        self.label_153.setGeometry(QtCore.QRect(620, 110, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_153.setFont(font)
        self.label_153.setObjectName("label_153")
        self.le_alignErrorOrtho = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignErrorOrtho.setGeometry(QtCore.QRect(670, 110, 81, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignErrorOrtho.setFont(font)
        self.le_alignErrorOrtho.setMouseTracking(False)
        self.le_alignErrorOrtho.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignErrorOrtho.setAcceptDrops(False)
        self.le_alignErrorOrtho.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignErrorOrtho.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignErrorOrtho.setReadOnly(True)
        self.le_alignErrorOrtho.setObjectName("le_alignErrorOrtho")
        self.label_154 = QtWidgets.QLabel(self.tab_8)
        self.label_154.setGeometry(QtCore.QRect(620, 50, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_154.setFont(font)
        self.label_154.setObjectName("label_154")
        self.le_alignNumberTerms = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignNumberTerms.setGeometry(QtCore.QRect(720, 50, 31, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignNumberTerms.setFont(font)
        self.le_alignNumberTerms.setMouseTracking(False)
        self.le_alignNumberTerms.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignNumberTerms.setAcceptDrops(False)
        self.le_alignNumberTerms.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignNumberTerms.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignNumberTerms.setReadOnly(True)
        self.le_alignNumberTerms.setObjectName("le_alignNumberTerms")
        self.line_54 = QtWidgets.QFrame(self.tab_8)
        self.line_54.setGeometry(QtCore.QRect(460, 30, 291, 21))
        self.line_54.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_54.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_54.setObjectName("line_54")
        self.label_155 = QtWidgets.QLabel(self.tab_8)
        self.label_155.setGeometry(QtCore.QRect(460, 20, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_155.setFont(font)
        self.label_155.setObjectName("label_155")
        self.label_156 = QtWidgets.QLabel(self.tab_8)
        self.label_156.setGeometry(QtCore.QRect(460, 170, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_156.setFont(font)
        self.label_156.setObjectName("label_156")
        self.le_alignKnobTurnAz = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignKnobTurnAz.setGeometry(QtCore.QRect(510, 170, 91, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignKnobTurnAz.setFont(font)
        self.le_alignKnobTurnAz.setMouseTracking(False)
        self.le_alignKnobTurnAz.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignKnobTurnAz.setAcceptDrops(False)
        self.le_alignKnobTurnAz.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignKnobTurnAz.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignKnobTurnAz.setReadOnly(True)
        self.le_alignKnobTurnAz.setObjectName("le_alignKnobTurnAz")
        self.label_157 = QtWidgets.QLabel(self.tab_8)
        self.label_157.setGeometry(QtCore.QRect(610, 170, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_157.setFont(font)
        self.label_157.setObjectName("label_157")
        self.le_alignKnobTurnAlt = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignKnobTurnAlt.setGeometry(QtCore.QRect(660, 170, 91, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignKnobTurnAlt.setFont(font)
        self.le_alignKnobTurnAlt.setMouseTracking(False)
        self.le_alignKnobTurnAlt.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignKnobTurnAlt.setAcceptDrops(False)
        self.le_alignKnobTurnAlt.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignKnobTurnAlt.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignKnobTurnAlt.setReadOnly(True)
        self.le_alignKnobTurnAlt.setObjectName("le_alignKnobTurnAlt")
        self.label_158 = QtWidgets.QLabel(self.tab_8)
        self.label_158.setGeometry(QtCore.QRect(460, 140, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_158.setFont(font)
        self.label_158.setObjectName("label_158")
        self.label_159 = QtWidgets.QLabel(self.tab_8)
        self.label_159.setGeometry(QtCore.QRect(620, 140, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_159.setFont(font)
        self.label_159.setObjectName("label_159")
        self.le_alignErrorAz = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignErrorAz.setGeometry(QtCore.QRect(520, 140, 81, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignErrorAz.setFont(font)
        self.le_alignErrorAz.setMouseTracking(False)
        self.le_alignErrorAz.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignErrorAz.setAcceptDrops(False)
        self.le_alignErrorAz.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignErrorAz.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignErrorAz.setReadOnly(True)
        self.le_alignErrorAz.setObjectName("le_alignErrorAz")
        self.le_alignErrorAlt = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignErrorAlt.setGeometry(QtCore.QRect(670, 140, 81, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignErrorAlt.setFont(font)
        self.le_alignErrorAlt.setMouseTracking(False)
        self.le_alignErrorAlt.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignErrorAlt.setAcceptDrops(False)
        self.le_alignErrorAlt.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignErrorAlt.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignErrorAlt.setReadOnly(True)
        self.le_alignErrorAlt.setObjectName("le_alignErrorAlt")
        self.le_alignErrorPosAngle = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignErrorPosAngle.setGeometry(QtCore.QRect(700, 80, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignErrorPosAngle.setFont(font)
        self.le_alignErrorPosAngle.setMouseTracking(False)
        self.le_alignErrorPosAngle.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignErrorPosAngle.setAcceptDrops(False)
        self.le_alignErrorPosAngle.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignErrorPosAngle.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignErrorPosAngle.setReadOnly(True)
        self.le_alignErrorPosAngle.setObjectName("le_alignErrorPosAngle")
        self.label_160 = QtWidgets.QLabel(self.tab_8)
        self.label_160.setGeometry(QtCore.QRect(620, 80, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_160.setFont(font)
        self.label_160.setObjectName("label_160")
        self.le_alignNumberStars.raise_()
        self.label.raise_()
        self.le_alignErrorRMS.raise_()
        self.label_14.raise_()
        self.btn_showActualModel.raise_()
        self.label_37.raise_()
        self.btn_runTargetRMSAlignment.raise_()
        self.targetRMS.raise_()
        self.btn_saveBackupModel.raise_()
        self.btn_loadBackupModel.raise_()
        self.line_18.raise_()
        self.btn_loadSimpleModel.raise_()
        self.btn_saveSimpleModel.raise_()
        self.btn_deleteWorstPoint.raise_()
        self.line_44.raise_()
        self.label_124.raise_()
        self.label_125.raise_()
        self.btn_loadBaseModel.raise_()
        self.btn_saveBaseModel.raise_()
        self.label_126.raise_()
        self.label_127.raise_()
        self.label_128.raise_()
        self.btn_saveDSO1Model.raise_()
        self.btn_loadDSO1Model.raise_()
        self.btn_saveDSO2Model.raise_()
        self.btn_loadDSO2Model.raise_()
        self.label_129.raise_()
        self.label_130.raise_()
        self.btn_saveRefinementModel.raise_()
        self.label_133.raise_()
        self.btn_loadRefinementModel.raise_()
        self.line_46.raise_()
        self.model.raise_()
        self.alignErrorStars.raise_()
        self.checkPolarPlot.raise_()
        self.le_alignErrorPolar.raise_()
        self.label_15.raise_()
        self.label_153.raise_()
        self.le_alignErrorOrtho.raise_()
        self.label_154.raise_()
        self.le_alignNumberTerms.raise_()
        self.line_54.raise_()
        self.label_155.raise_()
        self.label_156.raise_()
        self.le_alignKnobTurnAz.raise_()
        self.label_157.raise_()
        self.le_alignKnobTurnAlt.raise_()
        self.label_158.raise_()
        self.label_159.raise_()
        self.le_alignErrorAz.raise_()
        self.le_alignErrorAlt.raise_()
        self.le_alignErrorPosAngle.raise_()
        self.label_160.raise_()
        self.mainTabWidget.addTab(self.tab_8, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.label_107 = QtWidgets.QLabel(self.tab_5)
        self.label_107.setGeometry(QtCore.QRect(10, 20, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_107.setFont(font)
        self.label_107.setObjectName("label_107")
        self.btn_cancelAnalyseModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_cancelAnalyseModel.setGeometry(QtCore.QRect(10, 340, 291, 31))
        self.btn_cancelAnalyseModel.setObjectName("btn_cancelAnalyseModel")
        self.btn_runTimeChangeModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_runTimeChangeModel.setGeometry(QtCore.QRect(10, 110, 291, 31))
        self.btn_runTimeChangeModel.setObjectName("btn_runTimeChangeModel")
        self.line_33 = QtWidgets.QFrame(self.tab_5)
        self.line_33.setGeometry(QtCore.QRect(10, 30, 291, 21))
        self.line_33.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_33.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_33.setObjectName("line_33")
        self.label_174 = QtWidgets.QLabel(self.tab_5)
        self.label_174.setGeometry(QtCore.QRect(10, 50, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_174.setFont(font)
        self.label_174.setObjectName("label_174")
        self.azimuthTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.azimuthTimeChange.setGeometry(QtCore.QRect(240, 50, 51, 22))
        self.azimuthTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthTimeChange.setDecimals(0)
        self.azimuthTimeChange.setMaximum(359.0)
        self.azimuthTimeChange.setSingleStep(1.0)
        self.azimuthTimeChange.setProperty("value", 0.0)
        self.azimuthTimeChange.setObjectName("azimuthTimeChange")
        self.label_175 = QtWidgets.QLabel(self.tab_5)
        self.label_175.setGeometry(QtCore.QRect(190, 50, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_175.setFont(font)
        self.label_175.setObjectName("label_175")
        self.altitudeTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.altitudeTimeChange.setGeometry(QtCore.QRect(110, 50, 51, 22))
        self.altitudeTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeTimeChange.setDecimals(0)
        self.altitudeTimeChange.setMinimum(0.0)
        self.altitudeTimeChange.setMaximum(90.0)
        self.altitudeTimeChange.setSingleStep(1.0)
        self.altitudeTimeChange.setProperty("value", 45.0)
        self.altitudeTimeChange.setObjectName("altitudeTimeChange")
        self.label_176 = QtWidgets.QLabel(self.tab_5)
        self.label_176.setGeometry(QtCore.QRect(10, 80, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_176.setFont(font)
        self.label_176.setObjectName("label_176")
        self.numberRunsTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.numberRunsTimeChange.setGeometry(QtCore.QRect(110, 80, 51, 22))
        self.numberRunsTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberRunsTimeChange.setDecimals(0)
        self.numberRunsTimeChange.setMinimum(10.0)
        self.numberRunsTimeChange.setMaximum(300.0)
        self.numberRunsTimeChange.setSingleStep(1.0)
        self.numberRunsTimeChange.setProperty("value", 30.0)
        self.numberRunsTimeChange.setObjectName("numberRunsTimeChange")
        self.label_111 = QtWidgets.QLabel(self.tab_5)
        self.label_111.setGeometry(QtCore.QRect(290, 50, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_111.setFont(font)
        self.label_111.setAlignment(QtCore.Qt.AlignCenter)
        self.label_111.setWordWrap(False)
        self.label_111.setObjectName("label_111")
        self.label_112 = QtWidgets.QLabel(self.tab_5)
        self.label_112.setGeometry(QtCore.QRect(160, 50, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_112.setFont(font)
        self.label_112.setAlignment(QtCore.Qt.AlignCenter)
        self.label_112.setWordWrap(False)
        self.label_112.setObjectName("label_112")
        self.label_177 = QtWidgets.QLabel(self.tab_5)
        self.label_177.setGeometry(QtCore.QRect(190, 80, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_177.setFont(font)
        self.label_177.setObjectName("label_177")
        self.delayTimeTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.delayTimeTimeChange.setGeometry(QtCore.QRect(240, 80, 51, 22))
        self.delayTimeTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.delayTimeTimeChange.setDecimals(0)
        self.delayTimeTimeChange.setMinimum(1.0)
        self.delayTimeTimeChange.setMaximum(300.0)
        self.delayTimeTimeChange.setSingleStep(1.0)
        self.delayTimeTimeChange.setProperty("value", 30.0)
        self.delayTimeTimeChange.setObjectName("delayTimeTimeChange")
        self.label_115 = QtWidgets.QLabel(self.tab_5)
        self.label_115.setGeometry(QtCore.QRect(290, 80, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_115.setFont(font)
        self.label_115.setAlignment(QtCore.Qt.AlignCenter)
        self.label_115.setWordWrap(False)
        self.label_115.setObjectName("label_115")
        self.label_118 = QtWidgets.QLabel(self.tab_5)
        self.label_118.setGeometry(QtCore.QRect(10, 160, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_118.setFont(font)
        self.label_118.setObjectName("label_118")
        self.line_37 = QtWidgets.QFrame(self.tab_5)
        self.line_37.setGeometry(QtCore.QRect(10, 170, 291, 21))
        self.line_37.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_37.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_37.setObjectName("line_37")
        self.btn_runHystereseModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_runHystereseModel.setGeometry(QtCore.QRect(10, 280, 291, 31))
        self.btn_runHystereseModel.setObjectName("btn_runHystereseModel")
        self.le_analyseFileName = QtWidgets.QLineEdit(self.tab_5)
        self.le_analyseFileName.setGeometry(QtCore.QRect(430, 50, 311, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_analyseFileName.setFont(font)
        self.le_analyseFileName.setMouseTracking(False)
        self.le_analyseFileName.setAcceptDrops(False)
        self.le_analyseFileName.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_analyseFileName.setReadOnly(False)
        self.le_analyseFileName.setObjectName("le_analyseFileName")
        self.line_29 = QtWidgets.QFrame(self.tab_5)
        self.line_29.setGeometry(QtCore.QRect(430, 30, 311, 21))
        self.line_29.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_29.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_29.setObjectName("line_29")
        self.btn_openAnalyseWindow = QtWidgets.QPushButton(self.tab_5)
        self.btn_openAnalyseWindow.setGeometry(QtCore.QRect(430, 130, 311, 31))
        self.btn_openAnalyseWindow.setStyleSheet("background-color: rgb(16, 72, 96);\n"
"color: rgb(255,255,255);")
        self.btn_openAnalyseWindow.setObjectName("btn_openAnalyseWindow")
        self.btn_selectAnalyseFileName = QtWidgets.QPushButton(self.tab_5)
        self.btn_selectAnalyseFileName.setGeometry(QtCore.QRect(430, 80, 121, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_selectAnalyseFileName.setFont(font)
        self.btn_selectAnalyseFileName.setObjectName("btn_selectAnalyseFileName")
        self.label_99 = QtWidgets.QLabel(self.tab_5)
        self.label_99.setGeometry(QtCore.QRect(430, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_99.setFont(font)
        self.label_99.setObjectName("label_99")
        self.label_182 = QtWidgets.QLabel(self.tab_5)
        self.label_182.setGeometry(QtCore.QRect(190, 220, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_182.setFont(font)
        self.label_182.setObjectName("label_182")
        self.numberRunsHysterese = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.numberRunsHysterese.setGeometry(QtCore.QRect(110, 250, 51, 22))
        self.numberRunsHysterese.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberRunsHysterese.setDecimals(0)
        self.numberRunsHysterese.setMinimum(1.0)
        self.numberRunsHysterese.setMaximum(50.0)
        self.numberRunsHysterese.setSingleStep(1.0)
        self.numberRunsHysterese.setProperty("value", 5.0)
        self.numberRunsHysterese.setObjectName("numberRunsHysterese")
        self.label_183 = QtWidgets.QLabel(self.tab_5)
        self.label_183.setGeometry(QtCore.QRect(10, 250, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_183.setFont(font)
        self.label_183.setObjectName("label_183")
        self.label_184 = QtWidgets.QLabel(self.tab_5)
        self.label_184.setGeometry(QtCore.QRect(190, 250, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_184.setFont(font)
        self.label_184.setObjectName("label_184")
        self.delayTimeHysterese = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.delayTimeHysterese.setGeometry(QtCore.QRect(240, 250, 51, 22))
        self.delayTimeHysterese.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.delayTimeHysterese.setDecimals(0)
        self.delayTimeHysterese.setMinimum(1.0)
        self.delayTimeHysterese.setMaximum(300.0)
        self.delayTimeHysterese.setSingleStep(1.0)
        self.delayTimeHysterese.setProperty("value", 30.0)
        self.delayTimeHysterese.setObjectName("delayTimeHysterese")
        self.azimuthHysterese2 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.azimuthHysterese2.setGeometry(QtCore.QRect(240, 220, 51, 22))
        self.azimuthHysterese2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthHysterese2.setDecimals(0)
        self.azimuthHysterese2.setMaximum(359.0)
        self.azimuthHysterese2.setSingleStep(1.0)
        self.azimuthHysterese2.setProperty("value", 0.0)
        self.azimuthHysterese2.setObjectName("azimuthHysterese2")
        self.label_117 = QtWidgets.QLabel(self.tab_5)
        self.label_117.setGeometry(QtCore.QRect(290, 250, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_117.setFont(font)
        self.label_117.setAlignment(QtCore.Qt.AlignCenter)
        self.label_117.setWordWrap(False)
        self.label_117.setObjectName("label_117")
        self.label_114 = QtWidgets.QLabel(self.tab_5)
        self.label_114.setGeometry(QtCore.QRect(160, 220, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_114.setFont(font)
        self.label_114.setAlignment(QtCore.Qt.AlignCenter)
        self.label_114.setWordWrap(False)
        self.label_114.setObjectName("label_114")
        self.altitudeHysterese2 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.altitudeHysterese2.setGeometry(QtCore.QRect(110, 220, 51, 22))
        self.altitudeHysterese2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeHysterese2.setDecimals(0)
        self.altitudeHysterese2.setMinimum(0.0)
        self.altitudeHysterese2.setMaximum(90.0)
        self.altitudeHysterese2.setSingleStep(1.0)
        self.altitudeHysterese2.setProperty("value", 45.0)
        self.altitudeHysterese2.setObjectName("altitudeHysterese2")
        self.label_119 = QtWidgets.QLabel(self.tab_5)
        self.label_119.setGeometry(QtCore.QRect(290, 220, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_119.setFont(font)
        self.label_119.setAlignment(QtCore.Qt.AlignCenter)
        self.label_119.setWordWrap(False)
        self.label_119.setObjectName("label_119")
        self.label_185 = QtWidgets.QLabel(self.tab_5)
        self.label_185.setGeometry(QtCore.QRect(10, 190, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_185.setFont(font)
        self.label_185.setObjectName("label_185")
        self.label_120 = QtWidgets.QLabel(self.tab_5)
        self.label_120.setGeometry(QtCore.QRect(160, 190, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_120.setFont(font)
        self.label_120.setAlignment(QtCore.Qt.AlignCenter)
        self.label_120.setWordWrap(False)
        self.label_120.setObjectName("label_120")
        self.label_121 = QtWidgets.QLabel(self.tab_5)
        self.label_121.setGeometry(QtCore.QRect(290, 190, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_121.setFont(font)
        self.label_121.setAlignment(QtCore.Qt.AlignCenter)
        self.label_121.setWordWrap(False)
        self.label_121.setObjectName("label_121")
        self.azimuthHysterese1 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.azimuthHysterese1.setGeometry(QtCore.QRect(240, 190, 51, 22))
        self.azimuthHysterese1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthHysterese1.setDecimals(0)
        self.azimuthHysterese1.setMaximum(359.0)
        self.azimuthHysterese1.setSingleStep(1.0)
        self.azimuthHysterese1.setProperty("value", 0.0)
        self.azimuthHysterese1.setObjectName("azimuthHysterese1")
        self.altitudeHysterese1 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.altitudeHysterese1.setGeometry(QtCore.QRect(110, 190, 51, 22))
        self.altitudeHysterese1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeHysterese1.setDecimals(0)
        self.altitudeHysterese1.setMinimum(0.0)
        self.altitudeHysterese1.setMaximum(90.0)
        self.altitudeHysterese1.setSingleStep(1.0)
        self.altitudeHysterese1.setProperty("value", 45.0)
        self.altitudeHysterese1.setObjectName("altitudeHysterese1")
        self.label_186 = QtWidgets.QLabel(self.tab_5)
        self.label_186.setGeometry(QtCore.QRect(190, 190, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_186.setFont(font)
        self.label_186.setObjectName("label_186")
        self.line_43 = QtWidgets.QFrame(self.tab_5)
        self.line_43.setGeometry(QtCore.QRect(10, 170, 291, 21))
        self.line_43.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_43.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_43.setObjectName("line_43")
        self.label_187 = QtWidgets.QLabel(self.tab_5)
        self.label_187.setGeometry(QtCore.QRect(10, 220, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_187.setFont(font)
        self.label_187.setObjectName("label_187")
        self.btn_runBatchModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_runBatchModel.setGeometry(QtCore.QRect(430, 340, 311, 31))
        self.btn_runBatchModel.setObjectName("btn_runBatchModel")
        self.line_52 = QtWidgets.QFrame(self.tab_5)
        self.line_52.setGeometry(QtCore.QRect(370, 10, 21, 461))
        self.line_52.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_52.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_52.setObjectName("line_52")
        self.mainTabWidget.addTab(self.tab_5, "")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.line_31 = QtWidgets.QFrame(self.tab_9)
        self.line_31.setGeometry(QtCore.QRect(20, 30, 271, 21))
        self.line_31.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_31.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_31.setObjectName("line_31")
        self.btn_relay1 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay1.setGeometry(QtCore.QRect(20, 50, 131, 31))
        self.btn_relay1.setObjectName("btn_relay1")
        self.btn_relay3 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay3.setGeometry(QtCore.QRect(20, 130, 131, 31))
        self.btn_relay3.setObjectName("btn_relay3")
        self.btn_relay2 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay2.setGeometry(QtCore.QRect(20, 90, 131, 31))
        self.btn_relay2.setObjectName("btn_relay2")
        self.label_96 = QtWidgets.QLabel(self.tab_9)
        self.label_96.setGeometry(QtCore.QRect(20, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_96.setFont(font)
        self.label_96.setObjectName("label_96")
        self.btn_relay4 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay4.setGeometry(QtCore.QRect(20, 170, 131, 31))
        self.btn_relay4.setObjectName("btn_relay4")
        self.btn_relay5 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay5.setGeometry(QtCore.QRect(20, 210, 131, 31))
        self.btn_relay5.setObjectName("btn_relay5")
        self.btn_relay6 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay6.setGeometry(QtCore.QRect(20, 250, 131, 31))
        self.btn_relay6.setObjectName("btn_relay6")
        self.btn_relay7 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay7.setGeometry(QtCore.QRect(20, 290, 131, 31))
        self.btn_relay7.setObjectName("btn_relay7")
        self.btn_relay8 = QtWidgets.QPushButton(self.tab_9)
        self.btn_relay8.setGeometry(QtCore.QRect(20, 330, 131, 31))
        self.btn_relay8.setObjectName("btn_relay8")
        self.mainTabWidget.addTab(self.tab_9, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.settingsTabWidget = QtWidgets.QTabWidget(self.tab_3)
        self.settingsTabWidget.setGeometry(QtCore.QRect(10, 20, 741, 461))
        self.settingsTabWidget.setStyleSheet("")
        self.settingsTabWidget.setObjectName("settingsTabWidget")
        self.tab_13 = QtWidgets.QWidget()
        self.tab_13.setObjectName("tab_13")
        self.line_50 = QtWidgets.QFrame(self.tab_13)
        self.line_50.setGeometry(QtCore.QRect(20, 30, 311, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_50.setFont(font)
        self.line_50.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_50.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_50.setObjectName("line_50")
        self.label_143 = QtWidgets.QLabel(self.tab_13)
        self.label_143.setGeometry(QtCore.QRect(20, 20, 251, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_143.setFont(font)
        self.label_143.setObjectName("label_143")
        self.checkFastDownload = QtWidgets.QCheckBox(self.tab_13)
        self.checkFastDownload.setGeometry(QtCore.QRect(40, 190, 121, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkFastDownload.setFont(font)
        self.checkFastDownload.setChecked(True)
        self.checkFastDownload.setObjectName("checkFastDownload")
        self.checkKeepImages = QtWidgets.QCheckBox(self.tab_13)
        self.checkKeepImages.setGeometry(QtCore.QRect(20, 390, 231, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkKeepImages.setFont(font)
        self.checkKeepImages.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.checkKeepImages.setChecked(True)
        self.checkKeepImages.setObjectName("checkKeepImages")
        self.label_38 = QtWidgets.QLabel(self.tab_13)
        self.label_38.setGeometry(QtCore.QRect(20, 250, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_38.setFont(font)
        self.label_38.setObjectName("label_38")
        self.label_173 = QtWidgets.QLabel(self.tab_13)
        self.label_173.setGeometry(QtCore.QRect(160, 360, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_173.setFont(font)
        self.label_173.setObjectName("label_173")
        self.label_39 = QtWidgets.QLabel(self.tab_13)
        self.label_39.setGeometry(QtCore.QRect(20, 160, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_39.setFont(font)
        self.label_39.setObjectName("label_39")
        self.cameraBin = QtWidgets.QSpinBox(self.tab_13)
        self.cameraBin.setGeometry(QtCore.QRect(140, 130, 51, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.cameraBin.setFont(font)
        self.cameraBin.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
        self.cameraBin.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.cameraBin.setMinimum(1)
        self.cameraBin.setMaximum(3)
        self.cameraBin.setProperty("value", 1)
        self.cameraBin.setObjectName("cameraBin")
        self.label_102 = QtWidgets.QLabel(self.tab_13)
        self.label_102.setGeometry(QtCore.QRect(30, 360, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_102.setFont(font)
        self.label_102.setObjectName("label_102")
        self.scaleSubframe = QtWidgets.QDoubleSpinBox(self.tab_13)
        self.scaleSubframe.setGeometry(QtCore.QRect(100, 360, 51, 22))
        self.scaleSubframe.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.scaleSubframe.setDecimals(0)
        self.scaleSubframe.setMinimum(10.0)
        self.scaleSubframe.setMaximum(100.0)
        self.scaleSubframe.setSingleStep(10.0)
        self.scaleSubframe.setProperty("value", 100.0)
        self.scaleSubframe.setObjectName("scaleSubframe")
        self.label_163 = QtWidgets.QLabel(self.tab_13)
        self.label_163.setGeometry(QtCore.QRect(20, 100, 231, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_163.setFont(font)
        self.label_163.setObjectName("label_163")
        self.isoSetting = QtWidgets.QDoubleSpinBox(self.tab_13)
        self.isoSetting.setGeometry(QtCore.QRect(220, 220, 71, 22))
        self.isoSetting.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.isoSetting.setDecimals(0)
        self.isoSetting.setMinimum(100.0)
        self.isoSetting.setMaximum(128000.0)
        self.isoSetting.setSingleStep(100.0)
        self.isoSetting.setProperty("value", 800.0)
        self.isoSetting.setObjectName("isoSetting")
        self.checkDoSubframe = QtWidgets.QCheckBox(self.tab_13)
        self.checkDoSubframe.setGeometry(QtCore.QRect(20, 340, 131, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkDoSubframe.setFont(font)
        self.checkDoSubframe.setChecked(False)
        self.checkDoSubframe.setObjectName("checkDoSubframe")
        self.line_25 = QtWidgets.QFrame(self.tab_13)
        self.line_25.setGeometry(QtCore.QRect(20, 110, 311, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_25.setFont(font)
        self.line_25.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_25.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_25.setObjectName("line_25")
        self.label_172 = QtWidgets.QLabel(self.tab_13)
        self.label_172.setGeometry(QtCore.QRect(20, 220, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_172.setFont(font)
        self.label_172.setObjectName("label_172")
        self.label_167 = QtWidgets.QLabel(self.tab_13)
        self.label_167.setGeometry(QtCore.QRect(300, 280, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_167.setFont(font)
        self.label_167.setObjectName("label_167")
        self.label_168 = QtWidgets.QLabel(self.tab_13)
        self.label_168.setGeometry(QtCore.QRect(20, 310, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_168.setFont(font)
        self.label_168.setObjectName("label_168")
        self.line_55 = QtWidgets.QFrame(self.tab_13)
        self.line_55.setGeometry(QtCore.QRect(340, 10, 21, 411))
        self.line_55.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_55.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_55.setObjectName("line_55")
        self.label_40 = QtWidgets.QLabel(self.tab_13)
        self.label_40.setGeometry(QtCore.QRect(20, 130, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_40.setFont(font)
        self.label_40.setObjectName("label_40")
        self.label_166 = QtWidgets.QLabel(self.tab_13)
        self.label_166.setGeometry(QtCore.QRect(20, 280, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_166.setFont(font)
        self.label_166.setObjectName("label_166")
        self.label_164 = QtWidgets.QLabel(self.tab_13)
        self.label_164.setGeometry(QtCore.QRect(200, 160, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_164.setFont(font)
        self.label_164.setObjectName("label_164")
        self.pixelSize = QtWidgets.QDoubleSpinBox(self.tab_13)
        self.pixelSize.setGeometry(QtCore.QRect(240, 280, 51, 22))
        self.pixelSize.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.pixelSize.setDecimals(1)
        self.pixelSize.setMaximum(25.0)
        self.pixelSize.setSingleStep(0.1)
        self.pixelSize.setProperty("value", 3.7)
        self.pixelSize.setObjectName("pixelSize")
        self.label_169 = QtWidgets.QLabel(self.tab_13)
        self.label_169.setGeometry(QtCore.QRect(300, 310, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_169.setFont(font)
        self.label_169.setObjectName("label_169")
        self.focalLength = QtWidgets.QDoubleSpinBox(self.tab_13)
        self.focalLength.setGeometry(QtCore.QRect(240, 310, 51, 22))
        self.focalLength.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.focalLength.setDecimals(0)
        self.focalLength.setMaximum(5000.0)
        self.focalLength.setSingleStep(1.0)
        self.focalLength.setProperty("value", 582.0)
        self.focalLength.setObjectName("focalLength")
        self.label_165 = QtWidgets.QLabel(self.tab_13)
        self.label_165.setGeometry(QtCore.QRect(300, 250, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_165.setFont(font)
        self.label_165.setObjectName("label_165")
        self.cameraExposure = QtWidgets.QSpinBox(self.tab_13)
        self.cameraExposure.setGeometry(QtCore.QRect(140, 160, 51, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.cameraExposure.setFont(font)
        self.cameraExposure.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
        self.cameraExposure.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.cameraExposure.setMinimum(1)
        self.cameraExposure.setMaximum(10)
        self.cameraExposure.setProperty("value", 1)
        self.cameraExposure.setObjectName("cameraExposure")
        self.settlingTime = QtWidgets.QDoubleSpinBox(self.tab_13)
        self.settlingTime.setGeometry(QtCore.QRect(240, 250, 51, 22))
        self.settlingTime.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.settlingTime.setDecimals(0)
        self.settlingTime.setMinimum(1.0)
        self.settlingTime.setMaximum(100.0)
        self.settlingTime.setSingleStep(1.0)
        self.settlingTime.setProperty("value", 1.0)
        self.settlingTime.setObjectName("settlingTime")
        self.pd_chooseImagingApp = QtWidgets.QComboBox(self.tab_13)
        self.pd_chooseImagingApp.setGeometry(QtCore.QRect(20, 50, 311, 31))
        self.pd_chooseImagingApp.setObjectName("pd_chooseImagingApp")
        self.label_194 = QtWidgets.QLabel(self.tab_13)
        self.label_194.setGeometry(QtCore.QRect(370, 110, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_194.setFont(font)
        self.label_194.setObjectName("label_194")
        self.label_147 = QtWidgets.QLabel(self.tab_13)
        self.label_147.setGeometry(QtCore.QRect(370, 20, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_147.setFont(font)
        self.label_147.setObjectName("label_147")
        self.btn_selectModelPointsFileName = QtWidgets.QPushButton(self.tab_13)
        self.btn_selectModelPointsFileName.setGeometry(QtCore.QRect(680, 70, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_selectModelPointsFileName.setFont(font)
        self.btn_selectModelPointsFileName.setObjectName("btn_selectModelPointsFileName")
        self.line_58 = QtWidgets.QFrame(self.tab_13)
        self.line_58.setGeometry(QtCore.QRect(370, 120, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_58.setFont(font)
        self.line_58.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_58.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_58.setObjectName("line_58")
        self.le_horizonPointsFileName = QtWidgets.QLineEdit(self.tab_13)
        self.le_horizonPointsFileName.setGeometry(QtCore.QRect(370, 140, 301, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_horizonPointsFileName.setFont(font)
        self.le_horizonPointsFileName.setMouseTracking(False)
        self.le_horizonPointsFileName.setAcceptDrops(False)
        self.le_horizonPointsFileName.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_horizonPointsFileName.setReadOnly(False)
        self.le_horizonPointsFileName.setObjectName("le_horizonPointsFileName")
        self.label_122 = QtWidgets.QLabel(self.tab_13)
        self.label_122.setGeometry(QtCore.QRect(710, 180, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_122.setFont(font)
        self.label_122.setAlignment(QtCore.Qt.AlignCenter)
        self.label_122.setWordWrap(False)
        self.label_122.setObjectName("label_122")
        self.checkUseMinimumHorizonLine = QtWidgets.QCheckBox(self.tab_13)
        self.checkUseMinimumHorizonLine.setGeometry(QtCore.QRect(370, 180, 281, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkUseMinimumHorizonLine.setFont(font)
        self.checkUseMinimumHorizonLine.setChecked(True)
        self.checkUseMinimumHorizonLine.setObjectName("checkUseMinimumHorizonLine")
        self.label_35 = QtWidgets.QLabel(self.tab_13)
        self.label_35.setGeometry(QtCore.QRect(370, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_35.setFont(font)
        self.label_35.setObjectName("label_35")
        self.line_57 = QtWidgets.QFrame(self.tab_13)
        self.line_57.setGeometry(QtCore.QRect(370, 30, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_57.setFont(font)
        self.line_57.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_57.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_57.setObjectName("line_57")
        self.altitudeMinimumHorizon = QtWidgets.QDoubleSpinBox(self.tab_13)
        self.altitudeMinimumHorizon.setGeometry(QtCore.QRect(660, 180, 51, 22))
        self.altitudeMinimumHorizon.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeMinimumHorizon.setDecimals(0)
        self.altitudeMinimumHorizon.setMinimum(0.0)
        self.altitudeMinimumHorizon.setMaximum(90.0)
        self.altitudeMinimumHorizon.setSingleStep(1.0)
        self.altitudeMinimumHorizon.setProperty("value", 20.0)
        self.altitudeMinimumHorizon.setObjectName("altitudeMinimumHorizon")
        self.checkUseFileHorizonLine = QtWidgets.QCheckBox(self.tab_13)
        self.checkUseFileHorizonLine.setGeometry(QtCore.QRect(370, 160, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkUseFileHorizonLine.setFont(font)
        self.checkUseFileHorizonLine.setChecked(False)
        self.checkUseFileHorizonLine.setObjectName("checkUseFileHorizonLine")
        self.le_modelPointsFileName = QtWidgets.QLineEdit(self.tab_13)
        self.le_modelPointsFileName.setGeometry(QtCore.QRect(370, 70, 301, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_modelPointsFileName.setFont(font)
        self.le_modelPointsFileName.setMouseTracking(False)
        self.le_modelPointsFileName.setAcceptDrops(False)
        self.le_modelPointsFileName.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_modelPointsFileName.setReadOnly(False)
        self.le_modelPointsFileName.setObjectName("le_modelPointsFileName")
        self.btn_selectHorizonPointsFileName = QtWidgets.QPushButton(self.tab_13)
        self.btn_selectHorizonPointsFileName.setGeometry(QtCore.QRect(680, 140, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_selectHorizonPointsFileName.setFont(font)
        self.btn_selectHorizonPointsFileName.setObjectName("btn_selectHorizonPointsFileName")
        self.settingsTabWidget.addTab(self.tab_13, "")
        self.tab_12 = QtWidgets.QWidget()
        self.tab_12.setObjectName("tab_12")
        self.line_21 = QtWidgets.QFrame(self.tab_12)
        self.line_21.setGeometry(QtCore.QRect(20, 30, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_21.setFont(font)
        self.line_21.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_21.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_21.setObjectName("line_21")
        self.label_138 = QtWidgets.QLabel(self.tab_12)
        self.label_138.setGeometry(QtCore.QRect(20, 20, 201, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_138.setFont(font)
        self.label_138.setObjectName("label_138")
        self.line_56 = QtWidgets.QFrame(self.tab_12)
        self.line_56.setGeometry(QtCore.QRect(380, 10, 21, 411))
        self.line_56.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_56.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_56.setObjectName("line_56")
        self.label_193 = QtWidgets.QLabel(self.tab_12)
        self.label_193.setGeometry(QtCore.QRect(400, 20, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_193.setFont(font)
        self.label_193.setObjectName("label_193")
        self.line_49 = QtWidgets.QFrame(self.tab_12)
        self.line_49.setGeometry(QtCore.QRect(400, 30, 321, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_49.setFont(font)
        self.line_49.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_49.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_49.setObjectName("line_49")
        self.checkRemoteAccess = QtWidgets.QCheckBox(self.tab_12)
        self.checkRemoteAccess.setGeometry(QtCore.QRect(410, 50, 201, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkRemoteAccess.setFont(font)
        self.checkRemoteAccess.setChecked(False)
        self.checkRemoteAccess.setObjectName("checkRemoteAccess")
        self.pd_chooseMountConnection = QtWidgets.QComboBox(self.tab_12)
        self.pd_chooseMountConnection.setGeometry(QtCore.QRect(20, 50, 351, 31))
        self.pd_chooseMountConnection.setObjectName("pd_chooseMountConnection")
        self.btn_setupMountDriver = QtWidgets.QPushButton(self.tab_12)
        self.btn_setupMountDriver.setGeometry(QtCore.QRect(30, 100, 191, 51))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupMountDriver.setFont(font)
        self.btn_setupMountDriver.setStyleSheet("")
        self.btn_setupMountDriver.setObjectName("btn_setupMountDriver")
        self.le_mountIP = QtWidgets.QLineEdit(self.tab_12)
        self.le_mountIP.setGeometry(QtCore.QRect(70, 100, 151, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_mountIP.setFont(font)
        self.le_mountIP.setMouseTracking(False)
        self.le_mountIP.setAcceptDrops(False)
        self.le_mountIP.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_mountIP.setMaxLength(15)
        self.le_mountIP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_mountIP.setReadOnly(False)
        self.le_mountIP.setObjectName("le_mountIP")
        self.label_mountIP = QtWidgets.QLabel(self.tab_12)
        self.label_mountIP.setGeometry(QtCore.QRect(30, 100, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_mountIP.setFont(font)
        self.label_mountIP.setObjectName("label_mountIP")
        self.label_mountMAC = QtWidgets.QLabel(self.tab_12)
        self.label_mountMAC.setGeometry(QtCore.QRect(30, 130, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_mountMAC.setFont(font)
        self.label_mountMAC.setObjectName("label_mountMAC")
        self.le_mountMAC = QtWidgets.QLineEdit(self.tab_12)
        self.le_mountMAC.setGeometry(QtCore.QRect(70, 130, 151, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_mountMAC.setFont(font)
        self.le_mountMAC.setMouseTracking(False)
        self.le_mountMAC.setAcceptDrops(False)
        self.le_mountMAC.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_mountMAC.setMaxLength(18)
        self.le_mountMAC.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_mountMAC.setReadOnly(False)
        self.le_mountMAC.setObjectName("le_mountMAC")
        self.le_remotePort = QtWidgets.QLineEdit(self.tab_12)
        self.le_remotePort.setGeometry(QtCore.QRect(660, 50, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_remotePort.setFont(font)
        self.le_remotePort.setMouseTracking(False)
        self.le_remotePort.setAcceptDrops(False)
        self.le_remotePort.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_remotePort.setMaxLength(5)
        self.le_remotePort.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_remotePort.setReadOnly(False)
        self.le_remotePort.setObjectName("le_remotePort")
        self.label_mountIP_2 = QtWidgets.QLabel(self.tab_12)
        self.label_mountIP_2.setGeometry(QtCore.QRect(620, 50, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_mountIP_2.setFont(font)
        self.label_mountIP_2.setObjectName("label_mountIP_2")
        self.settingsTabWidget.addTab(self.tab_12, "")
        self.tab_20 = QtWidgets.QWidget()
        self.tab_20.setObjectName("tab_20")
        self.btn_setupDomeDriver = QtWidgets.QPushButton(self.tab_20)
        self.btn_setupDomeDriver.setGeometry(QtCore.QRect(270, 40, 101, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupDomeDriver.setFont(font)
        self.btn_setupDomeDriver.setObjectName("btn_setupDomeDriver")
        self.line_74 = QtWidgets.QFrame(self.tab_20)
        self.line_74.setGeometry(QtCore.QRect(380, 10, 21, 411))
        self.line_74.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_74.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_74.setObjectName("line_74")
        self.label_257 = QtWidgets.QLabel(self.tab_20)
        self.label_257.setGeometry(QtCore.QRect(20, 10, 201, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_257.setFont(font)
        self.label_257.setObjectName("label_257")
        self.line_75 = QtWidgets.QFrame(self.tab_20)
        self.line_75.setGeometry(QtCore.QRect(20, 20, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_75.setFont(font)
        self.line_75.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_75.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_75.setObjectName("line_75")
        self.label_258 = QtWidgets.QLabel(self.tab_20)
        self.label_258.setGeometry(QtCore.QRect(30, 80, 241, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_258.setFont(font)
        self.label_258.setObjectName("label_258")
        self.btn_setupAscomEnvironmentDriver = QtWidgets.QPushButton(self.tab_20)
        self.btn_setupAscomEnvironmentDriver.setGeometry(QtCore.QRect(270, 80, 101, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupAscomEnvironmentDriver.setFont(font)
        self.btn_setupAscomEnvironmentDriver.setObjectName("btn_setupAscomEnvironmentDriver")
        self.label_261 = QtWidgets.QLabel(self.tab_20)
        self.label_261.setGeometry(QtCore.QRect(30, 40, 251, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_261.setFont(font)
        self.label_261.setObjectName("label_261")
        self.settingsTabWidget.addTab(self.tab_20, "")
        self.tab_21 = QtWidgets.QWidget()
        self.tab_21.setObjectName("tab_21")
        self.le_INDIServerPort = QtWidgets.QLineEdit(self.tab_21)
        self.le_INDIServerPort.setGeometry(QtCore.QRect(310, 80, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_INDIServerPort.setFont(font)
        self.le_INDIServerPort.setMouseTracking(False)
        self.le_INDIServerPort.setAcceptDrops(False)
        self.le_INDIServerPort.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_INDIServerPort.setMaxLength(5)
        self.le_INDIServerPort.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_INDIServerPort.setReadOnly(False)
        self.le_INDIServerPort.setObjectName("le_INDIServerPort")
        self.le_INDIServerIP = QtWidgets.QLineEdit(self.tab_21)
        self.le_INDIServerIP.setGeometry(QtCore.QRect(110, 80, 131, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_INDIServerIP.setFont(font)
        self.le_INDIServerIP.setMouseTracking(False)
        self.le_INDIServerIP.setAcceptDrops(False)
        self.le_INDIServerIP.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_INDIServerIP.setMaxLength(15)
        self.le_INDIServerIP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_INDIServerIP.setReadOnly(False)
        self.le_INDIServerIP.setObjectName("le_INDIServerIP")
        self.label_259 = QtWidgets.QLabel(self.tab_21)
        self.label_259.setGeometry(QtCore.QRect(20, 10, 201, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_259.setFont(font)
        self.label_259.setObjectName("label_259")
        self.line_78 = QtWidgets.QFrame(self.tab_21)
        self.line_78.setGeometry(QtCore.QRect(20, 20, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_78.setFont(font)
        self.line_78.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_78.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_78.setObjectName("line_78")
        self.line_79 = QtWidgets.QFrame(self.tab_21)
        self.line_79.setGeometry(QtCore.QRect(380, 10, 21, 411))
        self.line_79.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_79.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_79.setObjectName("line_79")
        self.label_mountIP_3 = QtWidgets.QLabel(self.tab_21)
        self.label_mountIP_3.setGeometry(QtCore.QRect(270, 80, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_mountIP_3.setFont(font)
        self.label_mountIP_3.setObjectName("label_mountIP_3")
        self.label_145 = QtWidgets.QLabel(self.tab_21)
        self.label_145.setGeometry(QtCore.QRect(20, 80, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_145.setFont(font)
        self.label_145.setObjectName("label_145")
        self.le_INDIStatus = QtWidgets.QLineEdit(self.tab_21)
        self.le_INDIStatus.setGeometry(QtCore.QRect(110, 110, 261, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_INDIStatus.setFont(font)
        self.le_INDIStatus.setMouseTracking(False)
        self.le_INDIStatus.setAcceptDrops(False)
        self.le_INDIStatus.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_INDIStatus.setMaxLength(15)
        self.le_INDIStatus.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_INDIStatus.setReadOnly(False)
        self.le_INDIStatus.setObjectName("le_INDIStatus")
        self.label_146 = QtWidgets.QLabel(self.tab_21)
        self.label_146.setGeometry(QtCore.QRect(20, 110, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_146.setFont(font)
        self.label_146.setObjectName("label_146")
        self.le_INDITelescope = QtWidgets.QLineEdit(self.tab_21)
        self.le_INDITelescope.setGeometry(QtCore.QRect(110, 140, 261, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_INDITelescope.setFont(font)
        self.le_INDITelescope.setMouseTracking(False)
        self.le_INDITelescope.setAcceptDrops(False)
        self.le_INDITelescope.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_INDITelescope.setMaxLength(15)
        self.le_INDITelescope.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_INDITelescope.setReadOnly(False)
        self.le_INDITelescope.setObjectName("le_INDITelescope")
        self.le_INDICCD = QtWidgets.QLineEdit(self.tab_21)
        self.le_INDICCD.setGeometry(QtCore.QRect(110, 170, 261, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_INDICCD.setFont(font)
        self.le_INDICCD.setMouseTracking(False)
        self.le_INDICCD.setAcceptDrops(False)
        self.le_INDICCD.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_INDICCD.setMaxLength(15)
        self.le_INDICCD.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_INDICCD.setReadOnly(False)
        self.le_INDICCD.setObjectName("le_INDICCD")
        self.label_149 = QtWidgets.QLabel(self.tab_21)
        self.label_149.setGeometry(QtCore.QRect(20, 140, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_149.setFont(font)
        self.label_149.setObjectName("label_149")
        self.label_198 = QtWidgets.QLabel(self.tab_21)
        self.label_198.setGeometry(QtCore.QRect(20, 170, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_198.setFont(font)
        self.label_198.setObjectName("label_198")
        self.label_199 = QtWidgets.QLabel(self.tab_21)
        self.label_199.setGeometry(QtCore.QRect(20, 200, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_199.setFont(font)
        self.label_199.setObjectName("label_199")
        self.le_INDIWeather = QtWidgets.QLineEdit(self.tab_21)
        self.le_INDIWeather.setGeometry(QtCore.QRect(110, 200, 261, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_INDIWeather.setFont(font)
        self.le_INDIWeather.setMouseTracking(False)
        self.le_INDIWeather.setAcceptDrops(False)
        self.le_INDIWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_INDIWeather.setMaxLength(15)
        self.le_INDIWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_INDIWeather.setReadOnly(False)
        self.le_INDIWeather.setObjectName("le_INDIWeather")
        self.checkEnableINDI = QtWidgets.QCheckBox(self.tab_21)
        self.checkEnableINDI.setGeometry(QtCore.QRect(20, 40, 201, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkEnableINDI.setFont(font)
        self.checkEnableINDI.setChecked(False)
        self.checkEnableINDI.setObjectName("checkEnableINDI")
        self.settingsTabWidget.addTab(self.tab_21, "")
        self.tab_10 = QtWidgets.QWidget()
        self.tab_10.setObjectName("tab_10")
        self.le_altParkPos3 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos3.setGeometry(QtCore.QRect(350, 110, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos3.setFont(font)
        self.le_altParkPos3.setMouseTracking(False)
        self.le_altParkPos3.setAcceptDrops(False)
        self.le_altParkPos3.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos3.setReadOnly(False)
        self.le_altParkPos3.setObjectName("le_altParkPos3")
        self.le_parkPos3Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos3Text.setGeometry(QtCore.QRect(120, 110, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos3Text.setFont(font)
        self.le_parkPos3Text.setMouseTracking(False)
        self.le_parkPos3Text.setAcceptDrops(False)
        self.le_parkPos3Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos3Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos3Text.setReadOnly(False)
        self.le_parkPos3Text.setObjectName("le_parkPos3Text")
        self.le_parkPos1Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos1Text.setGeometry(QtCore.QRect(120, 50, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos1Text.setFont(font)
        self.le_parkPos1Text.setMouseTracking(False)
        self.le_parkPos1Text.setAcceptDrops(False)
        self.le_parkPos1Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos1Text.setReadOnly(False)
        self.le_parkPos1Text.setObjectName("le_parkPos1Text")
        self.label_19 = QtWidgets.QLabel(self.tab_10)
        self.label_19.setGeometry(QtCore.QRect(260, 50, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_19.setFont(font)
        self.label_19.setObjectName("label_19")
        self.label_43 = QtWidgets.QLabel(self.tab_10)
        self.label_43.setGeometry(QtCore.QRect(260, 80, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_43.setFont(font)
        self.label_43.setObjectName("label_43")
        self.label_54 = QtWidgets.QLabel(self.tab_10)
        self.label_54.setGeometry(QtCore.QRect(20, 20, 221, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_54.setFont(font)
        self.label_54.setObjectName("label_54")
        self.le_azParkPos3 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos3.setGeometry(QtCore.QRect(280, 110, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos3.setFont(font)
        self.le_azParkPos3.setMouseTracking(False)
        self.le_azParkPos3.setAcceptDrops(False)
        self.le_azParkPos3.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos3.setReadOnly(False)
        self.le_azParkPos3.setObjectName("le_azParkPos3")
        self.le_parkPos2Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos2Text.setGeometry(QtCore.QRect(120, 80, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos2Text.setFont(font)
        self.le_parkPos2Text.setMouseTracking(False)
        self.le_parkPos2Text.setAcceptDrops(False)
        self.le_parkPos2Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos2Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos2Text.setReadOnly(False)
        self.le_parkPos2Text.setObjectName("le_parkPos2Text")
        self.le_azParkPos1 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos1.setGeometry(QtCore.QRect(280, 50, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos1.setFont(font)
        self.le_azParkPos1.setMouseTracking(False)
        self.le_azParkPos1.setAcceptDrops(False)
        self.le_azParkPos1.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos1.setReadOnly(False)
        self.le_azParkPos1.setObjectName("le_azParkPos1")
        self.label_45 = QtWidgets.QLabel(self.tab_10)
        self.label_45.setGeometry(QtCore.QRect(330, 80, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_45.setFont(font)
        self.label_45.setObjectName("label_45")
        self.le_altParkPos4 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos4.setGeometry(QtCore.QRect(350, 140, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos4.setFont(font)
        self.le_altParkPos4.setMouseTracking(False)
        self.le_altParkPos4.setAcceptDrops(False)
        self.le_altParkPos4.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos4.setReadOnly(False)
        self.le_altParkPos4.setObjectName("le_altParkPos4")
        self.le_altParkPos1 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos1.setGeometry(QtCore.QRect(350, 50, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos1.setFont(font)
        self.le_altParkPos1.setMouseTracking(False)
        self.le_altParkPos1.setAcceptDrops(False)
        self.le_altParkPos1.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos1.setReadOnly(False)
        self.le_altParkPos1.setObjectName("le_altParkPos1")
        self.label_2 = QtWidgets.QLabel(self.tab_10)
        self.label_2.setGeometry(QtCore.QRect(20, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.le_altParkPos2 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos2.setGeometry(QtCore.QRect(350, 80, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos2.setFont(font)
        self.le_altParkPos2.setMouseTracking(False)
        self.le_altParkPos2.setAcceptDrops(False)
        self.le_altParkPos2.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos2.setReadOnly(False)
        self.le_altParkPos2.setObjectName("le_altParkPos2")
        self.label_51 = QtWidgets.QLabel(self.tab_10)
        self.label_51.setGeometry(QtCore.QRect(330, 140, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_51.setFont(font)
        self.label_51.setObjectName("label_51")
        self.label_50 = QtWidgets.QLabel(self.tab_10)
        self.label_50.setGeometry(QtCore.QRect(20, 140, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_50.setFont(font)
        self.label_50.setObjectName("label_50")
        self.label_44 = QtWidgets.QLabel(self.tab_10)
        self.label_44.setGeometry(QtCore.QRect(20, 80, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_44.setFont(font)
        self.label_44.setObjectName("label_44")
        self.le_azParkPos2 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos2.setGeometry(QtCore.QRect(280, 80, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos2.setFont(font)
        self.le_azParkPos2.setMouseTracking(False)
        self.le_azParkPos2.setAcceptDrops(False)
        self.le_azParkPos2.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos2.setReadOnly(False)
        self.le_azParkPos2.setObjectName("le_azParkPos2")
        self.label_49 = QtWidgets.QLabel(self.tab_10)
        self.label_49.setGeometry(QtCore.QRect(260, 140, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_49.setFont(font)
        self.label_49.setObjectName("label_49")
        self.label_3 = QtWidgets.QLabel(self.tab_10)
        self.label_3.setGeometry(QtCore.QRect(330, 50, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.line_4 = QtWidgets.QFrame(self.tab_10)
        self.line_4.setGeometry(QtCore.QRect(20, 30, 371, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_4.setFont(font)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setObjectName("line_4")
        self.le_azParkPos4 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos4.setGeometry(QtCore.QRect(280, 140, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos4.setFont(font)
        self.le_azParkPos4.setMouseTracking(False)
        self.le_azParkPos4.setAcceptDrops(False)
        self.le_azParkPos4.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos4.setReadOnly(False)
        self.le_azParkPos4.setObjectName("le_azParkPos4")
        self.label_46 = QtWidgets.QLabel(self.tab_10)
        self.label_46.setGeometry(QtCore.QRect(260, 110, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_46.setFont(font)
        self.label_46.setObjectName("label_46")
        self.label_48 = QtWidgets.QLabel(self.tab_10)
        self.label_48.setGeometry(QtCore.QRect(330, 110, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_48.setFont(font)
        self.label_48.setObjectName("label_48")
        self.le_parkPos4Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos4Text.setGeometry(QtCore.QRect(120, 140, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos4Text.setFont(font)
        self.le_parkPos4Text.setMouseTracking(False)
        self.le_parkPos4Text.setAcceptDrops(False)
        self.le_parkPos4Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos4Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos4Text.setReadOnly(False)
        self.le_parkPos4Text.setObjectName("le_parkPos4Text")
        self.label_47 = QtWidgets.QLabel(self.tab_10)
        self.label_47.setGeometry(QtCore.QRect(20, 110, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_47.setFont(font)
        self.label_47.setObjectName("label_47")
        self.le_azParkPos5 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos5.setGeometry(QtCore.QRect(280, 170, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos5.setFont(font)
        self.le_azParkPos5.setMouseTracking(False)
        self.le_azParkPos5.setAcceptDrops(False)
        self.le_azParkPos5.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos5.setReadOnly(False)
        self.le_azParkPos5.setObjectName("le_azParkPos5")
        self.label_92 = QtWidgets.QLabel(self.tab_10)
        self.label_92.setGeometry(QtCore.QRect(20, 200, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_92.setFont(font)
        self.label_92.setObjectName("label_92")
        self.le_altParkPos6 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos6.setGeometry(QtCore.QRect(350, 200, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos6.setFont(font)
        self.le_altParkPos6.setMouseTracking(False)
        self.le_altParkPos6.setAcceptDrops(False)
        self.le_altParkPos6.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos6.setReadOnly(False)
        self.le_altParkPos6.setObjectName("le_altParkPos6")
        self.label_93 = QtWidgets.QLabel(self.tab_10)
        self.label_93.setGeometry(QtCore.QRect(260, 170, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_93.setFont(font)
        self.label_93.setObjectName("label_93")
        self.label_94 = QtWidgets.QLabel(self.tab_10)
        self.label_94.setGeometry(QtCore.QRect(330, 170, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_94.setFont(font)
        self.label_94.setObjectName("label_94")
        self.label_95 = QtWidgets.QLabel(self.tab_10)
        self.label_95.setGeometry(QtCore.QRect(20, 170, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_95.setFont(font)
        self.label_95.setObjectName("label_95")
        self.le_altParkPos5 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos5.setGeometry(QtCore.QRect(350, 170, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos5.setFont(font)
        self.le_altParkPos5.setMouseTracking(False)
        self.le_altParkPos5.setAcceptDrops(False)
        self.le_altParkPos5.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos5.setReadOnly(False)
        self.le_altParkPos5.setObjectName("le_altParkPos5")
        self.le_parkPos6Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos6Text.setGeometry(QtCore.QRect(120, 200, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos6Text.setFont(font)
        self.le_parkPos6Text.setMouseTracking(False)
        self.le_parkPos6Text.setAcceptDrops(False)
        self.le_parkPos6Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos6Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos6Text.setReadOnly(False)
        self.le_parkPos6Text.setObjectName("le_parkPos6Text")
        self.le_parkPos5Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos5Text.setGeometry(QtCore.QRect(120, 170, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos5Text.setFont(font)
        self.le_parkPos5Text.setMouseTracking(False)
        self.le_parkPos5Text.setAcceptDrops(False)
        self.le_parkPos5Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos5Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos5Text.setReadOnly(False)
        self.le_parkPos5Text.setObjectName("le_parkPos5Text")
        self.label_131 = QtWidgets.QLabel(self.tab_10)
        self.label_131.setGeometry(QtCore.QRect(260, 200, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_131.setFont(font)
        self.label_131.setObjectName("label_131")
        self.label_132 = QtWidgets.QLabel(self.tab_10)
        self.label_132.setGeometry(QtCore.QRect(330, 200, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_132.setFont(font)
        self.label_132.setObjectName("label_132")
        self.le_azParkPos6 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos6.setGeometry(QtCore.QRect(280, 200, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos6.setFont(font)
        self.le_azParkPos6.setMouseTracking(False)
        self.le_azParkPos6.setAcceptDrops(False)
        self.le_azParkPos6.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos6.setReadOnly(False)
        self.le_azParkPos6.setObjectName("le_azParkPos6")
        self.settingsTabWidget.addTab(self.tab_10, "")
        self.tab_7 = QtWidgets.QWidget()
        self.tab_7.setObjectName("tab_7")
        self.btn_downloadEarthrotation = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadEarthrotation.setGeometry(QtCore.QRect(20, 40, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadEarthrotation.setFont(font)
        self.btn_downloadEarthrotation.setObjectName("btn_downloadEarthrotation")
        self.label_123 = QtWidgets.QLabel(self.tab_7)
        self.label_123.setGeometry(QtCore.QRect(20, 10, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_123.setFont(font)
        self.label_123.setObjectName("label_123")
        self.line_17 = QtWidgets.QFrame(self.tab_7)
        self.line_17.setGeometry(QtCore.QRect(20, 20, 341, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_17.setFont(font)
        self.line_17.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_17.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_17.setObjectName("line_17")
        self.btn_downloadSpacestations = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadSpacestations.setGeometry(QtCore.QRect(20, 110, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadSpacestations.setFont(font)
        self.btn_downloadSpacestations.setObjectName("btn_downloadSpacestations")
        self.btn_downloadSatbrighest = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadSatbrighest.setGeometry(QtCore.QRect(20, 150, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadSatbrighest.setFont(font)
        self.btn_downloadSatbrighest.setObjectName("btn_downloadSatbrighest")
        self.btn_downloadAsteroidsMPC5000 = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadAsteroidsMPC5000.setGeometry(QtCore.QRect(20, 270, 161, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadAsteroidsMPC5000.setFont(font)
        self.btn_downloadAsteroidsMPC5000.setObjectName("btn_downloadAsteroidsMPC5000")
        self.btn_downloadComets = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadComets.setGeometry(QtCore.QRect(20, 210, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadComets.setFont(font)
        self.btn_downloadComets.setObjectName("btn_downloadComets")
        self.checkEarthrotation = QtWidgets.QCheckBox(self.tab_7)
        self.checkEarthrotation.setGeometry(QtCore.QRect(410, 40, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkEarthrotation.setFont(font)
        self.checkEarthrotation.setChecked(False)
        self.checkEarthrotation.setObjectName("checkEarthrotation")
        self.checkTLE = QtWidgets.QCheckBox(self.tab_7)
        self.checkTLE.setGeometry(QtCore.QRect(410, 130, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkTLE.setFont(font)
        self.checkTLE.setChecked(False)
        self.checkTLE.setObjectName("checkTLE")
        self.checkAsteroids = QtWidgets.QCheckBox(self.tab_7)
        self.checkAsteroids.setGeometry(QtCore.QRect(410, 270, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkAsteroids.setFont(font)
        self.checkAsteroids.setChecked(False)
        self.checkAsteroids.setObjectName("checkAsteroids")
        self.checkComets = QtWidgets.QCheckBox(self.tab_7)
        self.checkComets.setGeometry(QtCore.QRect(410, 210, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkComets.setFont(font)
        self.checkComets.setChecked(False)
        self.checkComets.setObjectName("checkComets")
        self.btn_uploadMount = QtWidgets.QPushButton(self.tab_7)
        self.btn_uploadMount.setGeometry(QtCore.QRect(400, 390, 311, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_uploadMount.setFont(font)
        self.btn_uploadMount.setObjectName("btn_uploadMount")
        self.btn_downloadAll = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadAll.setGeometry(QtCore.QRect(20, 390, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadAll.setFont(font)
        self.btn_downloadAll.setObjectName("btn_downloadAll")
        self.line_47 = QtWidgets.QFrame(self.tab_7)
        self.line_47.setGeometry(QtCore.QRect(370, 0, 21, 421))
        self.line_47.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_47.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_47.setObjectName("line_47")
        self.label_134 = QtWidgets.QLabel(self.tab_7)
        self.label_134.setGeometry(QtCore.QRect(400, 10, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_134.setFont(font)
        self.label_134.setObjectName("label_134")
        self.line_19 = QtWidgets.QFrame(self.tab_7)
        self.line_19.setGeometry(QtCore.QRect(400, 20, 311, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_19.setFont(font)
        self.line_19.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_19.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_19.setObjectName("line_19")
        self.checkFilterMPC = QtWidgets.QCheckBox(self.tab_7)
        self.checkFilterMPC.setGeometry(QtCore.QRect(430, 300, 271, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkFilterMPC.setFont(font)
        self.checkFilterMPC.setChecked(False)
        self.checkFilterMPC.setObjectName("checkFilterMPC")
        self.le_filterExpressionMPC = QtWidgets.QLineEdit(self.tab_7)
        self.le_filterExpressionMPC.setGeometry(QtCore.QRect(430, 330, 281, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_filterExpressionMPC.setFont(font)
        self.le_filterExpressionMPC.setMouseTracking(False)
        self.le_filterExpressionMPC.setAcceptDrops(False)
        self.le_filterExpressionMPC.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_filterExpressionMPC.setReadOnly(False)
        self.le_filterExpressionMPC.setObjectName("le_filterExpressionMPC")
        self.btn_downloadAsteroidsNEA = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadAsteroidsNEA.setGeometry(QtCore.QRect(200, 270, 161, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadAsteroidsNEA.setFont(font)
        self.btn_downloadAsteroidsNEA.setObjectName("btn_downloadAsteroidsNEA")
        self.btn_downloadAsteroidsTNO = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadAsteroidsTNO.setGeometry(QtCore.QRect(200, 310, 161, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadAsteroidsTNO.setFont(font)
        self.btn_downloadAsteroidsTNO.setObjectName("btn_downloadAsteroidsTNO")
        self.btn_downloadAsteroidsPHA = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadAsteroidsPHA.setGeometry(QtCore.QRect(20, 310, 161, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadAsteroidsPHA.setFont(font)
        self.btn_downloadAsteroidsPHA.setObjectName("btn_downloadAsteroidsPHA")
        self.settingsTabWidget.addTab(self.tab_7, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.relay2Text = QtWidgets.QLineEdit(self.tab)
        self.relay2Text.setGeometry(QtCore.QRect(80, 110, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay2Text.setFont(font)
        self.relay2Text.setMouseTracking(False)
        self.relay2Text.setAcceptDrops(False)
        self.relay2Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay2Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.relay2Text.setReadOnly(False)
        self.relay2Text.setObjectName("relay2Text")
        self.label_101 = QtWidgets.QLabel(self.tab)
        self.label_101.setGeometry(QtCore.QRect(20, 140, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_101.setFont(font)
        self.label_101.setObjectName("label_101")
        self.relay5Text = QtWidgets.QLineEdit(self.tab)
        self.relay5Text.setGeometry(QtCore.QRect(80, 200, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay5Text.setFont(font)
        self.relay5Text.setMouseTracking(False)
        self.relay5Text.setAcceptDrops(False)
        self.relay5Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay5Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.relay5Text.setReadOnly(False)
        self.relay5Text.setObjectName("relay5Text")
        self.label_103 = QtWidgets.QLabel(self.tab)
        self.label_103.setGeometry(QtCore.QRect(20, 20, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_103.setFont(font)
        self.label_103.setObjectName("label_103")
        self.relay3Text = QtWidgets.QLineEdit(self.tab)
        self.relay3Text.setGeometry(QtCore.QRect(80, 140, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay3Text.setFont(font)
        self.relay3Text.setMouseTracking(False)
        self.relay3Text.setAcceptDrops(False)
        self.relay3Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay3Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.relay3Text.setReadOnly(False)
        self.relay3Text.setObjectName("relay3Text")
        self.label_36 = QtWidgets.QLabel(self.tab)
        self.label_36.setGeometry(QtCore.QRect(20, 80, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_36.setFont(font)
        self.label_36.setObjectName("label_36")
        self.relay4Text = QtWidgets.QLineEdit(self.tab)
        self.relay4Text.setGeometry(QtCore.QRect(80, 170, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay4Text.setFont(font)
        self.relay4Text.setMouseTracking(False)
        self.relay4Text.setAcceptDrops(False)
        self.relay4Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay4Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.relay4Text.setReadOnly(False)
        self.relay4Text.setObjectName("relay4Text")
        self.label_148 = QtWidgets.QLabel(self.tab)
        self.label_148.setGeometry(QtCore.QRect(20, 200, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_148.setFont(font)
        self.label_148.setObjectName("label_148")
        self.line_22 = QtWidgets.QFrame(self.tab)
        self.line_22.setGeometry(QtCore.QRect(20, 30, 361, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_22.setFont(font)
        self.line_22.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_22.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_22.setObjectName("line_22")
        self.relay6Text = QtWidgets.QLineEdit(self.tab)
        self.relay6Text.setGeometry(QtCore.QRect(80, 230, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay6Text.setFont(font)
        self.relay6Text.setMouseTracking(False)
        self.relay6Text.setAcceptDrops(False)
        self.relay6Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay6Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.relay6Text.setReadOnly(False)
        self.relay6Text.setObjectName("relay6Text")
        self.label_150 = QtWidgets.QLabel(self.tab)
        self.label_150.setGeometry(QtCore.QRect(20, 170, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_150.setFont(font)
        self.label_150.setObjectName("label_150")
        self.relay1Text = QtWidgets.QLineEdit(self.tab)
        self.relay1Text.setGeometry(QtCore.QRect(80, 80, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay1Text.setFont(font)
        self.relay1Text.setMouseTracking(False)
        self.relay1Text.setAcceptDrops(False)
        self.relay1Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay1Text.setReadOnly(False)
        self.relay1Text.setObjectName("relay1Text")
        self.label_161 = QtWidgets.QLabel(self.tab)
        self.label_161.setGeometry(QtCore.QRect(20, 230, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_161.setFont(font)
        self.label_161.setObjectName("label_161")
        self.label_162 = QtWidgets.QLabel(self.tab)
        self.label_162.setGeometry(QtCore.QRect(20, 110, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_162.setFont(font)
        self.label_162.setObjectName("label_162")
        self.relay8Text = QtWidgets.QLineEdit(self.tab)
        self.relay8Text.setGeometry(QtCore.QRect(80, 290, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay8Text.setFont(font)
        self.relay8Text.setMouseTracking(False)
        self.relay8Text.setAcceptDrops(False)
        self.relay8Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay8Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.relay8Text.setReadOnly(False)
        self.relay8Text.setObjectName("relay8Text")
        self.relay7Text = QtWidgets.QLineEdit(self.tab)
        self.relay7Text.setGeometry(QtCore.QRect(80, 260, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.relay7Text.setFont(font)
        self.relay7Text.setMouseTracking(False)
        self.relay7Text.setAcceptDrops(False)
        self.relay7Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.relay7Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.relay7Text.setReadOnly(False)
        self.relay7Text.setObjectName("relay7Text")
        self.label_191 = QtWidgets.QLabel(self.tab)
        self.label_191.setGeometry(QtCore.QRect(20, 260, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_191.setFont(font)
        self.label_191.setObjectName("label_191")
        self.label_192 = QtWidgets.QLabel(self.tab)
        self.label_192.setGeometry(QtCore.QRect(20, 290, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_192.setFont(font)
        self.label_192.setObjectName("label_192")
        self.label_144 = QtWidgets.QLabel(self.tab)
        self.label_144.setGeometry(QtCore.QRect(420, 60, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_144.setFont(font)
        self.label_144.setObjectName("label_144")
        self.le_relayIP = QtWidgets.QLineEdit(self.tab)
        self.le_relayIP.setGeometry(QtCore.QRect(500, 60, 131, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_relayIP.setFont(font)
        self.le_relayIP.setMouseTracking(False)
        self.le_relayIP.setAcceptDrops(False)
        self.le_relayIP.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_relayIP.setMaxLength(15)
        self.le_relayIP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_relayIP.setReadOnly(False)
        self.le_relayIP.setObjectName("le_relayIP")
        self.line_48 = QtWidgets.QFrame(self.tab)
        self.line_48.setGeometry(QtCore.QRect(420, 30, 301, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_48.setFont(font)
        self.line_48.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_48.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_48.setObjectName("line_48")
        self.label_141 = QtWidgets.QLabel(self.tab)
        self.label_141.setGeometry(QtCore.QRect(420, 20, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_141.setFont(font)
        self.label_141.setObjectName("label_141")
        self.label_41 = QtWidgets.QLabel(self.tab)
        self.label_41.setGeometry(QtCore.QRect(80, 50, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_41.setFont(font)
        self.label_41.setObjectName("label_41")
        self.label_195 = QtWidgets.QLabel(self.tab)
        self.label_195.setGeometry(QtCore.QRect(230, 50, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_195.setFont(font)
        self.label_195.setObjectName("label_195")
        self.label_196 = QtWidgets.QLabel(self.tab)
        self.label_196.setGeometry(QtCore.QRect(420, 90, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_196.setFont(font)
        self.label_196.setObjectName("label_196")
        self.label_197 = QtWidgets.QLabel(self.tab)
        self.label_197.setGeometry(QtCore.QRect(420, 120, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_197.setFont(font)
        self.label_197.setObjectName("label_197")
        self.KMUsername = QtWidgets.QLineEdit(self.tab)
        self.KMUsername.setGeometry(QtCore.QRect(500, 90, 131, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.KMUsername.setFont(font)
        self.KMUsername.setMouseTracking(False)
        self.KMUsername.setAcceptDrops(False)
        self.KMUsername.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.KMUsername.setMaxLength(15)
        self.KMUsername.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.KMUsername.setReadOnly(False)
        self.KMUsername.setObjectName("KMUsername")
        self.KMPassword = QtWidgets.QLineEdit(self.tab)
        self.KMPassword.setGeometry(QtCore.QRect(500, 120, 131, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.KMPassword.setFont(font)
        self.KMPassword.setMouseTracking(False)
        self.KMPassword.setAcceptDrops(False)
        self.KMPassword.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.KMPassword.setMaxLength(15)
        self.KMPassword.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.KMPassword.setReadOnly(False)
        self.KMPassword.setObjectName("KMPassword")
        self.line_59 = QtWidgets.QFrame(self.tab)
        self.line_59.setGeometry(QtCore.QRect(390, 10, 21, 411))
        self.line_59.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_59.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_59.setObjectName("line_59")
        self.relay1Function = QtWidgets.QComboBox(self.tab)
        self.relay1Function.setGeometry(QtCore.QRect(220, 80, 161, 22))
        self.relay1Function.setObjectName("relay1Function")
        self.relay2Function = QtWidgets.QComboBox(self.tab)
        self.relay2Function.setGeometry(QtCore.QRect(220, 110, 161, 22))
        self.relay2Function.setObjectName("relay2Function")
        self.relay3Function = QtWidgets.QComboBox(self.tab)
        self.relay3Function.setGeometry(QtCore.QRect(220, 140, 161, 22))
        self.relay3Function.setObjectName("relay3Function")
        self.relay4Function = QtWidgets.QComboBox(self.tab)
        self.relay4Function.setGeometry(QtCore.QRect(220, 170, 161, 22))
        self.relay4Function.setObjectName("relay4Function")
        self.relay5Function = QtWidgets.QComboBox(self.tab)
        self.relay5Function.setGeometry(QtCore.QRect(220, 200, 161, 22))
        self.relay5Function.setObjectName("relay5Function")
        self.relay6Function = QtWidgets.QComboBox(self.tab)
        self.relay6Function.setGeometry(QtCore.QRect(220, 230, 161, 22))
        self.relay6Function.setObjectName("relay6Function")
        self.relay7Function = QtWidgets.QComboBox(self.tab)
        self.relay7Function.setGeometry(QtCore.QRect(220, 260, 161, 22))
        self.relay7Function.setObjectName("relay7Function")
        self.relay8Function = QtWidgets.QComboBox(self.tab)
        self.relay8Function.setGeometry(QtCore.QRect(220, 290, 161, 22))
        self.relay8Function.setObjectName("relay8Function")
        self.settingsTabWidget.addTab(self.tab, "")
        self.tab_11 = QtWidgets.QWidget()
        self.tab_11.setObjectName("tab_11")
        self.le_firmwareTime = QtWidgets.QLabel(self.tab_11)
        self.le_firmwareTime.setGeometry(QtCore.QRect(130, 140, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareTime.setFont(font)
        self.le_firmwareTime.setObjectName("le_firmwareTime")
        self.firmwareProductName_7 = QtWidgets.QLabel(self.tab_11)
        self.firmwareProductName_7.setGeometry(QtCore.QRect(20, 250, 271, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_7.setFont(font)
        self.firmwareProductName_7.setObjectName("firmwareProductName_7")
        self.le_firmwareProductName = QtWidgets.QLabel(self.tab_11)
        self.le_firmwareProductName.setGeometry(QtCore.QRect(130, 50, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareProductName.setFont(font)
        self.le_firmwareProductName.setObjectName("le_firmwareProductName")
        self.le_firmwareDate = QtWidgets.QLabel(self.tab_11)
        self.le_firmwareDate.setGeometry(QtCore.QRect(130, 110, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareDate.setFont(font)
        self.le_firmwareDate.setObjectName("le_firmwareDate")
        self.firmwareProductName_2 = QtWidgets.QLabel(self.tab_11)
        self.firmwareProductName_2.setGeometry(QtCore.QRect(20, 50, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_2.setFont(font)
        self.firmwareProductName_2.setObjectName("firmwareProductName_2")
        self.le_firmwareProductName_2 = QtWidgets.QLabel(self.tab_11)
        self.le_firmwareProductName_2.setGeometry(QtCore.QRect(420, 400, 301, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareProductName_2.setFont(font)
        self.le_firmwareProductName_2.setObjectName("le_firmwareProductName_2")
        self.firmwareProductName_6 = QtWidgets.QLabel(self.tab_11)
        self.firmwareProductName_6.setGeometry(QtCore.QRect(20, 170, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_6.setFont(font)
        self.firmwareProductName_6.setObjectName("firmwareProductName_6")
        self.label_56 = QtWidgets.QLabel(self.tab_11)
        self.label_56.setGeometry(QtCore.QRect(20, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_56.setFont(font)
        self.label_56.setObjectName("label_56")
        self.le_hardwareVersion = QtWidgets.QLabel(self.tab_11)
        self.le_hardwareVersion.setGeometry(QtCore.QRect(130, 170, 201, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_hardwareVersion.setFont(font)
        self.le_hardwareVersion.setObjectName("le_hardwareVersion")
        self.le_firmwareNumber = QtWidgets.QLabel(self.tab_11)
        self.le_firmwareNumber.setGeometry(QtCore.QRect(130, 80, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareNumber.setFont(font)
        self.le_firmwareNumber.setObjectName("le_firmwareNumber")
        self.line_6 = QtWidgets.QFrame(self.tab_11)
        self.line_6.setGeometry(QtCore.QRect(20, 30, 331, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_6.setFont(font)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_6.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_6.setObjectName("line_6")
        self.le_mwWorkingDir = QtWidgets.QLabel(self.tab_11)
        self.le_mwWorkingDir.setGeometry(QtCore.QRect(20, 270, 701, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_mwWorkingDir.setFont(font)
        self.le_mwWorkingDir.setObjectName("le_mwWorkingDir")
        self.firmwareProductName_4 = QtWidgets.QLabel(self.tab_11)
        self.firmwareProductName_4.setGeometry(QtCore.QRect(20, 110, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_4.setFont(font)
        self.firmwareProductName_4.setObjectName("firmwareProductName_4")
        self.firmwareProductName_5 = QtWidgets.QLabel(self.tab_11)
        self.firmwareProductName_5.setGeometry(QtCore.QRect(20, 140, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_5.setFont(font)
        self.firmwareProductName_5.setObjectName("firmwareProductName_5")
        self.firmwareProductName_3 = QtWidgets.QLabel(self.tab_11)
        self.firmwareProductName_3.setGeometry(QtCore.QRect(20, 80, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_3.setFont(font)
        self.firmwareProductName_3.setObjectName("firmwareProductName_3")
        self.btn_runBoostModel = QtWidgets.QPushButton(self.tab_11)
        self.btn_runBoostModel.setGeometry(QtCore.QRect(20, 310, 121, 31))
        self.btn_runBoostModel.setObjectName("btn_runBoostModel")
        self.settingsTabWidget.addTab(self.tab_11, "")
        self.mainTabWidget.addTab(self.tab_3, "")
        self.btn_mountShutdown = QtWidgets.QPushButton(MainWindow)
        self.btn_mountShutdown.setGeometry(QtCore.QRect(10, 80, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountShutdown.setFont(font)
        self.btn_mountShutdown.setObjectName("btn_mountShutdown")
        self.btn_mountQuit = QtWidgets.QPushButton(MainWindow)
        self.btn_mountQuit.setGeometry(QtCore.QRect(280, 80, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountQuit.setFont(font)
        self.btn_mountQuit.setObjectName("btn_mountQuit")
        self.errorStatus = QtWidgets.QTextBrowser(MainWindow)
        self.errorStatus.setGeometry(QtCore.QRect(370, 30, 411, 81))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(8)
        self.errorStatus.setFont(font)
        self.errorStatus.setFrameShadow(QtWidgets.QFrame.Plain)
        self.errorStatus.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.errorStatus.setAcceptRichText(False)
        self.errorStatus.setObjectName("errorStatus")
        self.label_104 = QtWidgets.QLabel(MainWindow)
        self.label_104.setGeometry(QtCore.QRect(370, 10, 171, 16))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_104.setFont(font)
        self.label_104.setObjectName("label_104")
        self.btn_mountSave = QtWidgets.QPushButton(MainWindow)
        self.btn_mountSave.setGeometry(QtCore.QRect(190, 80, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountSave.setFont(font)
        self.btn_mountSave.setObjectName("btn_mountSave")
        self.btn_camPlateConnected = QtWidgets.QPushButton(MainWindow)
        self.btn_camPlateConnected.setGeometry(QtCore.QRect(100, 10, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_camPlateConnected.setFont(font)
        self.btn_camPlateConnected.setObjectName("btn_camPlateConnected")
        self.btn_domeConnected = QtWidgets.QPushButton(MainWindow)
        self.btn_domeConnected.setGeometry(QtCore.QRect(190, 10, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_domeConnected.setFont(font)
        self.btn_domeConnected.setObjectName("btn_domeConnected")
        self.btn_driverMountConnected = QtWidgets.QPushButton(MainWindow)
        self.btn_driverMountConnected.setGeometry(QtCore.QRect(10, 10, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_driverMountConnected.setFont(font)
        self.btn_driverMountConnected.setObjectName("btn_driverMountConnected")
        self.btn_mountBoot = QtWidgets.QPushButton(MainWindow)
        self.btn_mountBoot.setGeometry(QtCore.QRect(100, 80, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountBoot.setFont(font)
        self.btn_mountBoot.setObjectName("btn_mountBoot")
        self.btn_environmentConnected = QtWidgets.QPushButton(MainWindow)
        self.btn_environmentConnected.setGeometry(QtCore.QRect(280, 10, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_environmentConnected.setFont(font)
        self.btn_environmentConnected.setObjectName("btn_environmentConnected")

        self.retranslateUi(MainWindow)
        self.mainTabWidget.setCurrentIndex(0)
        self.settingsTabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.btn_mountShutdown, self.btn_openImageWindow)
        MainWindow.setTabOrder(self.btn_openImageWindow, self.mainTabWidget)
        MainWindow.setTabOrder(self.mainTabWidget, self.le_slewRate)
        MainWindow.setTabOrder(self.le_slewRate, self.btn_setSlewRate)
        MainWindow.setTabOrder(self.btn_setSlewRate, self.le_telescopeDualTrack)
        MainWindow.setTabOrder(self.le_telescopeDualTrack, self.btn_setDualTracking)
        MainWindow.setTabOrder(self.btn_setDualTracking, self.btn_mountQuit)
        MainWindow.setTabOrder(self.btn_mountQuit, self.le_telescopeUnattendedFlip)
        MainWindow.setTabOrder(self.le_telescopeUnattendedFlip, self.btn_setUnattendedFlip)
        MainWindow.setTabOrder(self.btn_setUnattendedFlip, self.le_meridianLimitTrack)
        MainWindow.setTabOrder(self.le_meridianLimitTrack, self.le_meridianLimitSlew)
        MainWindow.setTabOrder(self.le_meridianLimitSlew, self.btn_flipMount)
        MainWindow.setTabOrder(self.btn_flipMount, self.le_horizonLimitLow)
        MainWindow.setTabOrder(self.le_horizonLimitLow, self.btn_setHorizonLimitLow)
        MainWindow.setTabOrder(self.btn_setHorizonLimitLow, self.le_horizonLimitHigh)
        MainWindow.setTabOrder(self.le_horizonLimitHigh, self.btn_setHorizonLimitHigh)
        MainWindow.setTabOrder(self.btn_setHorizonLimitHigh, self.btn_mountPos1)
        MainWindow.setTabOrder(self.btn_mountPos1, self.btn_mountPos2)
        MainWindow.setTabOrder(self.btn_mountPos2, self.btn_mountPos3)
        MainWindow.setTabOrder(self.btn_mountPos3, self.btn_mountPos4)
        MainWindow.setTabOrder(self.btn_mountPos4, self.btn_mountPos5)
        MainWindow.setTabOrder(self.btn_mountPos5, self.btn_mountPos6)
        MainWindow.setTabOrder(self.btn_mountPos6, self.btn_startTracking)
        MainWindow.setTabOrder(self.btn_startTracking, self.btn_stopTracking)
        MainWindow.setTabOrder(self.btn_stopTracking, self.btn_setTrackingLunar)
        MainWindow.setTabOrder(self.btn_setTrackingLunar, self.btn_setTrackingSolar)
        MainWindow.setTabOrder(self.btn_setTrackingSolar, self.btn_setTrackingSideral)
        MainWindow.setTabOrder(self.btn_setTrackingSideral, self.btn_mountPark)
        MainWindow.setTabOrder(self.btn_mountPark, self.btn_mountUnpark)
        MainWindow.setTabOrder(self.btn_mountUnpark, self.btn_stop)
        MainWindow.setTabOrder(self.btn_stop, self.btn_loadBasePoints)
        MainWindow.setTabOrder(self.btn_loadBasePoints, self.btn_generateBasePoints)
        MainWindow.setTabOrder(self.btn_generateBasePoints, self.altitudeBase)
        MainWindow.setTabOrder(self.altitudeBase, self.azimuthBase)
        MainWindow.setTabOrder(self.azimuthBase, self.checkUseBlindSolve)
        MainWindow.setTabOrder(self.checkUseBlindSolve, self.checkClearModelFirst)
        MainWindow.setTabOrder(self.checkClearModelFirst, self.btn_runBaseModel)
        MainWindow.setTabOrder(self.btn_runBaseModel, self.btn_loadRefinementPoints)
        MainWindow.setTabOrder(self.btn_loadRefinementPoints, self.btn_generateGridPoints)
        MainWindow.setTabOrder(self.btn_generateGridPoints, self.numberGridPointsRow)
        MainWindow.setTabOrder(self.numberGridPointsRow, self.numberGridPointsCol)
        MainWindow.setTabOrder(self.numberGridPointsCol, self.btn_generateDensePoints)
        MainWindow.setTabOrder(self.btn_generateDensePoints, self.btn_generateNormalPoints)
        MainWindow.setTabOrder(self.btn_generateNormalPoints, self.btn_generateDSOPoints)
        MainWindow.setTabOrder(self.btn_generateDSOPoints, self.numberHoursDSO)
        MainWindow.setTabOrder(self.numberHoursDSO, self.numberHoursPreview)
        MainWindow.setTabOrder(self.numberHoursPreview, self.numberPointsDSO)
        MainWindow.setTabOrder(self.numberPointsDSO, self.checkKeepRefinement)
        MainWindow.setTabOrder(self.checkKeepRefinement, self.btn_runRefinementModel)
        MainWindow.setTabOrder(self.btn_runRefinementModel, self.btn_runAllModel)
        MainWindow.setTabOrder(self.btn_runAllModel, self.btn_plateSolveSync)
        MainWindow.setTabOrder(self.btn_plateSolveSync, self.btn_openModelingPlotWindow)
        MainWindow.setTabOrder(self.btn_openModelingPlotWindow, self.btn_deletePoints)
        MainWindow.setTabOrder(self.btn_deletePoints, self.btn_clearAlignmentModel)
        MainWindow.setTabOrder(self.btn_clearAlignmentModel, self.btn_runCheckModel)
        MainWindow.setTabOrder(self.btn_runCheckModel, self.btn_cancelModel)
        MainWindow.setTabOrder(self.btn_cancelModel, self.altitudeTimeChange)
        MainWindow.setTabOrder(self.altitudeTimeChange, self.azimuthTimeChange)
        MainWindow.setTabOrder(self.azimuthTimeChange, self.numberRunsTimeChange)
        MainWindow.setTabOrder(self.numberRunsTimeChange, self.delayTimeTimeChange)
        MainWindow.setTabOrder(self.delayTimeTimeChange, self.btn_runTimeChangeModel)
        MainWindow.setTabOrder(self.btn_runTimeChangeModel, self.altitudeHysterese1)
        MainWindow.setTabOrder(self.altitudeHysterese1, self.azimuthHysterese1)
        MainWindow.setTabOrder(self.azimuthHysterese1, self.altitudeHysterese2)
        MainWindow.setTabOrder(self.altitudeHysterese2, self.azimuthHysterese2)
        MainWindow.setTabOrder(self.azimuthHysterese2, self.numberRunsHysterese)
        MainWindow.setTabOrder(self.numberRunsHysterese, self.delayTimeHysterese)
        MainWindow.setTabOrder(self.delayTimeHysterese, self.btn_runHystereseModel)
        MainWindow.setTabOrder(self.btn_runHystereseModel, self.btn_cancelAnalyseModel)
        MainWindow.setTabOrder(self.btn_cancelAnalyseModel, self.le_analyseFileName)
        MainWindow.setTabOrder(self.le_analyseFileName, self.btn_selectAnalyseFileName)
        MainWindow.setTabOrder(self.btn_selectAnalyseFileName, self.btn_openAnalyseWindow)
        MainWindow.setTabOrder(self.btn_openAnalyseWindow, self.btn_runBatchModel)
        MainWindow.setTabOrder(self.btn_runBatchModel, self.btn_showActualModel)
        MainWindow.setTabOrder(self.btn_showActualModel, self.btn_runTargetRMSAlignment)
        MainWindow.setTabOrder(self.btn_runTargetRMSAlignment, self.btn_deleteWorstPoint)
        MainWindow.setTabOrder(self.btn_deleteWorstPoint, self.checkPolarPlot)
        MainWindow.setTabOrder(self.checkPolarPlot, self.targetRMS)
        MainWindow.setTabOrder(self.targetRMS, self.alignErrorStars)
        MainWindow.setTabOrder(self.alignErrorStars, self.btn_saveBackupModel)
        MainWindow.setTabOrder(self.btn_saveBackupModel, self.btn_loadBackupModel)
        MainWindow.setTabOrder(self.btn_loadBackupModel, self.btn_saveBaseModel)
        MainWindow.setTabOrder(self.btn_saveBaseModel, self.btn_loadBaseModel)
        MainWindow.setTabOrder(self.btn_loadBaseModel, self.btn_saveRefinementModel)
        MainWindow.setTabOrder(self.btn_saveRefinementModel, self.btn_loadRefinementModel)
        MainWindow.setTabOrder(self.btn_loadRefinementModel, self.btn_saveSimpleModel)
        MainWindow.setTabOrder(self.btn_saveSimpleModel, self.btn_loadSimpleModel)
        MainWindow.setTabOrder(self.btn_loadSimpleModel, self.btn_saveDSO1Model)
        MainWindow.setTabOrder(self.btn_saveDSO1Model, self.btn_loadDSO1Model)
        MainWindow.setTabOrder(self.btn_loadDSO1Model, self.btn_saveDSO2Model)
        MainWindow.setTabOrder(self.btn_saveDSO2Model, self.btn_loadDSO2Model)
        MainWindow.setTabOrder(self.btn_loadDSO2Model, self.btn_setRefractionCorrection)
        MainWindow.setTabOrder(self.btn_setRefractionCorrection, self.checkAutoRefractionCamera)
        MainWindow.setTabOrder(self.checkAutoRefractionCamera, self.btn_setRefractionParameters)
        MainWindow.setTabOrder(self.btn_setRefractionParameters, self.btn_setupMountDriver)
        MainWindow.setTabOrder(self.btn_setupMountDriver, self.le_parkPos1Text)
        MainWindow.setTabOrder(self.le_parkPos1Text, self.le_azParkPos1)
        MainWindow.setTabOrder(self.le_azParkPos1, self.le_altParkPos1)
        MainWindow.setTabOrder(self.le_altParkPos1, self.le_parkPos2Text)
        MainWindow.setTabOrder(self.le_parkPos2Text, self.le_azParkPos2)
        MainWindow.setTabOrder(self.le_azParkPos2, self.le_altParkPos2)
        MainWindow.setTabOrder(self.le_altParkPos2, self.le_parkPos3Text)
        MainWindow.setTabOrder(self.le_parkPos3Text, self.le_azParkPos3)
        MainWindow.setTabOrder(self.le_azParkPos3, self.le_altParkPos3)
        MainWindow.setTabOrder(self.le_altParkPos3, self.le_parkPos4Text)
        MainWindow.setTabOrder(self.le_parkPos4Text, self.le_azParkPos4)
        MainWindow.setTabOrder(self.le_azParkPos4, self.le_altParkPos4)
        MainWindow.setTabOrder(self.le_altParkPos4, self.le_parkPos5Text)
        MainWindow.setTabOrder(self.le_parkPos5Text, self.le_azParkPos5)
        MainWindow.setTabOrder(self.le_azParkPos5, self.le_altParkPos5)
        MainWindow.setTabOrder(self.le_altParkPos5, self.le_parkPos6Text)
        MainWindow.setTabOrder(self.le_parkPos6Text, self.le_azParkPos6)
        MainWindow.setTabOrder(self.le_azParkPos6, self.le_altParkPos6)
        MainWindow.setTabOrder(self.le_altParkPos6, self.btn_downloadEarthrotation)
        MainWindow.setTabOrder(self.btn_downloadEarthrotation, self.btn_downloadSpacestations)
        MainWindow.setTabOrder(self.btn_downloadSpacestations, self.btn_downloadSatbrighest)
        MainWindow.setTabOrder(self.btn_downloadSatbrighest, self.btn_downloadAsteroidsMPC5000)
        MainWindow.setTabOrder(self.btn_downloadAsteroidsMPC5000, self.btn_downloadComets)
        MainWindow.setTabOrder(self.btn_downloadComets, self.btn_downloadAll)
        MainWindow.setTabOrder(self.btn_downloadAll, self.checkEarthrotation)
        MainWindow.setTabOrder(self.checkEarthrotation, self.checkTLE)
        MainWindow.setTabOrder(self.checkTLE, self.checkAsteroids)
        MainWindow.setTabOrder(self.checkAsteroids, self.checkComets)
        MainWindow.setTabOrder(self.checkComets, self.btn_uploadMount)
        MainWindow.setTabOrder(self.btn_uploadMount, self.btn_driverMountConnected)
        MainWindow.setTabOrder(self.btn_driverMountConnected, self.btn_domeConnected)
        MainWindow.setTabOrder(self.btn_domeConnected, self.btn_camPlateConnected)
        MainWindow.setTabOrder(self.btn_camPlateConnected, self.errorStatus)
        MainWindow.setTabOrder(self.errorStatus, self.settingsTabWidget)
        MainWindow.setTabOrder(self.settingsTabWidget, self.btn_relay3)
        MainWindow.setTabOrder(self.btn_relay3, self.btn_relay2)
        MainWindow.setTabOrder(self.btn_relay2, self.btn_relay1)
        MainWindow.setTabOrder(self.btn_relay1, self.altitudeMax)
        MainWindow.setTabOrder(self.altitudeMax, self.altitudeMin)
        MainWindow.setTabOrder(self.altitudeMin, self.checkFastDownload)
        MainWindow.setTabOrder(self.checkFastDownload, self.checkKeepImages)
        MainWindow.setTabOrder(self.checkKeepImages, self.cameraBin)
        MainWindow.setTabOrder(self.cameraBin, self.scaleSubframe)
        MainWindow.setTabOrder(self.scaleSubframe, self.isoSetting)
        MainWindow.setTabOrder(self.isoSetting, self.checkDoSubframe)
        MainWindow.setTabOrder(self.checkDoSubframe, self.pixelSize)
        MainWindow.setTabOrder(self.pixelSize, self.focalLength)
        MainWindow.setTabOrder(self.focalLength, self.cameraExposure)
        MainWindow.setTabOrder(self.cameraExposure, self.settlingTime)
        MainWindow.setTabOrder(self.settlingTime, self.checkRemoteAccess)
        MainWindow.setTabOrder(self.checkRemoteAccess, self.checkFilterMPC)
        MainWindow.setTabOrder(self.checkFilterMPC, self.le_filterExpressionMPC)
        MainWindow.setTabOrder(self.le_filterExpressionMPC, self.btn_downloadAsteroidsNEA)
        MainWindow.setTabOrder(self.btn_downloadAsteroidsNEA, self.btn_downloadAsteroidsTNO)
        MainWindow.setTabOrder(self.btn_downloadAsteroidsTNO, self.btn_downloadAsteroidsPHA)
        MainWindow.setTabOrder(self.btn_downloadAsteroidsPHA, self.btn_mountSave)
        MainWindow.setTabOrder(self.btn_mountSave, self.relay1Text)
        MainWindow.setTabOrder(self.relay1Text, self.relay2Text)
        MainWindow.setTabOrder(self.relay2Text, self.relay3Text)
        MainWindow.setTabOrder(self.relay3Text, self.relay4Text)
        MainWindow.setTabOrder(self.relay4Text, self.relay5Text)
        MainWindow.setTabOrder(self.relay5Text, self.relay6Text)
        MainWindow.setTabOrder(self.relay6Text, self.relay7Text)
        MainWindow.setTabOrder(self.relay7Text, self.relay8Text)
        MainWindow.setTabOrder(self.relay8Text, self.btn_relay5)
        MainWindow.setTabOrder(self.btn_relay5, self.btn_relay4)
        MainWindow.setTabOrder(self.btn_relay4, self.le_relayIP)
        MainWindow.setTabOrder(self.le_relayIP, self.btn_relay6)
        MainWindow.setTabOrder(self.btn_relay6, self.btn_relay7)
        MainWindow.setTabOrder(self.btn_relay7, self.btn_relay8)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Mount Command Window (C) MW 2016,2017"))
        self.le_mountStatus.setToolTip(_translate("MainWindow", "Status feedback from mount "))
        self.le_mountStatus.setText(_translate("MainWindow", "Mount Status"))
        self.mainTabWidget.setToolTip(_translate("MainWindow", "Tab section"))
        self.le_telescopeRA.setToolTip(_translate("MainWindow", "<html><head/><body><p>Right Ascention in J2000</p></body></html>"))
        self.le_telescopeRA.setText(_translate("MainWindow", "RA"))
        self.le_telescopeAzimut.setToolTip(_translate("MainWindow", "<html><head/><body><p>Azimuth</p></body></html>"))
        self.le_telescopeAzimut.setText(_translate("MainWindow", "AZ"))
        self.le_telescopeDEC.setToolTip(_translate("MainWindow", "<html><head/><body><p>Declination in J2000</p></body></html>"))
        self.le_telescopeDEC.setText(_translate("MainWindow", "DEC"))
        self.le_telescopeAltitude.setToolTip(_translate("MainWindow", "<html><head/><body><p>Altitude</p></body></html>"))
        self.le_telescopeAltitude.setText(_translate("MainWindow", "ALT"))
        self.label_9.setText(_translate("MainWindow", "Telescope AZ (Deg)"))
        self.label_10.setText(_translate("MainWindow", "Telescope DEC (DMS)"))
        self.label_8.setText(_translate("MainWindow", "Telescope ALT (Deg)"))
        self.label_11.setText(_translate("MainWindow", "Telescope RA (HMS)"))
        self.label_17.setText(_translate("MainWindow", "Slew Rate"))
        self.le_meridianLimitTrack.setInputMask(_translate("MainWindow", "#9"))
        self.le_meridianLimitTrack.setText(_translate("MainWindow", "10"))
        self.le_telescopePierSide.setToolTip(_translate("MainWindow", "Pier side"))
        self.le_telescopePierSide.setText(_translate("MainWindow", "WEST"))
        self.label_18.setText(_translate("MainWindow", "Pier"))
        self.label_21.setText(_translate("MainWindow", "Dual Tracking"))
        self.le_telescopeDualTrack.setToolTip(_translate("MainWindow", "Status of dual tracking"))
        self.le_telescopeDualTrack.setText(_translate("MainWindow", "ON"))
        self.btn_setDualTracking.setToolTip(_translate("MainWindow", "Sets dual tracking on / off"))
        self.btn_setDualTracking.setText(_translate("MainWindow", "I/O"))
        self.label_52.setText(_translate("MainWindow", "Time to Flip"))
        self.le_timeToFlip.setToolTip(_translate("MainWindow", "Time until tracking ends because of flip / horizon limit"))
        self.le_timeToFlip.setText(_translate("MainWindow", "1234"))
        self.btn_setUnattendedFlip.setToolTip(_translate("MainWindow", "Sets unattended flip on / off"))
        self.btn_setUnattendedFlip.setText(_translate("MainWindow", "I/O"))
        self.le_telescopeUnattendedFlip.setToolTip(_translate("MainWindow", "Status of unattended Flip"))
        self.le_telescopeUnattendedFlip.setText(_translate("MainWindow", "ON"))
        self.label_23.setText(_translate("MainWindow", "Unattended Flip"))
        self.label_61.setText(_translate("MainWindow", "min"))
        self.label_62.setText(_translate("MainWindow", "°/s"))
        self.label_80.setText(_translate("MainWindow", "Tracking"))
        self.label_81.setText(_translate("MainWindow", "Pointing Coordinates"))
        self.btn_startTracking.setToolTip(_translate("MainWindow", "Start tracking the mount"))
        self.btn_startTracking.setText(_translate("MainWindow", "Start Tracking"))
        self.btn_mountPark.setToolTip(_translate("MainWindow", "PArk mount in default position"))
        self.btn_mountPark.setText(_translate("MainWindow", "Park"))
        self.btn_mountUnpark.setToolTip(_translate("MainWindow", "Unpark the mount"))
        self.btn_mountUnpark.setText(_translate("MainWindow", "Unpark"))
        self.label_83.setText(_translate("MainWindow", "Defined Positions"))
        self.label_84.setText(_translate("MainWindow", "Tracking"))
        self.btn_mountPos4.setText(_translate("MainWindow", "Park Pos4"))
        self.label_85.setText(_translate("MainWindow", "Parking"))
        self.btn_mountPos2.setText(_translate("MainWindow", "Park Pos2"))
        self.btn_mountPos3.setText(_translate("MainWindow", "Park Pos3"))
        self.btn_mountPos1.setText(_translate("MainWindow", "Park Pos1"))
        self.btn_stopTracking.setToolTip(_translate("MainWindow", "Stop tracking mount"))
        self.btn_stopTracking.setText(_translate("MainWindow", "Stop Tracking"))
        self.btn_stop.setToolTip(_translate("MainWindow", "Stops all mount movements immediatly"))
        self.btn_stop.setText(_translate("MainWindow", "STOP MOUNT"))
        self.btn_flipMount.setToolTip(_translate("MainWindow", "Flips the mount if possible"))
        self.btn_flipMount.setText(_translate("MainWindow", "Meridian Flip Now"))
        self.btn_setTrackingLunar.setToolTip(_translate("MainWindow", "Set tracking speed to lunar"))
        self.btn_setTrackingLunar.setText(_translate("MainWindow", "Lunar"))
        self.btn_setTrackingSolar.setToolTip(_translate("MainWindow", "Set tracking speed to solar"))
        self.btn_setTrackingSolar.setText(_translate("MainWindow", "Solar"))
        self.btn_setTrackingSideral.setToolTip(_translate("MainWindow", "Set tracking speed to sideral"))
        self.btn_setTrackingSideral.setText(_translate("MainWindow", "Sideral"))
        self.label_100.setText(_translate("MainWindow", "Side"))
        self.label_34.setText(_translate("MainWindow", "Meridian Limit Track"))
        self.label_65.setText(_translate("MainWindow", "Meridian Limit Slew"))
        self.le_meridianLimitSlew.setInputMask(_translate("MainWindow", "#9"))
        self.le_meridianLimitSlew.setText(_translate("MainWindow", "10"))
        self.label_88.setText(_translate("MainWindow", "°"))
        self.label_89.setText(_translate("MainWindow", "°"))
        self.le_slewRate.setInputMask(_translate("MainWindow", "99"))
        self.le_slewRate.setText(_translate("MainWindow", "10"))
        self.label_90.setText(_translate("MainWindow", "Time to Meridian"))
        self.le_timeToMeridian.setToolTip(_translate("MainWindow", "Time until tracking ends because of flip / horizon limit"))
        self.le_timeToMeridian.setText(_translate("MainWindow", "1234"))
        self.label_91.setText(_translate("MainWindow", "min"))
        self.btn_mountPos6.setText(_translate("MainWindow", "Park Pos6"))
        self.btn_mountPos5.setText(_translate("MainWindow", "Park Pos5"))
        self.btn_setSlewRate.setToolTip(_translate("MainWindow", "Sets the horion limit low"))
        self.btn_setSlewRate.setText(_translate("MainWindow", "Set"))
        self.label_20.setText(_translate("MainWindow", "Horizonlim. high"))
        self.le_horizonLimitHigh.setToolTip(_translate("MainWindow", "Actual horizon limit for slewing higher bound"))
        self.le_horizonLimitHigh.setInputMask(_translate("MainWindow", "#99"))
        self.le_horizonLimitHigh.setText(_translate("MainWindow", "090"))
        self.label_4.setText(_translate("MainWindow", "Horionlim. low"))
        self.btn_setHorizonLimitLow.setToolTip(_translate("MainWindow", "Sets the horion limit low"))
        self.btn_setHorizonLimitLow.setText(_translate("MainWindow", "Set"))
        self.label_60.setText(_translate("MainWindow", "°"))
        self.le_horizonLimitLow.setToolTip(_translate("MainWindow", "Actual horizon limit for slewing lower bound"))
        self.le_horizonLimitLow.setInputMask(_translate("MainWindow", "#99"))
        self.le_horizonLimitLow.setText(_translate("MainWindow", "000"))
        self.label_59.setText(_translate("MainWindow", "Slewing Limits"))
        self.label_42.setText(_translate("MainWindow", "°"))
        self.btn_setHorizonLimitHigh.setToolTip(_translate("MainWindow", "Sets the horizon limit high"))
        self.btn_setHorizonLimitHigh.setText(_translate("MainWindow", "Set"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab_2), _translate("MainWindow", "Pointing"))
        self.le_siteElevation.setText(_translate("MainWindow", "0000.0"))
        self.label_5.setText(_translate("MainWindow", "Site Longitude"))
        self.le_siteLongitude.setText(_translate("MainWindow", "0000000000"))
        self.label_6.setText(_translate("MainWindow", "Site Latitude"))
        self.le_localSiderealTime.setText(_translate("MainWindow", "00:00:00.00"))
        self.label_7.setText(_translate("MainWindow", "Local Sidereal Time "))
        self.le_siteLatitude.setText(_translate("MainWindow", "0000000000"))
        self.label_12.setText(_translate("MainWindow", "Site Elevation"))
        self.label_58.setText(_translate("MainWindow", "Coordinates from Mount"))
        self.label_16.setText(_translate("MainWindow", "measurement is on both axes same"))
        self.le_telescopeTempDECMotor.setToolTip(_translate("MainWindow", "Temperatur of DEC motor in mount"))
        self.le_telescopeTempDECMotor.setText(_translate("MainWindow", "00.0"))
        self.label_55.setText(_translate("MainWindow", "Temperature Motor Driver Circuit"))
        self.label_64.setText(_translate("MainWindow", "°C"))
        self.le_windSpeed.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_windSpeed.setText(_translate("MainWindow", "---"))
        self.label_32.setText(_translate("MainWindow", "WindSpeed"))
        self.label_73.setText(_translate("MainWindow", "hPa"))
        self.le_temperature.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_temperature.setText(_translate("MainWindow", "---"))
        self.label_25.setText(_translate("MainWindow", "DewPoint"))
        self.label_31.setText(_translate("MainWindow", "Rain Rate"))
        self.label_70.setText(_translate("MainWindow", "°C"))
        self.label_68.setText(_translate("MainWindow", "%"))
        self.label_26.setText(_translate("MainWindow", "Humidity"))
        self.le_refractionTemperature.setToolTip(_translate("MainWindow", "shows the refraction temperature used in mount"))
        self.le_humidity.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_humidity.setText(_translate("MainWindow", "---"))
        self.le_cloudCover.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_cloudCover.setText(_translate("MainWindow", "---"))
        self.label_67.setText(_translate("MainWindow", "m/s"))
        self.btn_setRefractionParameters.setToolTip(_translate("MainWindow", "Pushes the refraction temp and pressur to mount"))
        self.btn_setRefractionParameters.setText(_translate("MainWindow", "Push Parameters to Mount manually"))
        self.le_dewPoint.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_dewPoint.setText(_translate("MainWindow", "---"))
        self.label_71.setText(_translate("MainWindow", "°C"))
        self.le_windDirection.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_windDirection.setText(_translate("MainWindow", "---"))
        self.label_33.setText(_translate("MainWindow", "WindDirect."))
        self.label_30.setText(_translate("MainWindow", "CloudCover"))
        self.label_24.setText(_translate("MainWindow", "Airtemp."))
        self.label_22.setText(_translate("MainWindow", "Refraction correction in mount computer is"))
        self.label_27.setText(_translate("MainWindow", "Pressure"))
        self.label_57.setText(_translate("MainWindow", "Environment Conditions"))
        self.le_refractionPressure.setToolTip(_translate("MainWindow", "shows the refraction pressure used in mount"))
        self.le_rainRate.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_rainRate.setText(_translate("MainWindow", "---"))
        self.label_66.setText(_translate("MainWindow", "°"))
        self.le_pressure.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_pressure.setText(_translate("MainWindow", "---"))
        self.le_refractionStatus.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_refractionStatus.setText(_translate("MainWindow", "ON"))
        self.label_13.setText(_translate("MainWindow", "Data in mount"))
        self.label_72.setText(_translate("MainWindow", "%"))
        self.label_69.setText(_translate("MainWindow", "%"))
        self.label_78.setText(_translate("MainWindow", "hPa"))
        self.label_82.setText(_translate("MainWindow", "m"))
        self.checkAutoRefractionCamera.setToolTip(_translate("MainWindow", "sets the refraction param updates to automatic"))
        self.checkAutoRefractionCamera.setText(_translate("MainWindow", "Camera is IDLE"))
        self.label_86.setText(_translate("MainWindow", "Refraction Correction in Mount"))
        self.btn_setRefractionCorrection.setToolTip(_translate("MainWindow", "Sets refraction correction in mount on / off"))
        self.btn_setRefractionCorrection.setText(_translate("MainWindow", "I/O"))
        self.label_105.setText(_translate("MainWindow", "DMS"))
        self.label_106.setText(_translate("MainWindow", "DMS"))
        self.label_79.setText(_translate("MainWindow", "°C"))
        self.label_142.setText(_translate("MainWindow", "SQR"))
        self.le_SQR.setToolTip(_translate("MainWindow", "shows the refraction correction status on / off"))
        self.le_SQR.setText(_translate("MainWindow", "---"))
        self.label_87.setText(_translate("MainWindow", "mpas"))
        self.label_63.setText(_translate("MainWindow", "Julian Date"))
        self.le_JulianDate.setText(_translate("MainWindow", "0000000.00000"))
        self.label_151.setText(_translate("MainWindow", "UTC DataUploadToMount is"))
        self.le_UTCDataExpirationDate.setToolTip(_translate("MainWindow", "<html><head/><body><p>Expiration date of UTC data</p></body></html>"))
        self.le_UTCDataExpirationDate.setText(_translate("MainWindow", "-----"))
        self.label_152.setText(_translate("MainWindow", "and expires on "))
        self.le_UTCDataValid.setToolTip(_translate("MainWindow", "<html><head/><body><p>Status of UTC data</p></body></html>"))
        self.le_UTCDataValid.setText(_translate("MainWindow", "-----"))
        self.label_74.setText(_translate("MainWindow", "Actuality of Time Data"))
        self.checkAutoRefractionNotTracking.setToolTip(_translate("MainWindow", "sets the refraction param updates to automatic"))
        self.checkAutoRefractionNotTracking.setText(_translate("MainWindow", "Mount is not tracking"))
        self.label_135.setText(_translate("MainWindow", "Periodic refraction data update"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab_4), _translate("MainWindow", "Site Conditions"))
        self.btn_runBaseModel.setToolTip(_translate("MainWindow", "Runs the base model, if ther are any points"))
        self.btn_runBaseModel.setText(_translate("MainWindow", "Run Base Model"))
        self.checkUseBlindSolve.setToolTip(_translate("MainWindow", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkUseBlindSolve.setText(_translate("MainWindow", "Use Blind Solve"))
        self.btn_clearAlignmentModel.setToolTip(_translate("MainWindow", "Clear the model in mount. Can\'t be revised."))
        self.btn_clearAlignmentModel.setText(_translate("MainWindow", "Clear Pointing Model in Mount"))
        self.btn_loadBasePoints.setToolTip(_translate("MainWindow", "Shows the base points of model point file"))
        self.btn_loadBasePoints.setText(_translate("MainWindow", "Basepoints from File"))
        self.btn_generateBasePoints.setToolTip(_translate("MainWindow", "Generates Basepoint based on Altitude and AZ"))
        self.btn_generateBasePoints.setText(_translate("MainWindow", "Generate Basepoints"))
        self.label_170.setText(_translate("MainWindow", "Altitude"))
        self.label_171.setText(_translate("MainWindow", "Azimuth"))
        self.label_109.setText(_translate("MainWindow", "°"))
        self.label_110.setText(_translate("MainWindow", "°"))
        self.label_116.setText(_translate("MainWindow", "Generate Base Points"))
        self.btn_openModelingPlotWindow.setToolTip(_translate("MainWindow", "<html><head/><body><p>Opens the coordinate an model points popup window</p></body></html>"))
        self.btn_openModelingPlotWindow.setText(_translate("MainWindow", "Open Modeling Plot Window"))
        self.btn_generateGridPoints.setToolTip(_translate("MainWindow", "Generates a regular pattern with 100 stars"))
        self.btn_generateGridPoints.setText(_translate("MainWindow", "Grid Points"))
        self.label_108.setText(_translate("MainWindow", "Generate Refinement Points"))
        self.label_179.setText(_translate("MainWindow", "Columns"))
        self.label_178.setText(_translate("MainWindow", "Rows"))
        self.btn_generateNormalPoints.setToolTip(_translate("MainWindow", "Generates a pointcloud with greater circles medium number"))
        self.btn_generateNormalPoints.setText(_translate("MainWindow", "Pointcloud Normal"))
        self.btn_generateDensePoints.setToolTip(_translate("MainWindow", "Generates a pointcloud with greater circles high number"))
        self.btn_generateDensePoints.setText(_translate("MainWindow", "Pointcloud Dense"))
        self.numberGridPointsRow.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of rows in the grid build</p></body></html>"))
        self.numberGridPointsCol.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of coloms in the grid build</p></body></html>"))
        self.btn_runRefinementModel.setToolTip(_translate("MainWindow", "Run refinment model"))
        self.btn_runRefinementModel.setText(_translate("MainWindow", "Run Refinement Model"))
        self.btn_loadRefinementPoints.setToolTip(_translate("MainWindow", "Shows the refinment point of the model point file."))
        self.btn_loadRefinementPoints.setText(_translate("MainWindow", "Refinepoints from File"))
        self.btn_cancelModel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Cancels any model run in the next cycle (next point)</p></body></html>"))
        self.btn_cancelModel.setText(_translate("MainWindow", "Cancel any Model Run"))
        self.btn_runCheckModel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Runs a analyse cycle without updating the mount model</p></body></html>"))
        self.btn_runCheckModel.setText(_translate("MainWindow", "Run Model Check (Simulation)"))
        self.label_98.setText(_translate("MainWindow", "Model Check Run - (Base & Refine Points)"))
        self.btn_generateDSOPoints.setToolTip(_translate("MainWindow", "<html><head/><body><p>Generates a given number of refinement points along DSO track for a give time</p></body></html>"))
        self.btn_generateDSOPoints.setText(_translate("MainWindow", "Generate DSO Track"))
        self.label_113.setText(_translate("MainWindow", "General Functions"))
        self.btn_deletePoints.setToolTip(_translate("MainWindow", "<html><head/><body><p>Delete all points on coordinate window including Base / Model</p></body></html>"))
        self.btn_deletePoints.setText(_translate("MainWindow", "Clear Points in Modeling Plot Window"))
        self.btn_runAllModel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Run base and refinement model directly after another</p></body></html>"))
        self.btn_runAllModel.setText(_translate("MainWindow", "Run Base and Refinement Model together"))
        self.numberHoursDSO.setToolTip(_translate("MainWindow", "<html><head/><body><p>Length of the DSO track in hours.</p></body></html>"))
        self.label_181.setText(_translate("MainWindow", "Hours"))
        self.label_188.setText(_translate("MainWindow", "Points"))
        self.numberPointsDSO.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of points in the DSO track for the given time in hours</p></body></html>"))
        self.label_189.setText(_translate("MainWindow", "TimeShift [h]"))
        self.numberHoursPreview.setToolTip(_translate("MainWindow", "<html><head/><body><p>Length of the DSO track in hours.</p></body></html>"))
        self.btn_plateSolveSync.setToolTip(_translate("MainWindow", "<html><head/><body><p>Image, Platesolve and Sync the model of the mount</p></body></html>"))
        self.btn_plateSolveSync.setText(_translate("MainWindow", "Plate Solve and Sync Model"))
        self.checkClearModelFirst.setToolTip(_translate("MainWindow", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkClearModelFirst.setText(_translate("MainWindow", "Clear Model first"))
        self.checkKeepRefinement.setToolTip(_translate("MainWindow", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkKeepRefinement.setText(_translate("MainWindow", "Keep Refinement Model"))
        self.label_180.setText(_translate("MainWindow", "Alt Max"))
        self.altitudeMax.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of coloms in the grid build</p></body></html>"))
        self.altitudeMin.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of rows in the grid build</p></body></html>"))
        self.label_190.setText(_translate("MainWindow", "Alt Min"))
        self.btn_openImageWindow.setToolTip(_translate("MainWindow", "<html><head/><body><p>Opens the coordinate an model points popup window</p></body></html>"))
        self.btn_openImageWindow.setText(_translate("MainWindow", "Open Image Window"))
        self.checkDeletePointsHorizonMask.setToolTip(_translate("MainWindow", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkDeletePointsHorizonMask.setText(_translate("MainWindow", "Delete points below horizon mask"))
        self.checkSortPoints.setToolTip(_translate("MainWindow", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkSortPoints.setText(_translate("MainWindow", "Sort points East / West"))
        self.checkSimulation.setToolTip(_translate("MainWindow", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkSimulation.setText(_translate("MainWindow", "Do Simulation"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab_6), _translate("MainWindow", "Make Mount Model"))
        self.le_alignNumberStars.setToolTip(_translate("MainWindow", "Number of alignment stars in actual used pointing model"))
        self.le_alignNumberStars.setText(_translate("MainWindow", "NN"))
        self.label.setText(_translate("MainWindow", "Number Stars"))
        self.le_alignErrorRMS.setToolTip(_translate("MainWindow", "<html><head/><body><p>Actual RMS Error in arc sec</p><p><br/></p></body></html>"))
        self.le_alignErrorRMS.setText(_translate("MainWindow", "NN.N"))
        self.label_14.setText(_translate("MainWindow", "RMS"))
        self.btn_showActualModel.setToolTip(_translate("MainWindow", "Download actual model from mount"))
        self.btn_showActualModel.setText(_translate("MainWindow", "Show Actual Model"))
        self.label_37.setText(_translate("MainWindow", "Target"))
        self.btn_runTargetRMSAlignment.setToolTip(_translate("MainWindow", "Deletes worst point of actual model until error is below target RMS"))
        self.btn_runTargetRMSAlignment.setText(_translate("MainWindow", "Run Optimise"))
        self.btn_saveBackupModel.setToolTip(_translate("MainWindow", "Saves actual model und name \"BACKUP\" in mount"))
        self.btn_saveBackupModel.setText(_translate("MainWindow", "Save"))
        self.btn_loadBackupModel.setToolTip(_translate("MainWindow", "Restores the actual model from stored model with name \"BACKUP\""))
        self.btn_loadBackupModel.setText(_translate("MainWindow", "Load"))
        self.btn_loadSimpleModel.setToolTip(_translate("MainWindow", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadSimpleModel.setText(_translate("MainWindow", "Load"))
        self.btn_saveSimpleModel.setToolTip(_translate("MainWindow", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveSimpleModel.setText(_translate("MainWindow", "Save"))
        self.btn_deleteWorstPoint.setToolTip(_translate("MainWindow", "<html><head/><body><p>Deletes worst point of actual model.</p></body></html>"))
        self.btn_deleteWorstPoint.setText(_translate("MainWindow", "Delete worst Point"))
        self.label_124.setText(_translate("MainWindow", "Optimise Actual Model"))
        self.label_125.setText(_translate("MainWindow", "Load / Save Model in Mount Computer"))
        self.btn_loadBaseModel.setToolTip(_translate("MainWindow", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadBaseModel.setText(_translate("MainWindow", "Load"))
        self.btn_saveBaseModel.setToolTip(_translate("MainWindow", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveBaseModel.setText(_translate("MainWindow", "Save"))
        self.label_126.setText(_translate("MainWindow", "BACKUP"))
        self.label_127.setText(_translate("MainWindow", "BASE"))
        self.label_128.setText(_translate("MainWindow", "SIMPLE"))
        self.btn_saveDSO1Model.setToolTip(_translate("MainWindow", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveDSO1Model.setText(_translate("MainWindow", "Save"))
        self.btn_loadDSO1Model.setToolTip(_translate("MainWindow", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadDSO1Model.setText(_translate("MainWindow", "Load"))
        self.btn_saveDSO2Model.setToolTip(_translate("MainWindow", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveDSO2Model.setText(_translate("MainWindow", "Save"))
        self.btn_loadDSO2Model.setToolTip(_translate("MainWindow", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadDSO2Model.setText(_translate("MainWindow", "Load"))
        self.label_129.setText(_translate("MainWindow", "DSO 1"))
        self.label_130.setText(_translate("MainWindow", "DSO 2"))
        self.btn_saveRefinementModel.setToolTip(_translate("MainWindow", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveRefinementModel.setText(_translate("MainWindow", "Save"))
        self.label_133.setText(_translate("MainWindow", "REFINE"))
        self.btn_loadRefinementModel.setToolTip(_translate("MainWindow", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadRefinementModel.setText(_translate("MainWindow", "Load"))
        self.checkPolarPlot.setToolTip(_translate("MainWindow", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkPolarPlot.setText(_translate("MainWindow", "Polar Plot"))
        self.le_alignErrorPolar.setToolTip(_translate("MainWindow", "<html><head/><body><p>Actual Polar Error</p></body></html>"))
        self.le_alignErrorPolar.setText(_translate("MainWindow", "HH:MM:SS"))
        self.label_15.setText(_translate("MainWindow", "Polar "))
        self.label_153.setText(_translate("MainWindow", "Ortho"))
        self.le_alignErrorOrtho.setToolTip(_translate("MainWindow", "<html><head/><body><p>Actual Ortho Error</p></body></html>"))
        self.le_alignErrorOrtho.setText(_translate("MainWindow", "HH:MM:SS"))
        self.label_154.setText(_translate("MainWindow", "Number Terms"))
        self.le_alignNumberTerms.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of Terms in actual used pointing model</p></body></html>"))
        self.le_alignNumberTerms.setText(_translate("MainWindow", "NN"))
        self.label_155.setText(_translate("MainWindow", "Actual Model Status from Mount Computer"))
        self.label_156.setText(_translate("MainWindow", "Turn AZ"))
        self.le_alignKnobTurnAz.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of Turns azimuth ajustment knobs for correction (left if polar axis has to be moved to the left) </p></body></html>"))
        self.le_alignKnobTurnAz.setText(_translate("MainWindow", "NN.NN"))
        self.label_157.setText(_translate("MainWindow", "Turn Alt"))
        self.le_alignKnobTurnAlt.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of Turns altitude ajustment knobs for correction (down if the polar axis has to be moved downwards) </p></body></html>"))
        self.le_alignKnobTurnAlt.setText(_translate("MainWindow", "NN.NN"))
        self.label_158.setText(_translate("MainWindow", "AZ"))
        self.label_159.setText(_translate("MainWindow", "ALT"))
        self.le_alignErrorAz.setToolTip(_translate("MainWindow", "<html><head/><body><p>Actual Polar Error</p></body></html>"))
        self.le_alignErrorAz.setText(_translate("MainWindow", "HH:MM:SS"))
        self.le_alignErrorAlt.setToolTip(_translate("MainWindow", "<html><head/><body><p>Actual Ortho Error</p></body></html>"))
        self.le_alignErrorAlt.setText(_translate("MainWindow", "HH:MM:SS"))
        self.le_alignErrorPosAngle.setToolTip(_translate("MainWindow", "<html><head/><body><p>Actual RMS Error in arc sec</p><p><br/></p></body></html>"))
        self.le_alignErrorPosAngle.setText(_translate("MainWindow", "NN.N"))
        self.label_160.setText(_translate("MainWindow", "PosAngle"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab_8), _translate("MainWindow", "Manage Mount Models"))
        self.label_107.setText(_translate("MainWindow", "Analyse - Time Flexure"))
        self.btn_cancelAnalyseModel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Cancels a analyse cycle by constant pointing alt/az and measuring the error (next point)</p></body></html>"))
        self.btn_cancelAnalyseModel.setText(_translate("MainWindow", "Cancel any Analyse Run"))
        self.btn_runTimeChangeModel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Runs a analyse cycle by constant pointing alt/az and measuring the error</p></body></html>"))
        self.btn_runTimeChangeModel.setText(_translate("MainWindow", "Run Time Flexure"))
        self.label_174.setText(_translate("MainWindow", "Altitude"))
        self.label_175.setText(_translate("MainWindow", "Azimuth"))
        self.label_176.setText(_translate("MainWindow", "Number Cycles"))
        self.label_111.setText(_translate("MainWindow", "°"))
        self.label_112.setText(_translate("MainWindow", "°"))
        self.label_177.setText(_translate("MainWindow", "Delay"))
        self.label_115.setText(_translate("MainWindow", "s"))
        self.label_118.setText(_translate("MainWindow", "Analyse - Hysterese"))
        self.btn_runHystereseModel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Runs a analyse cycle by swapping two alt/az positions and measuring the error</p></body></html>"))
        self.btn_runHystereseModel.setText(_translate("MainWindow", "Run Hysteresis"))
        self.le_analyseFileName.setToolTip(_translate("MainWindow", "Name of Analysis file, where the data ist stored"))
        self.btn_openAnalyseWindow.setToolTip(_translate("MainWindow", "<html><head/><body><p>Opens the analyse Popup Window</p></body></html>"))
        self.btn_openAnalyseWindow.setText(_translate("MainWindow", "Open Analyse Window"))
        self.btn_selectAnalyseFileName.setToolTip(_translate("MainWindow", "<html><head/><body><p>Selects the file, where the analyse data is stored</p></body></html>"))
        self.btn_selectAnalyseFileName.setText(_translate("MainWindow", "Select File"))
        self.label_99.setText(_translate("MainWindow", "Select Analyse File"))
        self.label_182.setText(_translate("MainWindow", "Azimuth"))
        self.label_183.setText(_translate("MainWindow", "Number Cycles"))
        self.label_184.setText(_translate("MainWindow", "Delay"))
        self.label_117.setText(_translate("MainWindow", "s"))
        self.label_114.setText(_translate("MainWindow", "°"))
        self.label_119.setText(_translate("MainWindow", "°"))
        self.label_185.setText(_translate("MainWindow", "Point 1    Altitude"))
        self.label_120.setText(_translate("MainWindow", "°"))
        self.label_121.setText(_translate("MainWindow", "°"))
        self.label_186.setText(_translate("MainWindow", "Azimuth"))
        self.label_187.setText(_translate("MainWindow", "Point 2    Altitude"))
        self.btn_runBatchModel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Generates a new pointing model from stored analyse data</p></body></html>"))
        self.btn_runBatchModel.setText(_translate("MainWindow", "Make Mount Model from Analyse Data"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab_5), _translate("MainWindow", "Model Analyse"))
        self.btn_relay1.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay1.setText(_translate("MainWindow", "Relay1"))
        self.btn_relay3.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay3.setText(_translate("MainWindow", "Relay3"))
        self.btn_relay2.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay2.setText(_translate("MainWindow", "Relay2"))
        self.label_96.setText(_translate("MainWindow", "Relays"))
        self.btn_relay4.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay4.setText(_translate("MainWindow", "Relay4"))
        self.btn_relay5.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay5.setText(_translate("MainWindow", "Relay5"))
        self.btn_relay6.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay6.setText(_translate("MainWindow", "Relay6"))
        self.btn_relay7.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay7.setText(_translate("MainWindow", "Relay7"))
        self.btn_relay8.setToolTip(_translate("MainWindow", "<html><head/><body><p>Sets Relay to configured state</p></body></html>"))
        self.btn_relay8.setText(_translate("MainWindow", "Relay8"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab_9), _translate("MainWindow", "Relay"))
        self.settingsTabWidget.setToolTip(_translate("MainWindow", "<html><head/><body><p>Configuration of the imaging / plate solving program and the ASCOM drivers</p></body></html>"))
        self.label_143.setText(_translate("MainWindow", "Imaging Application: Camera / PlateSolver"))
        self.checkFastDownload.setToolTip(_translate("MainWindow", "Use Highspeed download of CCD camera if availabe"))
        self.checkFastDownload.setText(_translate("MainWindow", "Fast Download"))
        self.checkKeepImages.setToolTip(_translate("MainWindow", "Checked if you would like to keep the images of modeling session"))
        self.checkKeepImages.setText(_translate("MainWindow", "Keep Images from Modeling"))
        self.label_38.setText(_translate("MainWindow", "Mount Settle Time for Modeling"))
        self.label_173.setText(_translate("MainWindow", "% of total Size"))
        self.label_39.setText(_translate("MainWindow", "Exposure Camera"))
        self.cameraBin.setToolTip(_translate("MainWindow", "sets the camera bin"))
        self.label_102.setText(_translate("MainWindow", "Subframe"))
        self.scaleSubframe.setToolTip(_translate("MainWindow", "<html><head/><body><p>sets the percentage of frame size for subframe </p></body></html>"))
        self.label_163.setText(_translate("MainWindow", "Imaging Configuration for Modeling"))
        self.isoSetting.setToolTip(_translate("MainWindow", "Sets the iso setting"))
        self.checkDoSubframe.setToolTip(_translate("MainWindow", "<html><head/><body><p>If checked, subframes were used if possible</p></body></html>"))
        self.checkDoSubframe.setText(_translate("MainWindow", "Use Subframe"))
        self.label_172.setText(_translate("MainWindow", "ISO Setting"))
        self.label_167.setText(_translate("MainWindow", "um"))
        self.label_168.setText(_translate("MainWindow", "Focal Length of Telescope"))
        self.label_40.setText(_translate("MainWindow", "Camera Bin X/Y"))
        self.label_166.setText(_translate("MainWindow", "Pixel Size x/y for Camera"))
        self.label_164.setText(_translate("MainWindow", "s"))
        self.pixelSize.setToolTip(_translate("MainWindow", "Pixel size of camera"))
        self.label_169.setText(_translate("MainWindow", "mm"))
        self.focalLength.setToolTip(_translate("MainWindow", "resulting focal length - please think of reducers etc."))
        self.label_165.setText(_translate("MainWindow", "s"))
        self.cameraExposure.setToolTip(_translate("MainWindow", "sets the exposure time"))
        self.settlingTime.setToolTip(_translate("MainWindow", "Sets the time to wait after mount stop before imaging"))
        self.label_194.setText(_translate("MainWindow", "Horizon Mask"))
        self.label_147.setText(_translate("MainWindow", "Model Points File (Base & Refinement) "))
        self.btn_selectModelPointsFileName.setToolTip(_translate("MainWindow", "Sets dual tracking on / off"))
        self.btn_selectModelPointsFileName.setText(_translate("MainWindow", "Select"))
        self.le_horizonPointsFileName.setToolTip(_translate("MainWindow", "<html><head/><body><p>Filename for horizon file mask</p></body></html>"))
        self.label_122.setText(_translate("MainWindow", "°"))
        self.checkUseMinimumHorizonLine.setToolTip(_translate("MainWindow", "<html><head/><body><p>Use minimum altitude for horizon mask in modeling plot window</p></body></html>"))
        self.checkUseMinimumHorizonLine.setText(_translate("MainWindow", "Use Minumum Altitude as Horizon Mask"))
        self.label_35.setText(_translate("MainWindow", "Filename"))
        self.altitudeMinimumHorizon.setToolTip(_translate("MainWindow", "<html><head/><body><p>Value for minimum altitude for horizon mask</p></body></html>"))
        self.checkUseFileHorizonLine.setToolTip(_translate("MainWindow", "<html><head/><body><p>Use horizon mask file in modeling plot window</p></body></html>"))
        self.checkUseFileHorizonLine.setText(_translate("MainWindow", "Use Horizon Mask File"))
        self.le_modelPointsFileName.setToolTip(_translate("MainWindow", "<html><head/><body><p>Filename for model points data</p></body></html>"))
        self.btn_selectHorizonPointsFileName.setToolTip(_translate("MainWindow", "Sets dual tracking on / off"))
        self.btn_selectHorizonPointsFileName.setText(_translate("MainWindow", "Select"))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab_13), _translate("MainWindow", "Imaging"))
        self.label_138.setText(_translate("MainWindow", "Mount Connection Configuration"))
        self.label_193.setText(_translate("MainWindow", "Remote Access"))
        self.checkRemoteAccess.setToolTip(_translate("MainWindow", "<html><head/><body><p>check, if you would like to remote control MountWizzard for shutdown</p></body></html>"))
        self.checkRemoteAccess.setText(_translate("MainWindow", "Enable Remote Access"))
        self.btn_setupMountDriver.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select ASCOM driver for mount</p></body></html>"))
        self.btn_setupMountDriver.setText(_translate("MainWindow", "Setup Driver Mount"))
        self.le_mountIP.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of mount</p></body></html>"))
        self.le_mountIP.setText(_translate("MainWindow", "192.168.2.15"))
        self.label_mountIP.setText(_translate("MainWindow", "IP"))
        self.label_mountMAC.setText(_translate("MainWindow", "MAC"))
        self.le_mountMAC.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of mount</p></body></html>"))
        self.le_mountMAC.setText(_translate("MainWindow", "00.c0.08.87.35.db"))
        self.le_remotePort.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of mount</p></body></html>"))
        self.le_remotePort.setText(_translate("MainWindow", "3495"))
        self.label_mountIP_2.setText(_translate("MainWindow", "Port: "))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab_12), _translate("MainWindow", "Mount Driver"))
        self.btn_setupDomeDriver.setToolTip(_translate("MainWindow", "<html><head/><body><p>setup ASCOM dome driver</p></body></html>"))
        self.btn_setupDomeDriver.setText(_translate("MainWindow", "Dome"))
        self.label_257.setText(_translate("MainWindow", "Configuration of ASCOM Devices"))
        self.label_258.setText(_translate("MainWindow", "ASCOM Observing Conditions Hub"))
        self.btn_setupAscomEnvironmentDriver.setToolTip(_translate("MainWindow", "<html><head/><body><p>setup ASCOM Stickstation / mBox driver</p></body></html>"))
        self.btn_setupAscomEnvironmentDriver.setText(_translate("MainWindow", "Environment"))
        self.label_261.setText(_translate("MainWindow", "ASCOM Dome Driver Setup"))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab_20), _translate("MainWindow", "ASCOM Drivers"))
        self.le_INDIServerPort.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of mount</p></body></html>"))
        self.le_INDIServerPort.setText(_translate("MainWindow", "7624"))
        self.le_INDIServerIP.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.le_INDIServerIP.setText(_translate("MainWindow", "192.168.2.164"))
        self.label_259.setText(_translate("MainWindow", "Configuration of INDI Subsystem"))
        self.label_mountIP_3.setText(_translate("MainWindow", "Port: "))
        self.label_145.setText(_translate("MainWindow", "IP Address:"))
        self.le_INDIStatus.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.le_INDIStatus.setText(_translate("MainWindow", "---"))
        self.label_146.setText(_translate("MainWindow", "INDI Status"))
        self.le_INDITelescope.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.le_INDITelescope.setText(_translate("MainWindow", "---"))
        self.le_INDICCD.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.le_INDICCD.setText(_translate("MainWindow", "---"))
        self.label_149.setText(_translate("MainWindow", "Telescope"))
        self.label_198.setText(_translate("MainWindow", "CCD"))
        self.label_199.setText(_translate("MainWindow", "Weather"))
        self.le_INDIWeather.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.le_INDIWeather.setText(_translate("MainWindow", "---"))
        self.checkEnableINDI.setToolTip(_translate("MainWindow", "<html><head/><body><p>check, if you would like to remote control MountWizzard for shutdown</p></body></html>"))
        self.checkEnableINDI.setText(_translate("MainWindow", "Enable INDI Client running"))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab_21), _translate("MainWindow", "INDI Drivers"))
        self.le_altParkPos3.setInputMask(_translate("MainWindow", "99"))
        self.le_altParkPos3.setText(_translate("MainWindow", "1"))
        self.le_parkPos3Text.setToolTip(_translate("MainWindow", "Button text park menu 3"))
        self.le_parkPos3Text.setText(_translate("MainWindow", "Dew"))
        self.le_parkPos1Text.setToolTip(_translate("MainWindow", "Button text park menu 1"))
        self.le_parkPos1Text.setText(_translate("MainWindow", "Flat West"))
        self.label_19.setText(_translate("MainWindow", "Az"))
        self.label_43.setText(_translate("MainWindow", "Az"))
        self.label_54.setText(_translate("MainWindow", "Configuration of Fixed Park Positions "))
        self.le_azParkPos3.setInputMask(_translate("MainWindow", "999"))
        self.le_azParkPos3.setText(_translate("MainWindow", "270"))
        self.le_parkPos2Text.setToolTip(_translate("MainWindow", "Button text park menu 2"))
        self.le_parkPos2Text.setText(_translate("MainWindow", "Flat East"))
        self.le_azParkPos1.setInputMask(_translate("MainWindow", "999"))
        self.le_azParkPos1.setText(_translate("MainWindow", "1"))
        self.label_45.setText(_translate("MainWindow", "Alt"))
        self.le_altParkPos4.setInputMask(_translate("MainWindow", "99"))
        self.le_altParkPos4.setText(_translate("MainWindow", "1"))
        self.le_altParkPos1.setInputMask(_translate("MainWindow", "99"))
        self.le_altParkPos1.setText(_translate("MainWindow", "89"))
        self.label_2.setText(_translate("MainWindow", "Button 1    Text"))
        self.le_altParkPos2.setInputMask(_translate("MainWindow", "99"))
        self.le_altParkPos2.setText(_translate("MainWindow", "89"))
        self.label_51.setText(_translate("MainWindow", "Alt"))
        self.label_50.setText(_translate("MainWindow", "Button 4    Text"))
        self.label_44.setText(_translate("MainWindow", "Button 2    Text"))
        self.le_azParkPos2.setInputMask(_translate("MainWindow", "999"))
        self.le_azParkPos2.setText(_translate("MainWindow", "359"))
        self.label_49.setText(_translate("MainWindow", "Az"))
        self.label_3.setText(_translate("MainWindow", "Alt"))
        self.le_azParkPos4.setInputMask(_translate("MainWindow", "999"))
        self.le_azParkPos4.setText(_translate("MainWindow", "90"))
        self.label_46.setText(_translate("MainWindow", "Az"))
        self.label_48.setText(_translate("MainWindow", "Alt"))
        self.le_parkPos4Text.setToolTip(_translate("MainWindow", "Button text park menu 4"))
        self.le_parkPos4Text.setText(_translate("MainWindow", "CCD"))
        self.label_47.setText(_translate("MainWindow", "Button 3    Text"))
        self.le_azParkPos5.setInputMask(_translate("MainWindow", "999"))
        self.le_azParkPos5.setText(_translate("MainWindow", "270"))
        self.label_92.setText(_translate("MainWindow", "Button 6    Text"))
        self.le_altParkPos6.setInputMask(_translate("MainWindow", "99"))
        self.le_altParkPos6.setText(_translate("MainWindow", "1"))
        self.label_93.setText(_translate("MainWindow", "Az"))
        self.label_94.setText(_translate("MainWindow", "Alt"))
        self.label_95.setText(_translate("MainWindow", "Button 5    Text"))
        self.le_altParkPos5.setInputMask(_translate("MainWindow", "99"))
        self.le_altParkPos5.setText(_translate("MainWindow", "1"))
        self.le_parkPos6Text.setToolTip(_translate("MainWindow", "Button text park menu 4"))
        self.le_parkPos6Text.setText(_translate("MainWindow", "CCD"))
        self.le_parkPos5Text.setToolTip(_translate("MainWindow", "Button text park menu 3"))
        self.le_parkPos5Text.setText(_translate("MainWindow", "Dew"))
        self.label_131.setText(_translate("MainWindow", "Az"))
        self.label_132.setText(_translate("MainWindow", "Alt"))
        self.le_azParkPos6.setInputMask(_translate("MainWindow", "999"))
        self.le_azParkPos6.setText(_translate("MainWindow", "90"))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab_10), _translate("MainWindow", "Park Positions"))
        self.btn_downloadEarthrotation.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download earth rotation data</p></body></html>"))
        self.btn_downloadEarthrotation.setText(_translate("MainWindow", "Download Earth Rotation and UTC files"))
        self.label_123.setText(_translate("MainWindow", "Webservices for space data"))
        self.btn_downloadSpacestations.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download space stations TLE (please note: alternatively to Satellite)</p></body></html>"))
        self.btn_downloadSpacestations.setText(_translate("MainWindow", "Download Space Stations TLE Elements"))
        self.btn_downloadSatbrighest.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download Satellite TLE (please note: alternatively to space stations)</p></body></html>"))
        self.btn_downloadSatbrighest.setText(_translate("MainWindow", "Download Brightest Satellite TLE Elements"))
        self.btn_downloadAsteroidsMPC5000.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download asteroids MPC file</p></body></html>"))
        self.btn_downloadAsteroidsMPC5000.setText(_translate("MainWindow", "Downl. Asteroids MPC5000"))
        self.btn_downloadComets.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download comets MPC file</p></body></html>"))
        self.btn_downloadComets.setText(_translate("MainWindow", "Download Comets MPC File"))
        self.checkEarthrotation.setToolTip(_translate("MainWindow", "<html><head/><body><p>Upload earth rotation and UTC data</p></body></html>"))
        self.checkEarthrotation.setText(_translate("MainWindow", "Upload  Earth Rotation and UTC files"))
        self.checkTLE.setToolTip(_translate("MainWindow", "<html><head/><body><p>Upload TLE elements</p></body></html>"))
        self.checkTLE.setText(_translate("MainWindow", "Upload TLE Elements"))
        self.checkAsteroids.setToolTip(_translate("MainWindow", "<html><head/><body><p>Upload asteroids data</p></body></html>"))
        self.checkAsteroids.setText(_translate("MainWindow", "Upload Asteroids MPC File"))
        self.checkComets.setToolTip(_translate("MainWindow", "<html><head/><body><p>Upload comets data</p></body></html>"))
        self.checkComets.setText(_translate("MainWindow", "Upload Comets MPC File"))
        self.btn_uploadMount.setToolTip(_translate("MainWindow", "<html><head/><body><p>Start upload with 10micron updater</p></body></html>"))
        self.btn_uploadMount.setText(_translate("MainWindow", "Upload to Mount"))
        self.btn_downloadAll.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download all files (please note satellite and space stations work alternatively)  </p></body></html>"))
        self.btn_downloadAll.setText(_translate("MainWindow", "Download All Files"))
        self.label_134.setText(_translate("MainWindow", "Mount Uploads"))
        self.checkFilterMPC.setToolTip(_translate("MainWindow", "<html><head/><body><p>Check to filter Comets and Asteroids MPC File</p></body></html>"))
        self.checkFilterMPC.setText(_translate("MainWindow", "Filter MPC Files with expression(s):"))
        self.le_filterExpressionMPC.setToolTip(_translate("MainWindow", "<html><head/><body><p>serach expression, separated with \',\'</p></body></html>"))
        self.btn_downloadAsteroidsNEA.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download asteroids MPC file</p></body></html>"))
        self.btn_downloadAsteroidsNEA.setText(_translate("MainWindow", "Downl. Asteroids NEA"))
        self.btn_downloadAsteroidsTNO.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download asteroids MPC file</p></body></html>"))
        self.btn_downloadAsteroidsTNO.setText(_translate("MainWindow", "Downl. Asteroids TNO"))
        self.btn_downloadAsteroidsPHA.setToolTip(_translate("MainWindow", "<html><head/><body><p>Download asteroids MPC file</p></body></html>"))
        self.btn_downloadAsteroidsPHA.setText(_translate("MainWindow", "Downl. Asteroids PHA"))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab_7), _translate("MainWindow", "UTC / MPC / TLE "))
        self.relay2Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay2Text.setText(_translate("MainWindow", "free"))
        self.label_101.setText(_translate("MainWindow", "Relay 3"))
        self.relay5Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay5Text.setText(_translate("MainWindow", "free"))
        self.label_103.setText(_translate("MainWindow", "Relay Button Text Setup"))
        self.relay3Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay3Text.setText(_translate("MainWindow", "free"))
        self.label_36.setText(_translate("MainWindow", "Relay 1"))
        self.relay4Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay4Text.setText(_translate("MainWindow", "free"))
        self.label_148.setText(_translate("MainWindow", "Relay 5"))
        self.relay6Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay6Text.setText(_translate("MainWindow", "free"))
        self.label_150.setText(_translate("MainWindow", "Relay 4"))
        self.relay1Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay1Text.setText(_translate("MainWindow", "free"))
        self.label_161.setText(_translate("MainWindow", "Relay 6"))
        self.label_162.setText(_translate("MainWindow", "Relay 2"))
        self.relay8Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay8Text.setText(_translate("MainWindow", "free"))
        self.relay7Text.setToolTip(_translate("MainWindow", "<html><head/><body><p>Button text for relay</p></body></html>"))
        self.relay7Text.setText(_translate("MainWindow", "free"))
        self.label_191.setText(_translate("MainWindow", "Relay 7"))
        self.label_192.setText(_translate("MainWindow", "Relay 8"))
        self.label_144.setText(_translate("MainWindow", "IP Address:"))
        self.le_relayIP.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.le_relayIP.setText(_translate("MainWindow", "192.168.2.14"))
        self.label_141.setText(_translate("MainWindow", "Configuration of Relay Box (KMTronics Switch)"))
        self.label_41.setText(_translate("MainWindow", "Text"))
        self.label_195.setText(_translate("MainWindow", "Function"))
        self.label_196.setText(_translate("MainWindow", "Username:"))
        self.label_197.setText(_translate("MainWindow", "Password:"))
        self.KMUsername.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.KMUsername.setText(_translate("MainWindow", "empty"))
        self.KMPassword.setToolTip(_translate("MainWindow", "<html><head/><body><p>IP address of relay switch</p></body></html>"))
        self.KMPassword.setText(_translate("MainWindow", "empty"))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab), _translate("MainWindow", "Relay"))
        self.le_firmwareTime.setText(_translate("MainWindow", "Firmware Time"))
        self.firmwareProductName_7.setText(_translate("MainWindow", "Working Directory of MountWizzard is actually: "))
        self.le_firmwareProductName.setText(_translate("MainWindow", "Product Number"))
        self.le_firmwareDate.setText(_translate("MainWindow", "Firmware Date"))
        self.firmwareProductName_2.setText(_translate("MainWindow", "Product:"))
        self.le_firmwareProductName_2.setText(_translate("MainWindow", "MountWizzard 2 (C) 2016, 2017 MWORION"))
        self.firmwareProductName_6.setText(_translate("MainWindow", "HW Version:"))
        self.label_56.setText(_translate("MainWindow", "Product Versions"))
        self.le_hardwareVersion.setText(_translate("MainWindow", "Hardware Version"))
        self.le_firmwareNumber.setText(_translate("MainWindow", "Firmware Number"))
        self.le_mwWorkingDir.setToolTip(_translate("MainWindow", "<html><head/><body><p>Here the actually used working directory is shown</p></body></html>"))
        self.le_mwWorkingDir.setText(_translate("MainWindow", "Diectory Name"))
        self.firmwareProductName_4.setText(_translate("MainWindow", "FW Date:"))
        self.firmwareProductName_5.setText(_translate("MainWindow", "FW Time:"))
        self.firmwareProductName_3.setText(_translate("MainWindow", "Firmware:"))
        self.btn_runBoostModel.setToolTip(_translate("MainWindow", "Run refinment model"))
        self.btn_runBoostModel.setText(_translate("MainWindow", "Run Boost Model"))
        self.settingsTabWidget.setTabText(self.settingsTabWidget.indexOf(self.tab_11), _translate("MainWindow", "Versions"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab_3), _translate("MainWindow", "Settings"))
        self.btn_mountShutdown.setToolTip(_translate("MainWindow", "Send shutdown command to the mount and quit the tool"))
        self.btn_mountShutdown.setText(_translate("MainWindow", "Shutdown"))
        self.btn_mountQuit.setToolTip(_translate("MainWindow", "Quits the tool and saves the settings data in config.cfg"))
        self.btn_mountQuit.setText(_translate("MainWindow", "Save / Quit"))
        self.errorStatus.setToolTip(_translate("MainWindow", "Error Messages from Tool"))
        self.errorStatus.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))
        self.label_104.setText(_translate("MainWindow", "Message Board:"))
        self.btn_mountSave.setToolTip(_translate("MainWindow", "<html><head/><body><p>Saves the settings data in config.cfg</p></body></html>"))
        self.btn_mountSave.setText(_translate("MainWindow", "Save"))
        self.btn_camPlateConnected.setToolTip(_translate("MainWindow", "<html><head/><body><p>Status of Camera: green = available and connected</p></body></html>"))
        self.btn_camPlateConnected.setText(_translate("MainWindow", "Camera"))
        self.btn_domeConnected.setToolTip(_translate("MainWindow", "<html><head/><body><p>Status of dome: grey: no dome configured</p></body></html>"))
        self.btn_domeConnected.setText(_translate("MainWindow", "Dome"))
        self.btn_driverMountConnected.setToolTip(_translate("MainWindow", "<html><head/><body><p>Status of mount</p></body></html>"))
        self.btn_driverMountConnected.setText(_translate("MainWindow", "Mount"))
        self.btn_mountBoot.setToolTip(_translate("MainWindow", "<html><head/><body><p>Saves the settings data in config.cfg</p></body></html>"))
        self.btn_mountBoot.setText(_translate("MainWindow", "Boot"))
        self.btn_environmentConnected.setToolTip(_translate("MainWindow", "<html><head/><body><p>Status of Camera: green = available and connected</p></body></html>"))
        self.btn_environmentConnected.setText(_translate("MainWindow", "Environment"))

